part of orm_infrastructure;

class ServiceBase {
  
  //-----------------------------------
  //
  // Public properties
  //
  //-----------------------------------
  
  final String host;
  final String port;
  final Serializer serializer;
  final OnConflictFunction onConflict;
  
  //-----------------------------------
  //
  // Constructor
  //
  //-----------------------------------
  
  ServiceBase(this.host, this.port, this.serializer, this.onConflict);
  
  //-----------------------------------
  //
  // Public methods
  //
  //-----------------------------------
  
  Future apply(String operation, Map<String, dynamic> arguments, bool isUniqueResult) {
    Completer completer = new Completer();
    
    HttpRequest.request(
        'http://${host}:$port', 
        method:operation, 
        sendData:serializer.outgoing(arguments)
    ).then(
        (HttpRequest request) {
          if (request.responseText.length > 0) {
            EntityFactory<Entity> factory = new EntityFactory(onConflict);
            Stopwatch stopwatch;
            
            stopwatch = new Stopwatch()..start();
            
            List<Map<String, dynamic>> result = serializer.incoming(request.responseText);
            
            ObservableList<Entity> spawned = factory.spawn(result, serializer);
            
            stopwatch.stop();
            
            print('deserializing & assembly completed in ${stopwatch.elapsedMicroseconds} micro seconds');
            
            completer.complete(isUniqueResult ? spawned.first : spawned);
          }
        }, onError: (_) {
          print('Oops, something went wrong, are you sure that the server has started up correctly?');
        }
    );
    
    return completer.future;
  }
  
  //final test = '[{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"67E31","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1369265404150,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":694605,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Schedule Generation Job","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":4045,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Giorgio D-ESPOSITO","userId":17758},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517600000,"isBunkerCall":false,"updateTS":1334595923000,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1323877529000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":251,"insertTS":1323877529000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331885951000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":253,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1323862560000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1323875365000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1326216277960,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1323875365000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Matthew WATTS","userId":17732},"proformavesselscheduleterminalcallId":21}],"dieselConsumption":null},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1369265404150,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":697062}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":697062},"berthingId":213313,"vesselServiceAssignmentId":524,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"GBLIVRS","isTBN":"false","name":"ROYAL SEAFORTH CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531,"codePort":null}],"name":"LIVERPOOL","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":6,"pilotStations":[],"portId":222,"isRealPort":true,"displayName":"LIVERPOOL","isDeleted":false,"isInService":true,"isoCode":"GBLIV","timeZoneDifference":0.0,"netpasName":"Liverpool (UK)"},"draftArrivalAFT":null,"pilotArrivalDate":1376535600000,"berthingArrivalDate":1376564400000,"operatorContainerMoves40":null,"customArrivalVoyage":"67E31","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376517600000,"customArrivalVoyage":"67E31","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"67E31","dailyvesselschedulecellcompactId":658411,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"67E31","departureVoyage":"67E31","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"isTBN":"false","terminals":[{"codeMSC":"BEANRQT","isTBN":"false","name":"QUAY 125 TROUWNATIE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":48,"codePort":null},{"codeMSC":"BEANRCD","isTBN":"false","name":"Q522 - MEDREPAIR 4","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1350,"codePort":null},{"codeMSC":"730","isTBN":"false","name":"MSC HOME TERMINAL N.V. K730","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47,"codePort":null},{"codeMSC":"BEANRBH","isTBN":"false","name":"M12","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":969,"codePort":null},{"codeMSC":"BEANRBM","isTBN":"false","name":"M11","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1171,"codePort":null},{"codeMSC":"1227","isTBN":"false","name":"KATOENNATIE K1227","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":46,"codePort":null},{"codeMSC":"BEANRBQ","isTBN":"false","name":"DPWORLD 1700","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160,"codePort":null},{"codeMSC":"BEANRBR","isTBN":"false","name":"DPWORLD  746","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1159,"codePort":null},{"codeMSC":"BEANRBS","isTBN":"false","name":"DPWORLD  742","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1158,"codePort":null},{"codeMSC":"BEANRBT","isTBN":"false","name":"DEURGANCK TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263,"codePort":null},{"codeMSC":"BEANRBN","isTBN":"false","name":"DDM6","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1170,"codePort":null},{"codeMSC":"S869","isTBN":"false","name":"BERTH S869","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":45,"codePort":null},{"codeMSC":"S913","isTBN":"false","name":"BERTH Q913","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":44,"codePort":null},{"codeMSC":"736","isTBN":"false","name":"BERTH 736","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":43,"codePort":null},{"codeMSC":"BEANRBO","isTBN":"false","name":"BERTH 524","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":970,"codePort":null},{"codeMSC":"BEANRBE","isTBN":"false","name":"BERTH 420","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":42,"codePort":null},{"codeMSC":"BEANRTH","isTBN":"false","name":"BERTH 1742","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":41,"codePort":null},{"codeMSC":"BEANRCA","isTBN":"false","name":"BERTH 1207 EUROPORTS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1321,"codePort":null},{"codeMSC":"BEANRBG","isTBN":"false","name":"ANTWERP SHIP REPAIR NV","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":968,"codePort":null},{"codeMSC":"BEANTGA","isTBN":"false","name":"ANTWERP GATEWAY N.V.","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40,"codePort":null}],"name":"ANTWERP","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":8,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Wandelaar","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":1,"netpasName":"Wandelaar Pilot station_Antwarp"},{"isDeleted":false,"isDefault":false,"name":"Steenbank","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":2,"netpasName":"Steenbank Pilot Station"}],"portId":743,"isRealPort":true,"displayName":"ANTWERP","isDeleted":false,"isInService":true,"isoCode":"BEANR","timeZoneDifference":1.0,"netpasName":"Antwerp"},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Administrator","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1423,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC ALYSSA","vesselId":2128,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1423,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSAY","dateOutService":null,"dateInService":998524800000,"code":"02229","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":273.7,"imoNumber":"9235050","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"MTR EX","isStandardMSCVoyageCoding":false,"useVoyageLinking":true,"isDeleted":false,"startDate":1322431200000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ffff00","laneCode":"MTREX","useWeeklyVoyageNumbers":true,"name":"MONTREAL EXPRESS 1","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":61,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"CM","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1369660571193,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"DEBRUNK","isTBN":"false","name":"UNIKAI","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":186,"codePort":null},{"codeMSC":"DEBRVNT","isTBN":"false","name":"NTB","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185,"codePort":null},{"codeMSC":"DEBRVMG","isTBN":"false","name":"MSC GATE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184,"codePort":null}],"name":"BREMERHAVEN","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":4,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Weser Pilor station","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":6,"netpasName":"Weser Pilot station (Bermen)"}],"portId":747,"isRealPort":true,"displayName":"BREMERHAVEN","isDeleted":false,"isInService":true,"isoCode":"DEBRV","timeZoneDifference":1.0,"netpasName":"Bremerhaven"},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1369177814337,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":693777,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1326177423000,"isBunkerCall":false,"updateTS":1373288144000,"berthingArrival":1326206223000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":28582,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1373288144000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1373288144000,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Julien CHETCUTI","userId":13229}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":374691,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304431200000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1308693615000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1337255134000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":54,"insertTS":1337255134000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":5756,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Fabio GARGIULO","userId":12330},"proformavesselscheduleterminalcallId":375481}],"dieselConsumption":null},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1369177814337,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":696228}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":696228},"berthingId":213877,"vesselServiceAssignmentId":5102,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"BRIGIST","isTBN":"false","name":"SEPETIBA TECON S/A","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57,"codePort":null}],"name":"ITAGUAI","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":61,"isRealPort":true,"displayName":"ITAGUAI","isDeleted":false,"isInService":true,"isoCode":"BRIGI","timeZoneDifference":-6.0,"netpasName":null},"draftArrivalAFT":null,"pilotArrivalDate":1379599200000,"berthingArrivalDate":1379628000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NA334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379455200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":657601,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA334R","departureVoyage":"NA334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3542,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"HS PARIS","vesselId":8929,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3542,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MHPR","dateOutService":null,"dateInService":1358121600000,"code":"08712","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9526502","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"SAEC1","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":1321254000000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":10,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"7fff00","laneCode":"NWSA1","useWeeklyVoyageNumbers":true,"name":"NWC TO SAEC - STRING I","exceedingDateOffset":10080,"isScheduleDelayDisplayed":false,"serviceId":67,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NA","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1369660571193,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"NLRTMUN","isTBN":"false","name":"UNIPORT MULTIPURPOSE TERMINALS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":346,"codePort":null},{"codeMSC":"NLRTMAT","isTBN":"false","name":"RST-NZ TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":617,"codePort":null},{"codeMSC":"NLRTMZT","isTBN":"false","name":"ROTTERDAM SHORTSEA TERMINALS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":345,"codePort":null},{"codeMSC":"NLRTMCT","isTBN":"false","name":"ROTTERDAM CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":344,"codePort":null},{"codeMSC":"NLRTMAS","isTBN":"false","name":"ECT EUROMAX TERMINAL ROTTERDAM","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":616,"codePort":null},{"codeMSC":"NLEC1","isTBN":"false","name":"ECT DELTA TERMINAL BV","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":342,"codePort":null},{"codeMSC":"NLRTMBQ","isTBN":"false","name":"ECT DELTA TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615,"codePort":null},{"codeMSC":"NLRTMAW","isTBN":"false","name":"ECT DELTA MARINE TERMINAL (DMT)","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613,"codePort":null},{"codeMSC":"NLRTMAV","isTBN":"false","name":"ECT DELTA DDW TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614,"codePort":null},{"codeMSC":"NLRTMAU","isTBN":"false","name":"ECT DELTA DDE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":612,"codePort":null},{"codeMSC":"NLEC2","isTBN":"false","name":"ECT CITY TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":343,"codePort":null},{"codeMSC":"NLRTMBC","isTBN":"false","name":"BCW (BARGE CENTER WAALHAVEN)","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":341,"codePort":null},{"codeMSC":"NLRTMCW","isTBN":"false","name":"BARGE CENTER WAALHAVEN BV","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":611,"codePort":null},{"codeMSC":"NLAPM","isTBN":"false","name":"APM TERMINALS BV","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":340,"codePort":null}],"name":"ROTTERDAM","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Maas pilot station","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":15,"netpasName":"Maas pilot station (Rotterdam)"}],"portId":762,"isRealPort":true,"displayName":"ROTTERDAM","isDeleted":false,"isInService":true,"isoCode":"NLRTM","timeZoneDifference":1.0,"netpasName":"Rotterdam"},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1368575731183,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":688543,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1313042967000,"isBunkerCall":false,"updateTS":1369904994000,"berthingArrival":1313071767000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":26697,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1369904994000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1369904994000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1368575731183,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":690965}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":690965},"berthingId":213885,"vesselServiceAssignmentId":1036,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":null,"pilotArrivalDate":1378994400000,"berthingArrivalDate":1379023200000,"operatorContainerMoves40":null,"customArrivalVoyage":"NA333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378850400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":652487,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA333R","departureVoyage":"NA333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1353,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC ANTARES","vesselId":4224,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1353,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MANT","dateOutService":null,"dateInService":1225756800000,"code":"06388","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":277.3,"imoNumber":"9213571","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1369660571193,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375450790000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA330R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375450788000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375450788000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753017,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308315002000,"isBunkerCall":false,"updateTS":1375450788000,"berthingArrival":1308343802000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":27434,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1371112184000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1371112184000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375450788000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756139}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":756139},"berthingId":213901,"vesselServiceAssignmentId":3494,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":0.0,"pilotArrivalDate":1377007200000,"berthingArrivalDate":1377036000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NA330R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377122400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":715406,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA330R","departureVoyage":"NA330R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1478,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC FLORENTINA","vesselId":2137,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1478,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSFT","dateOutService":null,"dateInService":998438400000,"code":"02241","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":299.9,"imoNumber":"9251705","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1369660571193,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375861877000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375861875000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375861875000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":755958,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308630003000,"isBunkerCall":false,"updateTS":1375861875000,"berthingArrival":1308658803000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":27880,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1372092477000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1372092477000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":13,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375861875000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":759115}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759115},"berthingId":213911,"vesselServiceAssignmentId":3648,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":0.0,"pilotArrivalDate":1378216800000,"berthingArrivalDate":1378245600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NA332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378245600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":718309,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA332R","departureVoyage":"NA332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1778,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"AGIOS DIMITRIOS","vesselId":5067,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1778,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MADT","dateOutService":null,"dateInService":1298937600000,"code":"07506","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":299.2,"imoNumber":"9349605","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1369660571193,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1369595722347,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":696933,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309082447000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1309111247000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":16,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":617446,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309082447000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1309111247000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":54,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":9871,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":16,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617446,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"John WEBB","userId":17733},"proformavesselscheduleterminalcallId":619358}],"dieselConsumption":null},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1369595722347,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":699408}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":699408},"berthingId":214689,"vesselServiceAssignmentId":4040,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"USCHWND","isTBN":"false","name":"WANDO WELCH TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":541,"codePort":null},{"codeMSC":"USCHSNC","isTBN":"false","name":"NORTH CHARLESTON MARINE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540,"codePort":null}],"name":"CHARLESTON, SC","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":3,"pilotStations":[],"portId":603,"isRealPort":true,"displayName":"CHARLESTON","isDeleted":false,"isInService":true,"isoCode":"USCHS","timeZoneDifference":-5.0,"netpasName":"Charleston"},"draftArrivalAFT":null,"pilotArrivalDate":1378551600000,"berthingArrivalDate":1378580400000,"operatorContainerMoves40":null,"customArrivalVoyage":"NG333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378656000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":660707,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG333R","departureVoyage":"NG333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1381,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CMA CGM VERLAINE","vesselId":4641,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1381,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCVL","dateOutService":1337817540000,"dateInService":1267920000000,"code":"07015","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"BUXCLIFF","vesselId":8370,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1381,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MBXL","dateOutService":null,"dateInService":1337817600000,"code":"08310","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":299.9,"imoNumber":"9221815","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"NWCUSG","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":1320127200000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ffa500","laneCode":"NWUSG","useWeeklyVoyageNumbers":true,"name":"NWC TO USA - SOUTH ATLANTIC","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":71,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NG","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1369660571193,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1369778723940,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":698396,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1317421119000,"isBunkerCall":false,"updateTS":1373878671000,"berthingArrival":1317449919000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":29194,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1373878671000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1373878671000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1369778723940,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":700880}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":700880},"berthingId":217020,"vesselServiceAssignmentId":4729,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":null,"pilotArrivalDate":1380031200000,"berthingArrivalDate":1380060000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NA335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380060000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":662145,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA335R","departureVoyage":"NA335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1991,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC BARCELONA","vesselId":5448,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1991,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MBCN","dateOutService":null,"dateInService":1316131200000,"code":"07815","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":270.3,"imoNumber":"9480186","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1369822150100,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376773200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NQ333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1369799102410,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":698408,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Giuseppe MARESCA","userId":12887},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1310986852000,"isBunkerCall":false,"updateTS":1372075938000,"berthingArrival":1311015652000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1311130852000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":21027,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":41.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":632688,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306472408000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1306501208000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":1184,"vesselClass":null,"updateUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Gianfranco DI BARTOLOMEO","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"updateTS":1364486293000,"isMaster":true,"isDeleted":false,"insertTS":1363356674000,"isInService":true,"versionInfo":"TEST  LEH+ SAV + PEF 7 navi","version":4,"dateInUse":null,"deleteTS":1359803295000,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":632693,"averageVesselFuelConsumptionPerHour":3.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308591464000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1304474400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":4320,"port":{"isTBN":"false","terminals":[{"codeMSC":"ECGYEAJ","isTBN":"false","name":"TERMINAL PORTUARIO DE GUAYAQUIL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1000,"codePort":null},{"codeMSC":"ECGYEAN","isTBN":"false","name":"NAPORTEC S.A.","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1231,"codePort":null},{"codeMSC":"ECGYEAQ","isTBN":"false","name":"NAPORTEC","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1354,"codePort":null},{"codeMSC":"ECGYEAP","isTBN":"false","name":"CONTECON","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":144,"codePort":null}],"name":"GUAYAQUIL","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":10,"pilotStations":[],"portId":158,"isRealPort":true,"displayName":"GUAYAQUIL","isDeleted":false,"isInService":true,"isoCode":"ECGYE","timeZoneDifference":-5.0,"netpasName":"Guayaquil"},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304744400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10534},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21023,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":158},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"PABLBPB","isTBN":"false","name":"PORT OF BALBOA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":388,"codePort":null}],"name":"BALBOA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":677,"isRealPort":true,"displayName":"BALBOA","isDeleted":false,"isInService":true,"isoCode":"PABLB","timeZoneDifference":-5.0,"netpasName":"Balboa"},"isDeleted":false,"distanceInMiles":810,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":144},"pilottimeId":10534,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":158},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":171.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304733600000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":144},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632693,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634536}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":632689,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304906400000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1304917200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"bufferTime":180,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304992800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10535},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21029,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"PACRBPC","isTBN":"false","name":"PORT OF CRISTOBAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":389,"codePort":null}],"name":"CRISTOBAL","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":676,"isRealPort":true,"displayName":"CRISTOBAL","isDeleted":false,"isInService":true,"isoCode":"PACTB","timeZoneDifference":-5.0,"netpasName":"Cristobal"},"isDeleted":false,"distanceInMiles":56,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":388},"pilottimeId":10535,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":12.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":7.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304982000000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":388},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632689,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634544}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":632692,"averageVesselFuelConsumptionPerHour":3.6,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305032400000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1305039600000,"inheritedVoyage":"","adjustmentTime":43,"timeInPort":1380,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"isDeleted":false,"bufferTime":360,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305129600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10538},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21026,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":4969,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":389},"pilottimeId":10538,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":1052.26,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305122400000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":389},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632692,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634543}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":632686,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306206038000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1306216838000,"inheritedVoyage":"","adjustmentTime":30,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306314038000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10542},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21028,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":200,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":10542,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":42.5,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306303238000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634541}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":632687,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306357238000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1306364438000,"inheritedVoyage":"","adjustmentTime":37,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306458038000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10536},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21024,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":54,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"pilottimeId":10536,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":11.48,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306450838000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632687,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634537}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":632688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":632690,"averageVesselFuelConsumptionPerHour":3.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306663259000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1306670459000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":600,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306713659000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10541},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":-6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21020,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USSAVGC","isTBN":"false","name":"GARDEN CITY TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":566,"codePort":null}],"name":"SAVANNAH, GA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":3,"pilotStations":[],"portId":630,"isRealPort":true,"displayName":"SAVANNAH","isDeleted":false,"isInService":true,"isoCode":"USSAV","timeZoneDifference":-5.0,"netpasName":"Savannah"},"isDeleted":false,"distanceInMiles":3675,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":10541,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":872.81,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306706459000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632690,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634535}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":632691,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307584814000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1307599214000,"inheritedVoyage":"","adjustmentTime":15,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":630},"isDeleted":false,"bufferTime":360,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307656814000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10543},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21025,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":630},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USPEFPE","isTBN":"false","name":"PORT EVERGLADES TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":562,"codePort":null}],"name":"PORT EVERGLADES, FL","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":622,"isRealPort":true,"displayName":"PORT EVERGLADES","isDeleted":false,"isInService":true,"isoCode":"USPEF","timeZoneDifference":-5.0,"netpasName":"Fort Lauderdale"},"isDeleted":false,"distanceInMiles":380,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":240.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":566},"pilottimeId":10543,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":630},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":80.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307642414000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":1359803295000,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":566},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634540}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":632694,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307764814000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1307772014000,"inheritedVoyage":"","adjustmentTime":30,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":622},"isDeleted":false,"bufferTime":3360,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307822414000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10537},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21022,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":622},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"distanceInMiles":1272,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":562},"pilottimeId":10537,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":622},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":270.3,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307815214000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":1359803295000,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":562},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632694,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634542}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":632695,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308312014000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1308322814000,"inheritedVoyage":"","adjustmentTime":12,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"bufferTime":1571,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308420014000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10539},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21021,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":158},"isDeleted":false,"distanceInMiles":810,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":388},"pilottimeId":10539,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":172.13,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308409214000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":1359803295000,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":388},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632695,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634545}],"dieselConsumption":null}],"voyageCalculationMethod":{"isDeleted":false,"name":"Default MSC encoding","isInService":true,"description":"Default MSC encoding","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1,"type":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":632685,"averageVesselFuelConsumptionPerHour":3.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308697244000,"isBunkerCall":false,"updateTS":1363356674000,"berthingArrival":1308708044000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":4320,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":158},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10534},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":21023,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10534},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":171.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":144},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632685,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634539}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1306616408000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21027,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1363356674000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":159,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":10540,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1363356674000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":41.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"leg":1,"matchingProformaVesselSchedulePort":null,"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306587608000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1363356674000,"useTimeZoneDifference":false,"deleteTS":1359803295000,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363356674000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1363356674000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":634538}],"dieselConsumption":null},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1311102052000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1369799102410,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":700892}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":700892},"berthingId":217032,"vesselServiceAssignmentId":4929,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":null,"pilotArrivalDate":1376629200000,"berthingArrivalDate":1376658000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NQ333A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376745480000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":662157,"liveDepartureDate":1376831880000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NQ333A","departureVoyage":"NQ333A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1945,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CSAV LEBU","vesselId":5531,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1945,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVLB","dateOutService":null,"dateInService":1321142400000,"code":"07889","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":261.0,"imoNumber":"9443463","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"ECUNW","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":false,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":false,"color":"6495ed","laneCode":"ECUNW","useWeeklyVoyageNumbers":true,"name":"ECUADOR TO NWC","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":227,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NQ","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1369822150100,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376744400000,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"FRLEHAM","isTBN":"false","name":"TN MSC 2000","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218,"codePort":null},{"codeMSC":"FRLEHPO","isTBN":"false","name":"TERMINAL PORTE OCEANE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":174,"codePort":null},{"codeMSC":"FRLEHTN","isTBN":"false","name":"TERMINAL DE NORMANDIE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173,"codePort":null},{"codeMSC":"FRLEHTO","isTBN":"false","name":"TERMINAL DE L-OCEAN","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":172,"codePort":null},{"codeMSC":"FRLEHAO","isTBN":"false","name":"TERMINAL DE L-EUROPE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1261,"codePort":null},{"codeMSC":"FRLEHTA","isTBN":"false","name":"TERMINAL DE L-ATLANTIQUE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171,"codePort":null},{"codeMSC":"FRLEHAN","isTBN":"false","name":"TERMINAL DE FRANCE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1243,"codePort":null}],"name":"LE HAVRE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":3,"pilotStations":[],"portId":756,"isRealPort":true,"displayName":"LE HAVRE","isDeleted":false,"isInService":true,"isoCode":"FRLEH","timeZoneDifference":1.0,"netpasName":"Le Havre"},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1369866306537,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":699355,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1369866306537,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":701841}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":701841},"berthingId":219218,"vesselServiceAssignmentId":525,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":null,"pilotArrivalDate":1377093600000,"berthingArrivalDate":1377122400000,"operatorContainerMoves40":null,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377122400000,"customArrivalVoyage":"22E32","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"22E32","dailyvesselschedulecellcompactId":663068,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"22E32","departureVoyage":"22E32","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1287,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"OOCL BELGIUM","vesselId":2471,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1287,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCBM","dateOutService":null,"dateInService":1040601600000,"code":"03025","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":0.0,"imoNumber":"9169419","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1369990656617,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370196642190,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":704020,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309082447000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1309111247000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":16,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617446,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370196642190,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":706524}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":706524},"berthingId":219338,"vesselServiceAssignmentId":4195,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":null,"pilotArrivalDate":1379420640000,"berthingArrivalDate":1379449440000,"operatorContainerMoves40":null,"customArrivalVoyage":"NG334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379260800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":667001,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG334R","departureVoyage":"NG334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1524,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC MARINA","vesselId":2489,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1524,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSMI","dateOutService":null,"dateInService":1042416000000,"code":"03052","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":304.0,"imoNumber":"9275971","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1370249523927,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370072717863,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":702782,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20364},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308539281000,"isBunkerCall":false,"updateTS":1372841204000,"berthingArrival":1308568081000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":28348,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20364},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1372841204000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1372841204000,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Arcangelo CASO","userId":20364}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":681491,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306533630000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1306562430000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":null,"updateTS":1326454423517,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":161,"insertTS":1326454423517,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":13073,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681491,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683859}],"dieselConsumption":null},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370072717863,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":705287}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":705287},"berthingId":219346,"vesselServiceAssignmentId":5074,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1376690400000,"berthingArrivalDate":1376719200000,"operatorContainerMoves40":null,"customArrivalVoyage":"NP332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376719200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":666412,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP332R","departureVoyage":"NP332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3617,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"THIRA","vesselId":9030,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3617,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MTHI","dateOutService":null,"dateInService":1364774400000,"code":"08809","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":205.5,"imoNumber":"9134490","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"NWCPOR","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":1319868000000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":false,"color":"32cd32","laneCode":"NWPOR","useWeeklyVoyageNumbers":true,"name":"NWC TO/FROM SPAIN & PORTUGAL - FEEDER SERVICE","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":65,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NP","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1370249523927,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370386819377,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":706912,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1317421119000,"isBunkerCall":false,"updateTS":1374858002000,"berthingArrival":1317449919000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":29730,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1374858002000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1374858002000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370386819377,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":709422}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":709422},"berthingId":220121,"vesselServiceAssignmentId":4547,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":null,"pilotArrivalDate":1380636000000,"berthingArrivalDate":1380664800000,"operatorContainerMoves40":null,"customArrivalVoyage":"NA336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380664800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":669826,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA336R","departureVoyage":"NA336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1840,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC SORAYA","vesselId":4129,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1840,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSOA","dateOutService":null,"dateInService":1216166400000,"code":"06183","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":277.3,"imoNumber":"9372494","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1370426813510,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377370800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NQ334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370400002940,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":706918,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1310986852000,"isBunkerCall":false,"updateTS":1374497053000,"berthingArrival":1311015652000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1311130852000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":21027,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":41.58,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1311102052000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1370400002940,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":709428}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":709428},"berthingId":220125,"vesselServiceAssignmentId":4928,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":null,"pilotArrivalDate":1377226800000,"berthingArrivalDate":1377255600000,"operatorContainerMoves40":null,"customArrivalVoyage":"NQ334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377306000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":669832,"liveDepartureDate":1377392400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NQ334A","departureVoyage":"NQ334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1946,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CSAV LINGUE","vesselId":5540,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1946,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVLI","dateOutService":null,"dateInService":1321747200000,"code":"07897","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":261.0,"imoNumber":"9443475","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1370426813510,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377342000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"692W31","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1370539535000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370539535000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":708652,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306936851000,"isBunkerCall":false,"updateTS":1370539535000,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Michela DI BARTOLOMEO","userId":18376},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370539535000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":711162}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":711162},"berthingId":220615,"vesselServiceAssignmentId":5545,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":null,"pilotArrivalDate":1377871200000,"berthingArrivalDate":1377900000000,"operatorContainerMoves40":null,"customArrivalVoyage":"692W31","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377727200000,"customArrivalVoyage":"692E33","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"692E33","dailyvesselschedulecellcompactId":671441,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"692E33","departureVoyage":"692E33","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1337,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC SANDRA","vesselId":1976,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1337,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSSD","dateOutService":null,"dateInService":967075200000,"code":"01650","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":273.7,"imoNumber":"9203954","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1370620221113,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370673617957,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":710259,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306533630000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306562430000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681491,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370673617957,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":712793}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":712793},"berthingId":220652,"vesselServiceAssignmentId":2972,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1377295200000,"berthingArrivalDate":1377324000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NP333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377324000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":672987,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP333R","departureVoyage":"NP333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1293,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"HISPANIA","vesselId":5044,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1293,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1325548740000,"dateInService":1297123200000,"code":"07482","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"HISPANIA","vesselId":8129,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1293,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MHIS","dateOutService":null,"dateInService":1329523200000,"code":"08100","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":168.87,"imoNumber":"9176682","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1370770504503,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BJ332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370815807787,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":710567,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308753285000,"isBunkerCall":false,"updateTS":1375433062000,"berthingArrival":1308782085000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":30034,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1375433062000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1375433062000,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Marina LENNIE","userId":12142}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":382124,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304863200000,"isBunkerCall":false,"updateTS":1349681630000,"berthingArrival":1306101655000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1332179676000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":251,"insertTS":1332179676000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349681530000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":5858,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1349681530000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1349681530000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349681630000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1349681630000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382124,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Filip TORFS","userId":18989},"proformavesselscheduleterminalcallId":382894}],"dieselConsumption":null},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370815807787,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":713105}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":713105},"berthingId":220684,"vesselServiceAssignmentId":4493,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"EETLLMC","isTBN":"false","name":"MUUGA CT AS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153,"codePort":null}],"name":"TALLINN","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":159,"isRealPort":true,"displayName":"TALLINN","isDeleted":false,"isInService":true,"isoCode":"EETLL","timeZoneDifference":2.0,"netpasName":"Tallinn"},"draftArrivalAFT":null,"pilotArrivalDate":1376834400000,"berthingArrivalDate":1376863200000,"operatorContainerMoves40":null,"customArrivalVoyage":"BJ332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376866800000,"customArrivalVoyage":"BJ332R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ332R","dailyvesselschedulecellcompactId":673266,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ332R","departureVoyage":"BJ332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC HINA","vesselId":2592,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1336867200000,"dateInService":1052956800000,"code":"03207","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC HINA","vesselId":8385,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSHN","dateOutService":null,"dateInService":1336953600000,"code":"08326","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":203.06,"imoNumber":"8201686","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"BAL10","isStandardMSCVoyageCoding":false,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ff6347","laneCode":"BALT10","useWeeklyVoyageNumbers":false,"name":"BALTIC LOOP 10","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":16,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"BJ","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1370888005940,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21832},"operatorContainerMoves20":0,"updateTS":1375904687000,"noonPositionTelex":null,"pilotDepartureDate":1378697100000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21832},"deleteUser":null,"updateTS":1375904682000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1375904682000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":757015,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21832},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307030498000,"isBunkerCall":false,"updateTS":1375904682000,"berthingArrival":1307059298000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1307145698000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8365},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Tamires SILVA","userId":21832},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8365},"sequence":11,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":561507,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307282430000,"isBunkerCall":false,"updateTS":1357321631000,"berthingArrival":1307311230000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":993,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"updateTS":1375892746000,"isMaster":false,"isDeleted":false,"insertTS":1356629986000,"isInService":true,"versionInfo":"NWC 3 - SAMBA","version":9,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":561502,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308560627000,"isBunkerCall":false,"updateTS":1375892746000,"berthingArrival":1304319600000,"inheritedVoyage":"","adjustmentTime":554,"timeInPort":1080,"port":{"isTBN":"false","terminals":[{"codeMSC":"BRSSZBA","isTBN":"false","name":"TECONDI TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1346,"codePort":null},{"codeMSC":"BRSSZTE","isTBN":"false","name":"TECON","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":70,"codePort":null},{"codeMSC":"BRSSZRM","isTBN":"false","name":"RODRIMAR S.A.","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":69,"codePort":null},{"codeMSC":"BRSSZTS","isTBN":"false","name":"LIBRA TERMINAL 37","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":68,"codePort":null},{"codeMSC":"BRSSZTC","isTBN":"false","name":"LIBRA TERMINAL 35","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":67,"codePort":null},{"codeMSC":"BRSSZAY","isTBN":"false","name":"BRASIL TERMINAL PORTUARIO S/A","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1282,"codePort":null}],"name":"SANTOS, SP","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":74,"isRealPort":true,"displayName":"SANTOS","isDeleted":false,"isInService":true,"isoCode":"BRSSZ","timeZoneDifference":-3.0,"netpasName":"Santos"},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304388000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8374},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12766,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"BRPNGTC","isTBN":"false","name":"TCP","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62,"codePort":null}],"name":"PARANAGUA, PR","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":67,"isRealPort":true,"displayName":"PARANAGUA","isDeleted":false,"isInService":true,"isoCode":"BRPNG","timeZoneDifference":-3.0,"netpasName":"Paranagua"},"isDeleted":false,"distanceInMiles":166,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":68},"pilottimeId":8374,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.4,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304384400000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892746000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1346},"insertTS":1375892746000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561502,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759934}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":561497,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460045000,"isBunkerCall":false,"updateTS":1356629986000,"berthingArrival":1304467245000,"inheritedVoyage":"","adjustmentTime":45,"timeInPort":780,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304521245000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8371},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12773,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":27,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ARTRP","isTBN":"false","name":"TERMINAL RIO DE LA PLATA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":15,"codePort":null},{"codeMSC":"ARBUEAK","isTBN":"false","name":"TERMINAL 4 SA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1303,"codePort":null},{"codeMSC":"ARBUEAJ","isTBN":"false","name":"EXOLGAN S.A.","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1168,"codePort":null}],"name":"BUENOS AIRES","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":13,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Recalada Lightship","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":27,"netpasName":"Recalada Lightship"}],"portId":24,"isRealPort":true,"displayName":"BUENOS AIRES","isDeleted":false,"isInService":true,"isoCode":"ARBUE","timeZoneDifference":-3.0,"netpasName":"Buenos Aires"},"isDeleted":false,"distanceInMiles":772,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"pilottimeId":8371,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304514045000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561497,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563092}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561498,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304715614000,"isBunkerCall":false,"updateTS":1357321346000,"berthingArrival":1304751614000,"inheritedVoyage":"","adjustmentTime":516,"timeInPort":1410,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304872214000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":600.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1168},"pilottimeId":8367,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12768,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":27,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"UYMVDTC","isTBN":"false","name":"TERMINAL CUENCA DEL PLATA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":570,"codePort":null},{"codeMSC":"UYMVDMO","isTBN":"false","name":"MONTECON","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":569,"codePort":null}],"name":"MONTEVIDEO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":634,"isRealPort":true,"displayName":"MONTEVIDEO","isDeleted":false,"isInService":true,"isoCode":"UYMVD","timeZoneDifference":-3.0,"netpasName":"Montevideo"},"isDeleted":false,"distanceInMiles":129,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":600.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1168},"pilottimeId":8366,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":10.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304836214000,"pilotStation":{"?p":"true","pilotstationId":27,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1168},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561498,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563098}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561494,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949614000,"isBunkerCall":false,"updateTS":1357321346000,"berthingArrival":1304953214000,"inheritedVoyage":"","adjustmentTime":28,"timeInPort":1410,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305041414000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8369},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12775,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"BRRIGTR","isTBN":"false","name":"TECON RIO GRANDE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":65,"codePort":null}],"name":"RIO GRANDE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":70,"isRealPort":true,"displayName":"RIO GRANDE BRAZIL","isDeleted":false,"isInService":true,"isoCode":"BRRIG","timeZoneDifference":-3.0,"netpasName":"Rio Grande"},"isDeleted":false,"distanceInMiles":314,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":570},"pilottimeId":8369,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305037814000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":570},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561494,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563090}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561501,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305100836000,"isBunkerCall":false,"updateTS":1357321346000,"berthingArrival":1305104436000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":70},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305165636000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8373},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12776,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":70},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"BRIBBAA","isTBN":"false","name":"TECON IMBITUBA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1289,"codePort":null},{"codeMSC":"BRIBBAB","isTBN":"false","name":"SANTOS BRASIL PARTICIPA��ES S.A","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1292,"codePort":null}],"name":"IMBITUBA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":null,"pilotStations":[],"portId":897,"isRealPort":true,"displayName":"IMBITUBA","isDeleted":false,"isInService":true,"isoCode":"BRIBB","timeZoneDifference":-3.0,"netpasName":null},"isDeleted":false,"distanceInMiles":320,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":65},"pilottimeId":8373,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":70},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305162036000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":65},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561501,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563088}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561499,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305226826000,"isBunkerCall":false,"updateTS":1357321346000,"berthingArrival":1305234026000,"inheritedVoyage":"","adjustmentTime":41,"timeInPort":600,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":897},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305277226000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8377},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12778,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":897},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"distanceInMiles":295,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1289},"pilottimeId":8377,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":897},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305270026000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1289},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563087}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561495,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305331256000,"isBunkerCall":false,"updateTS":1357321346000,"berthingArrival":1305334856000,"inheritedVoyage":"","adjustmentTime":31,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305396056000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8374},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12765,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"BRPECCT","isTBN":"false","name":"APM TERMINALS PECEM OPERACOES PORTUARIAS LTDA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":63,"codePort":null}],"name":"PECEM, CE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":784,"isRealPort":true,"displayName":"PECEM, CE","isDeleted":false,"isInService":true,"isoCode":"BRPEC","timeZoneDifference":-3.0,"netpasName":"Pecem"},"isDeleted":false,"distanceInMiles":1688,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8374},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305392456000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":68},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563099}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561496,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305759630000,"isBunkerCall":false,"updateTS":1357321346000,"berthingArrival":1305763230000,"inheritedVoyage":"","adjustmentTime":167,"timeInPort":840,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":784},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305817230000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8376},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":4.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12772,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":784},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"isDeleted":false,"distanceInMiles":3025,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":63},"pilottimeId":8376,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":784},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305813630000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":63},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561496,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563091}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561500,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306414808000,"isBunkerCall":false,"updateTS":1357321631000,"berthingArrival":1306418408000,"inheritedVoyage":"","adjustmentTime":14,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306486808000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8370},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12769,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"GBTILTC","isTBN":"false","name":"LONDON CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536,"codePort":null}],"name":"TILBURY","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":5,"pilotStations":[],"portId":232,"isRealPort":true,"displayName":"TILBURY","isDeleted":false,"isInService":true,"isoCode":"GBTIL","timeZoneDifference":0.0,"netpasName":"Tilbury"},"isDeleted":false,"distanceInMiles":1296,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"pilottimeId":8370,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":9,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306483208000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561500,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563094}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561504,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306756815000,"isBunkerCall":false,"updateTS":1357321631000,"berthingArrival":1306764015000,"inheritedVoyage":"","adjustmentTime":110,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306857615000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8375},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12770,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":134,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"pilottimeId":8375,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":12.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306850415000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561504,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563086}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561505,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306908015000,"isBunkerCall":false,"updateTS":1357321631000,"berthingArrival":1306911615000,"inheritedVoyage":"","adjustmentTime":1320,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306972815000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8372},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12777,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":200,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":340},"pilottimeId":8372,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":10.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306969215000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":340},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561505,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563089}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":561503,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307124015000,"isBunkerCall":false,"updateTS":1357321631000,"berthingArrival":1307138415000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307224815000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8368},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12774,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":251,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":240.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"pilottimeId":8368,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1307210415000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561503,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563093}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":561507,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":561506,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307646020000,"isBunkerCall":false,"updateTS":1357321631000,"berthingArrival":1307649620000,"inheritedVoyage":"","adjustmentTime":3,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":993,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307739620000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8370},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-4.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12767,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"distanceInMiles":4375,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8370},"sequence":14,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.1,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307736020000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561506,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563100}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":561493,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304316000000,"isBunkerCall":false,"updateTS":1357321631000,"berthingArrival":1308553247000,"inheritedVoyage":"","adjustmentTime":554,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8374},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12766,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8374},"sequence":15,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.4,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1357321631000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":68},"insertTS":1357321631000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561493,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":570120}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1307397630000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8365},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1356629986000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"isDeleted":false,"distanceInMiles":1282,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"pilottimeId":8365,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1356629986000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":13,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307368830000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1356629986000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1356629986000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1356629986000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561507,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":563097}],"dieselConsumption":null},"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307116898000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375904682000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":760182}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21832},"proformavesselscheduleterminalcallId":760182},"berthingId":220693,"vesselServiceAssignmentId":4156,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1378581900000,"berthingArrivalDate":1378610700000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"dailyVesselScheduleCell":{"liveArrivalDate":1378620000000,"customArrivalVoyage":"1311","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"1311","dailyvesselschedulecellcompactId":719341,"liveDepartureDate":1378677600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"1311","departureVoyage":"1311","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3322,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MAERSK LAVRAS","vesselId":8587,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3322,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCAL","dateOutService":null,"dateInService":1346371200000,"code":"08499","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9526928","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"SAEC3","isStandardMSCVoyageCoding":false,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"b22222","laneCode":"SAEC3","useWeeklyVoyageNumbers":true,"name":"NWC TO SAEC - STRING III","exceedingDateOffset":10080,"isScheduleDelayDisplayed":false,"serviceId":207,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"ND","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1370888005940,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378668300000,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"ESALGJC","isTBN":"false","name":"JUAN CARLOS 1","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":966,"codePort":null},{"codeMSC":"ESALIVE","isTBN":"false","name":"ISLA VERDE EXTERIOR","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":967,"codePort":null},{"codeMSC":"ESALGIV","isTBN":"false","name":"ISLA VERDE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":965,"codePort":null},{"codeMSC":"ESALG9Z","isTBN":"false","name":"ALGECIRAS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728,"codePort":null}],"name":"ALGECIRAS","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":171,"isRealPort":true,"displayName":"ALGECIRAS","isDeleted":false,"isInService":true,"isoCode":"ESALG","timeZoneDifference":1.0,"netpasName":"Algeciras"},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370805039113,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":710530,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309082447000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1309111247000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":16,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617446,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370805039113,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":713066}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":713066},"berthingId":220695,"vesselServiceAssignmentId":4728,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":null,"pilotArrivalDate":1379887200000,"berthingArrivalDate":1379916000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NG335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379815200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":673229,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG335R","departureVoyage":"NG335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1399,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC MELISSA","vesselId":2131,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1399,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSMS","dateOutService":null,"dateInService":998524800000,"code":"02234","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":304.0,"imoNumber":"9226918","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1370888005940,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370962802003,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":712699,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306966742000,"isBunkerCall":false,"updateTS":1374829912000,"berthingArrival":1306995542000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":29714,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1374829912000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1374829912000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":403966,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304402400000,"isBunkerCall":false,"updateTS":1350996139000,"berthingArrival":1305640801000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1348745924000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":251,"insertTS":1348745924000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1350996139000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":6095,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1350996139000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1350996139000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1350996155000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1350996155000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403966,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":404828}],"dieselConsumption":null},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370962802003,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":715255}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":715255},"berthingId":220716,"vesselServiceAssignmentId":3063,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"FIHELMT","isTBN":"false","name":"MULTILINK TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156,"codePort":null},{"codeMSC":"FIHELFO","isTBN":"false","name":"FINNSTEVE OY AB","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":155,"codePort":null}],"name":"HELSINKI","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":197,"isRealPort":true,"displayName":"HELSINKI","isDeleted":false,"isInService":true,"isoCode":"FIHEL","timeZoneDifference":1.0,"netpasName":"Helsinki"},"draftArrivalAFT":null,"pilotArrivalDate":1376978400000,"berthingArrivalDate":1377007200000,"operatorContainerMoves40":null,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377007200000,"customArrivalVoyage":"BB332R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB332R","dailyvesselschedulecellcompactId":675391,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB332R","departureVoyage":"BB332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC EYRA","vesselId":2721,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1334188800000,"dateInService":1076544000000,"code":"04302","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC EYRA","vesselId":8335,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSEY","dateOutService":null,"dateInService":1334275200000,"code":"08278","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":203.0,"imoNumber":"8201648","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"BAL2","isStandardMSCVoyageCoding":false,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ff6347","laneCode":"BALT2","useWeeklyVoyageNumbers":false,"name":"BALTIC LOOP 02","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":8,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"BB","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1370970370137,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371075606070,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":713904,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371075606070,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":716461}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":716461},"berthingId":220743,"vesselServiceAssignmentId":527,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":null,"pilotArrivalDate":1378303200000,"berthingArrivalDate":1378332000000,"operatorContainerMoves40":null,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378332000000,"customArrivalVoyage":"26E34","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"26E34","dailyvesselschedulecellcompactId":676594,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"26E34","departureVoyage":"26E34","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1265,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"OTTAWA EXPRESS","vesselId":5243,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1265,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCOX","dateOutService":null,"dateInService":1310688000000,"code":"07666","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":0.0,"imoNumber":"9165360","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371145699690,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377151200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370988025443,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":712859,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1317565659000,"isBunkerCall":false,"updateTS":1375450788000,"berthingArrival":1317594459000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1317709659000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":374699,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308628094000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1304460000000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":702,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"updateTS":1355927645000,"isMaster":true,"isDeleted":false,"insertTS":1349337870000,"isInService":true,"versionInfo":"NWC TO SAEC 1  04/10/12","version":3,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":374699,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":374697,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304589625000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1304596825000,"inheritedVoyage":"","adjustmentTime":403,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304676025000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5762},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3721,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1337255134000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":200,"insertTS":1337255134000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"pilottimeId":5762,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":30.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304668825000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374697,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375476}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374694,"averageVesselFuelConsumptionPerHour":3.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304751634000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1304762434000,"inheritedVoyage":"","adjustmentTime":13,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304859634000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5755},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3719,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1337255134000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":410,"insertTS":1337255134000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":5755,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":84.28,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304848834000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374694,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375478}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374695,"averageVesselFuelConsumptionPerHour":3.6,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304942414000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1304949614000,"inheritedVoyage":"","adjustmentTime":2,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305014414000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5759},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":190,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":null,"updateTS":1324376431533,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"PTSIEPS","isTBN":"false","name":"PSA SINES","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405,"codePort":null}],"name":"SINES","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":511,"isRealPort":true,"displayName":"SINES","isDeleted":false,"isInService":true,"isoCode":"PTSIE","timeZoneDifference":0.0,"netpasName":"Sines"},"isDeleted":false,"distanceInMiles":920,"insertTS":1324376431533,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":5759,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":187.12,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305007214000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374695,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375471}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374693,"averageVesselFuelConsumptionPerHour":3.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305198052000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1305201652000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305262852000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5765},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":191,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":null,"updateTS":1324376431533,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"BRRIOMR","isTBN":"false","name":"MULTI-RIO","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":64,"codePort":null},{"codeMSC":"BRRIOAA","isTBN":"false","name":"LIBRA TERMINAL RIO S/A","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1064,"codePort":null},{"codeMSC":"BRRIOAD","isTBN":"false","name":"ATLANTIS RIO TERMINAIS DE CONTAINERS LTDA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1351,"codePort":null}],"name":"RIO DE JANEIRO, RJ","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":791,"isRealPort":true,"displayName":"RIO DE JANEIRO","isDeleted":false,"isInService":true,"isoCode":"BRRIO","timeZoneDifference":-3.0,"netpasName":"Rio De Janeiro"},"isDeleted":false,"distanceInMiles":4177,"insertTS":1324376431533,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"pilottimeId":5765,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":801.4,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.2,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305259252000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374693,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375473}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374696,"averageVesselFuelConsumptionPerHour":4.25,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306126848000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1306134048000,"inheritedVoyage":"","adjustmentTime":82,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":791},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306206048000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5761},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":192,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":null,"updateTS":1324376431533,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":791},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"distanceInMiles":216,"insertTS":1324376431533,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":64},"pilottimeId":5761,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":791},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":48.32,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306198848000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":64},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374696,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375474}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374698,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306242055000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1306245655000,"inheritedVoyage":"","adjustmentTime":110,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306314055000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5763},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3720,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":27,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":null,"updateTS":1337255134000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"isDeleted":false,"distanceInMiles":886,"insertTS":1337255134000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":70},"pilottimeId":5763,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":136.31,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306310455000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":70},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374698,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375475}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374702,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306566008000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1306602008000,"inheritedVoyage":"","adjustmentTime":55,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306724408000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5764},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3727,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":27,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1337255134000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":70},"isDeleted":false,"distanceInMiles":313,"insertTS":1337255134000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":600.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":15},"pilottimeId":5764,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":52.17,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":12.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1306688408000,"pilotStation":{"?p":"true","pilotstationId":27,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":15},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375470}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374703,"averageVesselFuelConsumptionPerHour":3.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306821608000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1306825208000,"inheritedVoyage":"","adjustmentTime":53,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":70},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306893608000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5766},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2960,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332411755000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":70},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"distanceInMiles":488,"insertTS":1332411755000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":65},"pilottimeId":5766,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":70},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":9,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":92.02,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306890008000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":65},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374703,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375472}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374700,"averageVesselFuelConsumptionPerHour":1.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306990816000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1306998016000,"inheritedVoyage":"","adjustmentTime":750,"timeInPort":480,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307034016000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5757},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2958,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332411755000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"BRNAVPN","isTBN":"false","name":"PORTONAVE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":61,"codePort":null}],"name":"NAVEGANTES","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":66,"isRealPort":true,"displayName":"NAVEGANTES","isDeleted":false,"isInService":true,"isoCode":"BRNVT","timeZoneDifference":-6.0,"netpasName":null},"isDeleted":false,"distanceInMiles":95,"insertTS":1332411755000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"pilottimeId":5757,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":17.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":10.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307026816000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374700,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375480}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374704,"averageVesselFuelConsumptionPerHour":4.25,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307102416000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1307106016000,"inheritedVoyage":"","adjustmentTime":1272,"timeInPort":1500,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":66},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307199616000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5758},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":197,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":null,"updateTS":1324376431533,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":66},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"distanceInMiles":222,"insertTS":1324376431533,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":61},"pilottimeId":5758,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":66},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":62.9,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307196016000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":61},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374704,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375477}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374705,"averageVesselFuelConsumptionPerHour":2.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307340016000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1307343616000,"inheritedVoyage":"","adjustmentTime":66,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307433616000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5763},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":198,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":null,"updateTS":1324376431533,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"isDeleted":false,"distanceInMiles":181,"insertTS":1324376431533,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5763},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":29.77,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.2,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307430016000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":70},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375479}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":374701,"averageVesselFuelConsumptionPerHour":3.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307469648000,"isBunkerCall":false,"updateTS":1349337870000,"berthingArrival":1307480448000,"inheritedVoyage":"","adjustmentTime":12,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":702,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307548848000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5760},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":7.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3723,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":null,"updateTS":1337255134000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":5208,"insertTS":1337255134000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"pilottimeId":5760,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"isDeleted":false,"insertTS":1349337870000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":13,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":999.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.2,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307538048000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374701,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375482}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":374691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304575200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304546400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349337870000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349337870000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1349337870000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374699,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":375483}],"dieselConsumption":null},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1317680859000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1370988025443,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":715415}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":715415},"berthingId":220747,"vesselServiceAssignmentId":3494,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":null,"pilotArrivalDate":1377007200000,"berthingArrivalDate":1377036000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NA330R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377122400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":675551,"liveDepartureDate":1377194400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA330R","departureVoyage":"NA334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1478,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371145699690,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377122400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA337R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370988025443,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":712872,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1321799271000,"isBunkerCall":false,"updateTS":1375450788000,"berthingArrival":1321828071000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":30045,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1375450788000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1375450788000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370988025443,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":715428}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":715428},"berthingId":220748,"vesselServiceAssignmentId":3494,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":null,"pilotArrivalDate":1381240800000,"berthingArrivalDate":1381269600000,"operatorContainerMoves40":null,"customArrivalVoyage":"NA337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381269600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":675564,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA337R","departureVoyage":"NA337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1478,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371145699690,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373628357000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371021907443,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":713059,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305698441000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":382107,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":1349680872000,"berthingArrival":1305698441000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1332178309000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":251,"insertTS":1332178309000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":5846,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1349680872000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1349680872000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1349680872000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382107,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382879}],"dieselConsumption":null},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371021907443,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":715615}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":715615},"berthingId":220750,"vesselServiceAssignmentId":2933,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"DEKELCT","isTBN":"false","name":"KIEL CANAL TRANSIT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191,"codePort":null}],"name":"KIEL","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[{"isDeleted":false,"isDefault":false,"name":"Kiel Canal (south)","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":46,"netpasName":"Ostermoor"},{"isDeleted":false,"isDefault":true,"name":"Kiel Canal (North)","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":47,"netpasName":"Laboe"}],"portId":750,"isRealPort":false,"displayName":"KIEL","isDeleted":false,"isInService":true,"isoCode":"DEKEL","timeZoneDifference":1.0,"netpasName":"Kiel"},"draftArrivalAFT":0.0,"pilotArrivalDate":1376870400000,"berthingArrivalDate":1376899200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377007200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":675751,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH332R","departureVoyage":"BH332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"LANGENESS","vesselId":7170,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1179619140000,"dateInService":1171584000000,"code":"05583","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC VILNIUS","vesselId":8203,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVVS","dateOutService":1211932740000,"dateInService":1179619200000,"code":"05706","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"LANGENESS","vesselId":8204,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"LANG","dateOutService":null,"dateInService":1332547200000,"code":"08166","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"LANGENESS","vesselId":8248,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1332547140000,"dateInService":1331683200000,"code":"08203","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":161.4,"imoNumber":"9301134","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"BAL8","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ff6347","laneCode":"BALT8","useWeeklyVoyageNumbers":true,"name":"BALTIC LOOP 08","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":14,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"BH","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1371145699690,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1375869510000,"noonPositionTelex":null,"pilotDepartureDate":1377982800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NQ335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1375869508000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375869508000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":756315,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306357408000,"isBunkerCall":false,"updateTS":1375869508000,"berthingArrival":1306386208000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1306501408000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":21027,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":41.54,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306472608000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375869508000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":759480}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":759480},"berthingId":220757,"vesselServiceAssignmentId":4927,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1377838800000,"berthingArrivalDate":1377867600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NQ335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377867600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":718640,"liveDepartureDate":1377954000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NQ335A","departureVoyage":"NQ335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1989,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CSAV LARAQUETE","vesselId":5627,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1989,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVLR","dateOutService":null,"dateInService":1322352000000,"code":"07947","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":0.0,"imoNumber":"9477311","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1371145699690,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377954000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376764200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NU333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371444033297,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":716146,"averageVesselFuelConsumptionPerHour":2.8,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304627431000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304656231000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304793031000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1059,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":246168,"averageVesselFuelConsumptionPerHour":2.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304627431000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1304656231000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":519,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"updateTS":1355477782000,"isMaster":true,"isDeleted":false,"insertTS":1345557304000,"isInService":true,"versionInfo":"NWC to USA North Atlantic ( With First Call NYC A )","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":246166,"averageVesselFuelConsumptionPerHour":3.15,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307231823000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1304308800000,"inheritedVoyage":"","adjustmentTime":28,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":420,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304427600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3575},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":796,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1326380792747,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"distanceInMiles":267,"insertTS":1326380792747,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":3575,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":48.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.25,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304416800000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246166,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246578}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":246169,"averageVesselFuelConsumptionPerHour":3.15,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304503241000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1304510441000,"inheritedVoyage":"","adjustmentTime":111,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304604041000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3581},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":4738,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":null,"updateTS":1341425180267,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":62,"insertTS":1341425180267,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"pilottimeId":3581,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":11.49,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304596841000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246169,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246575}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":246168,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":246170,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304829003000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1304839803000,"inheritedVoyage":"","adjustmentTime":7,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304922603000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3584},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":4741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":42,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":null,"updateTS":1341426237913,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USNYCNC","isTBN":"false","name":"PORT NEWARK CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":553,"codePort":null},{"codeMSC":"USNYCMT","isTBN":"false","name":"MAHER TERMINALS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":552,"codePort":null},{"codeMSC":"USNYCBK","isTBN":"false","name":"APM TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1325,"codePort":null}],"name":"NEW YORK, NY","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":3,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Ambrose ","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":42,"netpasName":"Ambrose Tower"}],"portId":618,"isRealPort":true,"displayName":"NEW YORK","isDeleted":false,"isInService":true,"isoCode":"USNYC","timeZoneDifference":-5.0,"netpasName":"New York"},"isDeleted":false,"distanceInMiles":3085,"insertTS":1341426237913,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"pilottimeId":3584,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":599.86,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304911803000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246170,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246571}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":246167,"averageVesselFuelConsumptionPerHour":2.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305518423000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1305525623000,"inheritedVoyage":"","adjustmentTime":85,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":618},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305597623000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":552},"pilottimeId":3583,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":618},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":4740,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":42,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1341426237913,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":618},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USBOSPW","isTBN":"false","name":"CONLEY TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":538,"codePort":null}],"name":"BOSTON, MA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":601,"isRealPort":true,"displayName":"BOSTON","isDeleted":false,"isInService":true,"isoCode":"USBOS","timeZoneDifference":-5.0,"netpasName":"Boston"},"isDeleted":false,"distanceInMiles":276,"insertTS":1341426237913,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":552},"pilottimeId":3588,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":618},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":55.2,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":11.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305590423000,"pilotStation":{"?p":"true","pilotstationId":42,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":552},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246167,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246569}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":246172,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305693051000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1305703851000,"inheritedVoyage":"","adjustmentTime":474,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":601},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305779451000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":538},"pilottimeId":3577,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":601},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":4742,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":29,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":null,"updateTS":1341426237913,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":601},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USPHLPA","isTBN":"false","name":"PACKER AVENUE MARINE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":561,"codePort":null}],"name":"PHILADELPHIA, PA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Cape Henlopen Pilot Station","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":29,"netpasName":"Cape Henlopen"}],"portId":623,"isRealPort":true,"displayName":"PHILADELPHIA","isDeleted":false,"isInService":true,"isoCode":"USPHL","timeZoneDifference":-5.0,"netpasName":"Philadelphia"},"isDeleted":false,"distanceInMiles":376,"insertTS":1341426237913,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":538},"pilottimeId":3580,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":601},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":78.96,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":10.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305768651000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":538},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246172,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246572}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":246171,"averageVesselFuelConsumptionPerHour":2.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305943251000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1305964851000,"inheritedVoyage":"","adjustmentTime":5,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":623},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306051251000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":360.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":561},"pilottimeId":3576,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":623},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1210,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":30,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":29,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1326535571870,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":623},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USBALPP","isTBN":"false","name":"SEAGIRT MARINE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":537,"codePort":null}],"name":"BALTIMORE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Cape Henry Pilot Station","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":30,"netpasName":"Cape Henry"}],"portId":600,"isRealPort":true,"displayName":"BALTIMORE","isDeleted":false,"isInService":true,"isoCode":"USBAL","timeZoneDifference":-5.0,"netpasName":"Baltimore (US)"},"isDeleted":false,"distanceInMiles":131,"insertTS":1326535571870,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":360.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":561},"pilottimeId":3585,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":623},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":26.2,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":11.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306029651000,"pilotStation":{"?p":"true","pilotstationId":29,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":561},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246171,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246568}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":246173,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306094423000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1306119623000,"inheritedVoyage":"","adjustmentTime":368,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":600},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306209623000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3586},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1211,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":30,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1326535571870,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":600},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USORFPT","isTBN":"false","name":"PORTSMOUTH MARINE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":556,"codePort":null},{"codeMSC":"USORFIT","isTBN":"false","name":"NORFOLK INTERNATIONAL TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":555,"codePort":null},{"codeMSC":"USORFTV","isTBN":"false","name":"APM TERMINALS OF VIRGINIA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":554,"codePort":null}],"name":"NORFOLK (VIRGINIA)","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":620,"isRealPort":true,"displayName":"NORFOLK","isDeleted":false,"isInService":true,"isoCode":"USORF","timeZoneDifference":-5.0,"netpasName":"Norfolk"},"isDeleted":false,"distanceInMiles":28,"insertTS":1326535571870,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":420.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":537},"pilottimeId":3586,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":600},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":3.73,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306184423000,"pilotStation":{"?p":"true","pilotstationId":30,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":537},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246173,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246570}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":246175,"averageVesselFuelConsumptionPerHour":2.55,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306238423000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1306245623000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":620},"isDeleted":false,"bufferTime":1440,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306324823000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":554},"pilottimeId":3587,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":620},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1213,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":42,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":null,"updateTS":1326535571870,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":620},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":618},"isDeleted":false,"distanceInMiles":260,"insertTS":1326535571870,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":554},"pilottimeId":3574,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":620},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":44.2,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306317623000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":554},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246175,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246573}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":246174,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306474223000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1306485023000,"inheritedVoyage":"","adjustmentTime":363,"timeInPort":1260,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":618},"isDeleted":false,"bufferTime":600,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306571423000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":552},"pilottimeId":3582,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":618},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1200,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":42,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1326535571870,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":618},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":3356,"insertTS":1326535571870,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":552},"pilottimeId":3579,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":618},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":652.56,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306560623000,"pilotStation":{"?p":"true","pilotstationId":42,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":552},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246174,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246577}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":246164,"averageVesselFuelConsumptionPerHour":3.15,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304298000000,"isBunkerCall":false,"updateTS":1345557304000,"berthingArrival":1307332803000,"inheritedVoyage":"","adjustmentTime":28,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3575},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":796,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3575},"sequence":11,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":48.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.25,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246164,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246576}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304793031000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1059,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1326467348417,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":161,"insertTS":1326467348417,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":3578,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1345557304000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304764231000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1345557304000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345557304000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1345557304000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246168,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":246574}],"dieselConsumption":null},"speed":15.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304764231000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371444033297,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":718719}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":718719},"berthingId":220761,"vesselServiceAssignmentId":4607,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"GBFXTTT","isTBN":"false","name":"TRINITY CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526,"codePort":null},{"codeMSC":"GBFXTAG","isTBN":"false","name":"FELIXSTOWE BERTHS 8+9","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":995,"codePort":null}],"name":"FELIXSTOWE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":671,"isRealPort":true,"displayName":"FELIXSTOWE","isDeleted":false,"isInService":true,"isoCode":"GBFXT","timeZoneDifference":0.0,"netpasName":"Felixstowe"},"draftArrivalAFT":null,"pilotArrivalDate":1376598600000,"berthingArrivalDate":1376627400000,"operatorContainerMoves40":null,"customArrivalVoyage":"NU333A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376620200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":678809,"liveDepartureDate":1376728200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NU333A","departureVoyage":"NU333A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1195,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC UGANDA","vesselId":3980,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1195,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MUGA","dateOutService":null,"dateInService":1194048000000,"code":"05890","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":294.1,"imoNumber":"9141285","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"NWCUSA","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":1319925600000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"cd5c5c","laneCode":"NWUSA","useWeeklyVoyageNumbers":true,"name":"NWC TO USA - NORTH ATLANTIC","exceedingDateOffset":10080,"isScheduleDelayDisplayed":false,"serviceId":70,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NU","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":false},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371461453270,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376735400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371395706517,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":716087,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304834400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305468017000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":382102,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304834400000,"isBunkerCall":false,"updateTS":1349680634000,"berthingArrival":1305468017000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1332176402000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"isDeleted":false,"distanceInMiles":587,"insertTS":1332176402000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680634000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":5842,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1349680634000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1349680634000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680634000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1349680634000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382102,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382870}],"dieselConsumption":null},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371395706517,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":718660}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":718660},"berthingId":220767,"vesselServiceAssignmentId":3065,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"NOKRSTO","isTBN":"false","name":"SCANDINAVIAN SHIPPING KRISTIANSAND","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373,"codePort":null}],"name":"KRISTIANSAND","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":447,"isRealPort":true,"displayName":"KRISTIANSAND","isDeleted":false,"isInService":true,"isoCode":"NOKRS","timeZoneDifference":1.0,"netpasName":"Kristiansand"},"draftArrivalAFT":null,"pilotArrivalDate":1376780400000,"berthingArrivalDate":1376809200000,"operatorContainerMoves40":null,"customArrivalVoyage":"BF333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376827200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":678750,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF333R","departureVoyage":"BF333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"LEYLA KALKAVAN","vesselId":8565,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"WYKA","dateOutService":null,"dateInService":1044489600000,"code":"03096","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9236286","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"BAL6","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ff6347","laneCode":"BALT6","useWeeklyVoyageNumbers":true,"name":"BALTIC LOOP 06","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":12,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"BF","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371461453270,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"NOOSLCT","isTBN":"false","name":"OCT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377,"codePort":null},{"codeMSC":"NOOSLNR","isTBN":"false","name":"NORSTEVE FILIPSTAD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":376,"codePort":null}],"name":"OSLO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":5,"pilotStations":[],"portId":451,"isRealPort":true,"displayName":"OSLO","isDeleted":false,"isInService":true,"isoCode":"NOOSL","timeZoneDifference":1.0,"netpasName":"Oslo"},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371424508597,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":716124,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304863200000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306101655000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382124,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371424508597,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":718697}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":718697},"berthingId":220769,"vesselServiceAssignmentId":4494,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":null,"pilotArrivalDate":1377410400000,"berthingArrivalDate":1377439200000,"operatorContainerMoves40":null,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377432000000,"customArrivalVoyage":"BJ333R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ333R","dailyvesselschedulecellcompactId":678787,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ333R","departureVoyage":"BJ333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3133,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"VALENTINA","vesselId":8316,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3133,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVAL","dateOutService":null,"dateInService":1336089600000,"code":"08260","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":175.57,"imoNumber":"9344722","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371461453270,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1373555183000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG330R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"deleteUser":null,"updateTS":1371222124000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371222124000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":715529,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309096589000,"isBunkerCall":false,"updateTS":1371222124000,"berthingArrival":1309125389000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Gianmarco SIREI","userId":17737},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":16,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617446,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371222124000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":718103}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"proformavesselscheduleterminalcallId":718103},"berthingId":220776,"vesselServiceAssignmentId":5605,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":0.0,"pilotArrivalDate":1376820000000,"berthingArrivalDate":1376848800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NG330R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376848800000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":678209,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG330R","departureVoyage":"NG330R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3594,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC DISCOVERY","vesselId":8998,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3594,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVDC","dateOutService":1301529540000,"dateInService":1240704000000,"code":"06576","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC DYMPHNA","vesselId":8999,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3594,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MDYM","dateOutService":null,"dateInService":1360800000000,"code":"08778","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9110391","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1371461453270,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371447310533,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":716158,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304884854000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304913654000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":651686,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304884854000,"isBunkerCall":false,"updateTS":1364910121000,"berthingArrival":1304913654000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"deleteUser":null,"pilotStationFrom":null,"updateTS":1364910121000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":611,"insertTS":1364910121000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"deleteUser":null,"updateTS":1364910121000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":12267,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1364910121000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221}},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1364910121000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"deleteUser":null,"updateTS":1364910121000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1364910121000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Raffaele ERCOLANO","userId":221},"proformavesselscheduleterminalcallId":653674}],"dieselConsumption":null},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371447310533,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":718731}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":718731},"berthingId":220782,"vesselServiceAssignmentId":5327,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1376856000000,"berthingArrivalDate":1376884800000,"operatorContainerMoves40":null,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376884800000,"customArrivalVoyage":"RB332R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB332R","dailyvesselschedulecellcompactId":678821,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB332R","departureVoyage":"RB332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"JOHN RICKMERS","vesselId":6904,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"WJRI","dateOutService":1326153540000,"dateInService":1325203200000,"code":"07999","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"JOHN RICKMERS","vesselId":8805,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MJRK","dateOutService":null,"dateInService":1351641600000,"code":"08588","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":196.9,"imoNumber":"9300154","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"LEHLIV","isStandardMSCVoyageCoding":false,"useVoyageLinking":true,"isDeleted":false,"startDate":1320501600000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"0000cd","laneCode":"LEHLV","useWeeklyVoyageNumbers":true,"name":"ANTWERP & LE HAVRE TO/FROM LIVERPOOL - FEEDER SERVICE","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":47,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"RB","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371461453270,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371282617657,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":715879,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306533630000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306562430000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681491,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371282617657,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":718449}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":718449},"berthingId":220789,"vesselServiceAssignmentId":4913,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1377900000000,"berthingArrivalDate":1377928800000,"operatorContainerMoves40":null,"customArrivalVoyage":"NP334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377928800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":678542,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP334R","departureVoyage":"NP334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1042,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"ATHENS TRADER","vesselId":5129,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1042,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MATR","dateOutService":null,"dateInService":1303516800000,"code":"07568","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC BELEM","vesselId":5668,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1042,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MBLM","dateOutService":1270166400000,"dateInService":1031529600000,"code":"02851","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":196.0,"imoNumber":"9070175","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371461453270,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376712000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NZ332A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371237923237,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":715671,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305165602000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305198002000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305345602000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13480},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":701517,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305165602000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1305198002000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":{"proformavesselscheduleId":1408,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"updateTS":1370007047000,"isMaster":true,"isDeleted":false,"insertTS":1370007047000,"isInService":true,"versionInfo":"NWC-S.Africa","version":11,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":701519,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309533525000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1304704800000,"inheritedVoyage":"","adjustmentTime":58,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":434,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304776800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13468},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3948,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":null,"updateTS":1337848904000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":93,"insertTS":1337848904000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":612},"pilottimeId":13468,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":20.34,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304769600000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":612},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701519,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704016}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701513,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304823645000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1304830845000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":726,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304910045000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13471},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3944,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":null,"updateTS":1337848904000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"distanceInMiles":280,"insertTS":1337848904000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"pilottimeId":13471,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":2,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":61.25,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304902845000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701513,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704017}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701520,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305018045000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1305039645000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305118845000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":360.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"pilottimeId":13475,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":true,"serviceportdistanceId":26823,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1370007047000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":264,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":360.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"pilottimeId":13470,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":58.52,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":20.3,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305097245000,"pilotStation":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701520,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704015}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":701517,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":701516,"averageVesselFuelConsumptionPerHour":4.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305385202000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1305396002000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":24,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305464402000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":13476,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":26814,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":null,"updateTS":1370006162000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"distanceInMiles":920,"insertTS":1370006162000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":13469,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":241.5,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305453602000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701516,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704020}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701515,"averageVesselFuelConsumptionPerHour":4.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305669602000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1305673202000,"inheritedVoyage":"","adjustmentTime":14,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305734402000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13474},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":26812,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":null,"updateTS":1370006162000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ESLPASA","isTBN":"false","name":"SANAPU","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":453,"codePort":null},{"codeMSC":"LPAES","isTBN":"false","name":"OPCSA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452,"codePort":null},{"codeMSC":"ESLPALL","isTBN":"false","name":"LA LUZ","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":451,"codePort":null}],"name":"LAS PALMAS, GRAN CANARIA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":181,"isRealPort":true,"displayName":"LAS PALMAS, GRAN CANARIA","isDeleted":false,"isInService":true,"isoCode":"ESLPA","timeZoneDifference":0.0,"netpasName":"Las Palmas"},"isDeleted":false,"distanceInMiles":679,"insertTS":1370006162000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"pilottimeId":13474,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":164.84,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.3,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305730802000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701515,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704022}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701518,"averageVesselFuelConsumptionPerHour":4.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305874856000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1305878456000,"inheritedVoyage":"","adjustmentTime":29,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305946856000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13473},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"isOverride":true,"serviceportdistanceId":26822,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":null,"updateTS":1370007047000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ZACPTAF","isTBN":"false","name":"MULTI PURPOSE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":987,"codePort":null},{"codeMSC":"ZACPTFP","isTBN":"false","name":"FRESH PRODUCE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":432,"codePort":null},{"codeMSC":"ZACPTCT","isTBN":"false","name":"CAPE TOWN CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":431,"codePort":null}],"name":"CAPE TOWN","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":660,"isRealPort":true,"displayName":"CAPE TOWN","isDeleted":false,"isInService":true,"isoCode":"ZACPT","timeZoneDifference":2.0,"netpasName":"Cape Town"},"isDeleted":false,"distanceInMiles":4412,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"pilottimeId":13473,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":1077.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.2,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305943256000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701518,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704012}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701522,"averageVesselFuelConsumptionPerHour":4.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306879238000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1306886438000,"inheritedVoyage":"","adjustmentTime":59,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":660},"isDeleted":false,"bufferTime":354,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307023238000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13481},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":true,"serviceportdistanceId":26824,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":null,"updateTS":1370007047000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":660},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ZAZBACT","isTBN":"false","name":"NGQURA CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":433,"codePort":null}],"name":"COEGA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":665,"isRealPort":true,"displayName":"COEGA","isDeleted":false,"isInService":true,"isoCode":"ZAZBA","timeZoneDifference":1.0,"netpasName":null},"isDeleted":false,"distanceInMiles":444,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":431},"pilottimeId":13481,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":660},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":109.69,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307016038000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":431},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701522,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704011}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701523,"averageVesselFuelConsumptionPerHour":4.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307138442000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1307142042000,"inheritedVoyage":"","adjustmentTime":60,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":665},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307275242000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13477},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":true,"serviceportdistanceId":26820,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":null,"updateTS":1370007047000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":665},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ZADURPT","isTBN":"false","name":"POINT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":437,"codePort":null},{"codeMSC":"ZADURPI","isTBN":"false","name":"PIER 1 CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":436,"codePort":null},{"codeMSC":"ZADURMY","isTBN":"false","name":"MAYDON WHARF TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":435,"codePort":null},{"codeMSC":"ZADURCT","isTBN":"false","name":"DURBAN CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":434,"codePort":null}],"name":"DURBAN","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":778,"isRealPort":true,"displayName":"DURBAN","isDeleted":false,"isInService":true,"isoCode":"ZADUR","timeZoneDifference":2.0,"netpasName":"Durban"},"isDeleted":false,"distanceInMiles":388,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":433},"pilottimeId":13477,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":665},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":9,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":92.38,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.64,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307271642000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":433},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701523,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704019}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701524,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307354425000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1307361625000,"inheritedVoyage":"","adjustmentTime":15,"timeInPort":5040,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":778},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307671225000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13472},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":true,"serviceportdistanceId":26821,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":null,"updateTS":1370007047000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":665},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":778},"isDeleted":false,"distanceInMiles":388,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":434},"pilottimeId":13472,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":778},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":84.88,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1307664025000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":434},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701524,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704018}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701525,"averageVesselFuelConsumptionPerHour":4.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307755825000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1307759425000,"inheritedVoyage":"","adjustmentTime":7,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":665},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307849425000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13478},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26824,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":433},"pilottimeId":13478,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":665},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":11,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":109.69,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307845825000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":433},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701525,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704021}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701514,"averageVesselFuelConsumptionPerHour":3.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307946629000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1307953829000,"inheritedVoyage":"","adjustmentTime":81,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":660},"isDeleted":false,"bufferTime":300,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308069029000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13481},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26822,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13481},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":1016.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308061829000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":431},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701514,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704023}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":701521,"averageVesselFuelConsumptionPerHour":3.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309047307000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1309050907000,"inheritedVoyage":"","adjustmentTime":78,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1309162507000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13473},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3945,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":null,"updateTS":1337848904000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":1717,"insertTS":1337848904000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13473},"sequence":13,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":395.43,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309158907000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701521,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704024}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":701512,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309536045000,"isBunkerCall":false,"updateTS":1370007047000,"berthingArrival":1309543245000,"inheritedVoyage":"","adjustmentTime":58,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13468},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3948,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13468},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":20.34,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":612},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701512,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704014}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1305345602000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":540.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":13479,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":true,"serviceportdistanceId":26819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1370006162000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":159,"insertTS":1370006162000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"pilotOnOffBoard":540.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":13480,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1370007047000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305313202000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1370007047000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1370007047000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1370007047000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701517,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":704013}],"dieselConsumption":null},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305313202000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371237923237,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":718239}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":718239},"berthingId":220792,"vesselServiceAssignmentId":5483,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"DEHAMUK","isTBN":"false","name":"UNIKAI","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":190,"codePort":null},{"codeMSC":"DEHAMLU","isTBN":"false","name":"LZ UNIKAI GMBH","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":188,"codePort":null},{"codeMSC":"DEHAMTT","isTBN":"false","name":"HHLA CTT TOLLERORT CONTAINER-TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":189,"codePort":null},{"codeMSC":"DEHAMAP","isTBN":"false","name":"HHLA CONTAINER TERMINAL BURCHARDKAI","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1012,"codePort":null},{"codeMSC":"DEHAMEU","isTBN":"false","name":"EUROGATE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187,"codePort":null}],"name":"HAMBURG","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":7,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Elbe pilot station","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":5,"netpasName":"Elbe pilot station (Hamburg)"}],"portId":749,"isRealPort":true,"displayName":"HAMBURG","isDeleted":false,"isInService":true,"isoCode":"DEHAM","timeZoneDifference":1.0,"netpasName":"Hamburg"},"draftArrivalAFT":null,"pilotArrivalDate":1376532000000,"berthingArrivalDate":1376564400000,"operatorContainerMoves40":null,"customArrivalVoyage":"NZ332A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376772000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":678336,"liveDepartureDate":1376887200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NZ332A","departureVoyage":"NZ332A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1498,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC VIVIANA","vesselId":2209,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1498,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSVV","dateOutService":1318809540000,"dateInService":1010016000000,"code":"02487","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC METHONI","vesselId":5509,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1498,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"METH","dateOutService":null,"dateInService":1318809600000,"code":"07868","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":303.9,"imoNumber":"9256755","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"NWCSAF","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":1323076920000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"7fff00","laneCode":"NWSAF","useWeeklyVoyageNumbers":true,"name":"NWC TO SOUTH AFRICA","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":69,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NZ","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371461453270,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376679600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376978400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NC333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371539103690,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":717679,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304843432000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304872232000,"inheritedVoyage":"","adjustmentTime":97,"timeInPort":1770,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007232000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2673,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":52229,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304843432000,"isBunkerCall":false,"updateTS":1332526578000,"berthingArrival":1304872232000,"inheritedVoyage":"","adjustmentTime":97,"timeInPort":1770,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":{"proformavesselscheduleId":230,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"deleteUser":null,"updateTS":1355477940000,"isMaster":true,"isDeleted":false,"insertTS":1331721920000,"isInService":true,"versionInfo":"NWC to Greece & Turkey - Aegean","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":52224,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306785437000,"isBunkerCall":false,"updateTS":1335608191000,"berthingArrival":1304406000000,"inheritedVoyage":"","adjustmentTime":442,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":230,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304499600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":263},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3555,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"deleteUser":null,"pilotStationFrom":null,"updateTS":1335608191000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"distanceInMiles":280,"insertTS":1335608191000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1331143730000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"pilottimeId":263,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"insertTS":1323873872000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304492400000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1331721920000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"insertTS":1331721920000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52224,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":49908}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":52226,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304586032000,"isBunkerCall":false,"updateTS":1332526578000,"berthingArrival":1304600432000,"inheritedVoyage":"","adjustmentTime":482,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":230,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304679632000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":502},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2677,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1331721920000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":213,"insertTS":1331721920000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1331143730000,"pilotOnOffBoard":240.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"pilottimeId":502,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"insertTS":1326816106000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304665232000,"pilotStation":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1331721920000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"insertTS":1331721920000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52226,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":49909}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":52225,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304751631000,"isBunkerCall":false,"updateTS":1332526578000,"berthingArrival":1304758831000,"inheritedVoyage":"","adjustmentTime":28,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":230,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304830831000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":262},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2674,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1331721920000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":54,"insertTS":1331721920000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1331143730000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"pilottimeId":262,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1323873872000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304823631000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1331721920000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"insertTS":1331721920000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52225,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":49911}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":52229,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":52228,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305612052000,"isBunkerCall":false,"updateTS":1335608191000,"berthingArrival":1305615652000,"inheritedVoyage":"","adjustmentTime":95,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":230,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305705652000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":386},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2675,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331721920000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"GRSKGTP","isTBN":"false","name":"THESSALONIKI PORT AUTHORITY SA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":199,"codePort":null}],"name":"THESSALONIKI","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":253,"isRealPort":true,"displayName":"THESSALONIKI","isDeleted":false,"isInService":true,"isoCode":"GRSKG","timeZoneDifference":2.0,"netpasName":"Thessaloniki"},"isDeleted":false,"distanceInMiles":271,"insertTS":1331721920000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1324401010237,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"pilottimeId":386,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"isDeleted":false,"insertTS":1324401010237,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.4,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305702052000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1331721920000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"insertTS":1331721920000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52228,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":49915}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":52227,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305756021000,"isBunkerCall":false,"updateTS":1335608191000,"berthingArrival":1305759621000,"inheritedVoyage":"","adjustmentTime":48,"timeInPort":1860,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":253},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":230,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305874821000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":921},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2672,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331721920000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":253},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"TRIZMIP","isTBN":"false","name":"IZMIR PORT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":510,"codePort":null}],"name":"IZMIR","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":581,"isRealPort":true,"displayName":"IZMIR","isDeleted":false,"isInService":true,"isoCode":"TRIZM","timeZoneDifference":2.0,"netpasName":"Izmir"},"isDeleted":false,"distanceInMiles":259,"insertTS":1331721920000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":199},"pilottimeId":921,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":253},"isDeleted":false,"insertTS":1331721920000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.5,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305871221000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1331721920000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":199},"insertTS":1331721920000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52227,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":49913}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":52223,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305925221000,"isBunkerCall":false,"updateTS":1332526578000,"berthingArrival":1305928821000,"inheritedVoyage":"","adjustmentTime":48,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":581},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":230,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306105221000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":389},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2676,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331721920000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":581},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"isDeleted":false,"distanceInMiles":208,"insertTS":1331721920000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1324401010237,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":510},"pilottimeId":389,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":581},"isDeleted":false,"insertTS":1324401010237,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.4,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306101621000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1331721920000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":510},"insertTS":1331721920000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52223,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":49916}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":52222,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306143037000,"isBunkerCall":false,"updateTS":1332526578000,"berthingArrival":1306146637000,"inheritedVoyage":"","adjustmentTime":3,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"isDeleted":false,"bufferTime":600,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":230,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306236637000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":386},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-2.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2679,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331721920000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"distanceInMiles":2762,"insertTS":1331721920000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":386},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306233037000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1331721920000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"insertTS":1331721920000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52222,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":49914}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":52221,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304398800000,"isBunkerCall":false,"updateTS":1335608191000,"berthingArrival":1306825217000,"inheritedVoyage":"","adjustmentTime":442,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":263},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3555,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":263},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1331721920000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"insertTS":1331721920000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52221,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":49910}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1305007232000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2673,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1331721920000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"isDeleted":false,"distanceInMiles":2761,"insertTS":1331721920000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978432000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1331721920000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331721920000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1331721920000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52229,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":49912}],"dieselConsumption":null},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978432000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371539103690,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":720268}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":720268},"berthingId":220794,"vesselServiceAssignmentId":5434,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":null,"pilotArrivalDate":1376814600000,"berthingArrivalDate":1376843400000,"operatorContainerMoves40":null,"customArrivalVoyage":"NC333A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376861400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":680341,"liveDepartureDate":1376949600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NC333A","departureVoyage":"NC333A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":890,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MAJESTIC","vesselId":4859,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":890,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MAJE","dateOutService":1304467140000,"dateInService":1283817600000,"code":"07278","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC SARISKA","vesselId":5097,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":890,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSKK","dateOutService":null,"dateInService":1304467200000,"code":"07536","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":294.1,"imoNumber":"8715857","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"PIR","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ff0000","laneCode":"AEGE","useWeeklyVoyageNumbers":true,"name":"NWC TO/FROM GREECE & TURKEY - AEGEAN SERVICE","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":1,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NC","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371578555783,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376949600000,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"GRPIRPP","isTBN":"false","name":"PIRAEUS PORT AUTHORITY SA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":197,"codePort":null},{"codeMSC":"GRPCTSA","isTBN":"false","name":"PIRAEUS CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056,"codePort":null}],"name":"PIRAEUS","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":250,"isRealPort":true,"displayName":"PIRAEUS","isDeleted":false,"isInService":true,"isoCode":"GRPIR","timeZoneDifference":2.0,"netpasName":"Piraeus"},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371564303547,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":717955,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306966742000,"isBunkerCall":false,"updateTS":1375701498000,"berthingArrival":1306995542000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":30113,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1375701498000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1375701498000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403966,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371564303547,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":720551}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":720551},"berthingId":220803,"vesselServiceAssignmentId":3064,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":null,"pilotArrivalDate":1377583200000,"berthingArrivalDate":1377612000000,"operatorContainerMoves40":null,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377612000000,"customArrivalVoyage":"BB333R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB333R","dailyvesselschedulecellcompactId":680617,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB333R","departureVoyage":"BB333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":768,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC Malin","vesselId":2719,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":768,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1337558400000,"dateInService":1076284800000,"code":"04300","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC MALIN","vesselId":8419,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":768,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MALI","dateOutService":null,"dateInService":1337644800000,"code":"08352","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":203.0,"imoNumber":"8201636","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1371578555783,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373621319000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371512404750,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":717394,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304344800000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305583245000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":439877,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304344800000,"isBunkerCall":false,"updateTS":1352898257000,"berthingArrival":1305583245000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1349164455000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"isDeleted":false,"distanceInMiles":243,"insertTS":1349164455000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":6664,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1352898257000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1352898257000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1352898257000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439877,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":441172}],"dieselConsumption":null},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371512404750,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":719968}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":719968},"berthingId":220807,"vesselServiceAssignmentId":5329,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1377468000000,"berthingArrivalDate":1377496800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377626400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":680056,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC333R","departureVoyage":"BC333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1801,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"HELUAN","vesselId":4957,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1801,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"HELU","dateOutService":null,"dateInService":1290729600000,"code":"07387","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"HELUAN","vesselId":6940,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1801,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1262822400000,"dateInService":1261612800000,"code":"06876","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":160.7,"imoNumber":"9358905","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"BAL3","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ff6347","laneCode":"BALT3","useWeeklyVoyageNumbers":true,"name":"BALTIC LOOP 03","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":9,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"BC","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1371578555783,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"GBTEEPT","isTBN":"false","name":"PD TEESPORT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534,"codePort":null}],"name":"TEESPORT","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":230,"isRealPort":true,"displayName":"TEESPORT","isDeleted":false,"isInService":true,"isoCode":"GBTEE","timeZoneDifference":0.0,"netpasName":"Teesport"},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"operatorContainerMoves20":0,"updateTS":1375981500000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"deleteUser":null,"updateTS":1375981499000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375981499000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":758024,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308948875000,"isBunkerCall":false,"updateTS":1375981499000,"berthingArrival":1308977675000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Faris SIDDIQUE","userId":17735},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":15,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617446,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375981499000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":761185}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"proformavesselscheduleterminalcallId":761185},"berthingId":220813,"vesselServiceAssignmentId":5615,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":0.0,"pilotArrivalDate":1380448860000,"berthingArrivalDate":1380477660000,"operatorContainerMoves40":0,"customArrivalVoyage":"NG336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380420000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":720253,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG336R","departureVoyage":"NG336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1382,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CMA CGM VOLTAIRE","vesselId":5517,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1382,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCVT","dateOutService":1341014340000,"dateInService":1322179200000,"code":"07876","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"BUXCOAST","vesselId":8422,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1382,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MBXO","dateOutService":null,"dateInService":1341014400000,"code":"08355","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":299.9,"imoNumber":"9221827","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1371578555783,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373616752000,"noonPositionTelex":null,"pilotDepartureDate":1376771400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NW333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371539139830,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":717686,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1310071866000,"isBunkerCall":false,"updateTS":1375111439000,"berthingArrival":1310100666000,"inheritedVoyage":"","adjustmentTime":2396,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1310237466000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22167,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":21.23,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":636499,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517635000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1304546435000,"inheritedVoyage":"","adjustmentTime":2396,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":1257,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"updateTS":1363689322000,"isMaster":true,"isDeleted":false,"insertTS":1363689322000,"isInService":true,"versionInfo":"NWC TO WCSA 1 - til sun mon","version":4,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":636504,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309778731000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1304402400000,"inheritedVoyage":"","adjustmentTime":70,"timeInPort":1680,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304510400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11454},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22166,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":54,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"pilottimeId":11454,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":11.12,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304503200000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":0,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636504,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638347},{"sequence":2,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636504,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638351}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":636499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":636497,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304848835000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1304856035000,"inheritedVoyage":"","adjustmentTime":28,"timeInPort":1560,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304956835000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11455},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22175,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":315,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"pilottimeId":11455,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":64.85,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304949635000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636497,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638359}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636506,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305025220000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1305036020000,"inheritedVoyage":"","adjustmentTime":374,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305104420000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11458},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22172,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"distanceInMiles":13,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":11458,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":2.68,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305093620000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636506,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638361}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636496,"averageVesselFuelConsumptionPerHour":3.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305129613000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1305144013000,"inheritedVoyage":"","adjustmentTime":140,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305201613000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11462},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":-5.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22177,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"DOCAUDW","isTBN":"false","name":"DP WORLD CAUCEDO","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":142,"codePort":null}],"name":"CAUCEDO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":678,"isRealPort":true,"displayName":"CAUCEDO","isDeleted":false,"isInService":true,"isoCode":"DOCAU","timeZoneDifference":-4.0,"netpasName":"Andres"},"isDeleted":false,"distanceInMiles":4202,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":240.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"pilottimeId":11462,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":814.93,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305187213000,"pilotStation":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636496,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638356}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636500,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306126813000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1306130413000,"inheritedVoyage":"","adjustmentTime":24,"timeInPort":1020,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":678},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306195213000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11457},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22174,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":678},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"COCTGCC","isTBN":"false","name":"TERMINAL DE CONTENEDORES DE CARTAGENA S.A.","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":125,"codePort":null},{"codeMSC":"COCTGSP","isTBN":"false","name":"SOCIEDAD PORTUARIA REGIONAL CARTAGENA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":124,"codePort":null},{"codeMSC":"COCTGTM","isTBN":"false","name":"MUELLES EL BOSQUE CTG","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1301,"codePort":null},{"codeMSC":"COCTGCT","isTBN":"false","name":"CONTECAR TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":123,"codePort":null}],"name":"CARTAGENA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":788,"isRealPort":true,"displayName":"CARTAGENA","isDeleted":false,"isInService":true,"isoCode":"COCTG","timeZoneDifference":-5.0,"netpasName":"Cartagena (CO)"},"isDeleted":false,"distanceInMiles":602,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":142},"pilottimeId":11457,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":678},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":123.94,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306191613000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":142},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636500,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638355}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636498,"averageVesselFuelConsumptionPerHour":3.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306321256000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1306324856000,"inheritedVoyage":"","adjustmentTime":333,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":788},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306393256000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11456},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22176,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":788},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"isDeleted":false,"distanceInMiles":278,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":123},"pilottimeId":11456,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":788},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":58.69,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306389656000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":123},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636498,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638345}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636495,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306468836000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1306476036000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306555236000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11460},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22173,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"distanceInMiles":56,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":389},"pilottimeId":11460,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":10.5,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":8.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306548036000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":389},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638349}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636502,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306580436000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1306591236000,"inheritedVoyage":"","adjustmentTime":49,"timeInPort":1560,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306695636000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11464},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22163,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"PECLLAX","isTBN":"false","name":"DP WORLD CALLAO TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":986,"codePort":null},{"codeMSC":"PECLLAW","isTBN":"false","name":"APM TERMINALES PORTUARIOS SA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":962,"codePort":null}],"name":"CALLAO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":485,"isRealPort":true,"displayName":"CALLAO","isDeleted":false,"isInService":true,"isoCode":"PECLL","timeZoneDifference":-5.0,"netpasName":"Callao"},"isDeleted":false,"distanceInMiles":1346,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":388},"pilottimeId":11464,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":277.12,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306684836000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":388},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636502,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638346}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636501,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306983611000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1306987211000,"inheritedVoyage":"","adjustmentTime":67,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":485},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307163611000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11465},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22171,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":485},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CLPAGPT","isTBN":"false","name":"PUERTO ANGAMOS TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":88,"codePort":null}],"name":"PUERTO ANGAMOS","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":89,"isRealPort":true,"displayName":"PUERTO ANGAMOS","isDeleted":false,"isInService":true,"isoCode":"CLPAG","timeZoneDifference":-6.0,"netpasName":null},"isDeleted":false,"distanceInMiles":780,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":986},"pilottimeId":11465,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":485},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":160.59,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1307160011000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":986},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636501,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638348}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636503,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307332807000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1307340007000,"inheritedVoyage":"","adjustmentTime":46,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":89},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307455207000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11466},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22170,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":89},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CLCNLPC","isTBN":"false","name":"PUERTO DE CORONEL S.A.","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":86,"codePort":null}],"name":"CORONEL","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":767,"isRealPort":true,"displayName":"CORONEL","isDeleted":false,"isInService":true,"isoCode":"CLCNL","timeZoneDifference":-7.0,"netpasName":"Coronel"},"isDeleted":false,"distanceInMiles":871,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":88},"pilottimeId":11466,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":89},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":179.32,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307448007000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":88},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636503,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638353}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636505,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307642414000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1307646014000,"inheritedVoyage":"","adjustmentTime":88,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":767},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307757614000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11461},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22169,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":767},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CLSAIST","isTBN":"false","name":"STI","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":90,"codePort":null}],"name":"SAN ANTONIO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":91,"isRealPort":true,"displayName":"SAN ANTONIO","isDeleted":false,"isInService":true,"isoCode":"CLSAI","timeZoneDifference":-4.0,"netpasName":"San Antonio (CL)"},"isDeleted":false,"distanceInMiles":230,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":86},"pilottimeId":11461,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":767},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":47.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307754014000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":86},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636505,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638352}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636507,"averageVesselFuelConsumptionPerHour":3.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307811600000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1307815200000,"inheritedVoyage":"","adjustmentTime":529,"timeInPort":2520,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":91},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307970000000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":90},"pilottimeId":11459,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":91},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22168,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":91},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"distanceInMiles":2643,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":90},"pilottimeId":11463,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":91},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":13,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":495.56,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307966400000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":90},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636507,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638357}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636509,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308596415000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1308607215000,"inheritedVoyage":"","adjustmentTime":100,"timeInPort":1680,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308718815000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11464},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22165,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":677},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"isDeleted":false,"distanceInMiles":56,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11464},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":14.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":6.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308708015000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":388},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636509,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638360}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":636508,"averageVesselFuelConsumptionPerHour":5.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308758415000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1308765615000,"inheritedVoyage":"","adjustmentTime":875,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1257,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308880815000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11460},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22164,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":676},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":4777,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11460},"sequence":15,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":1257.11,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308873615000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":389},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636508,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638362}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":636494,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309838431000,"isBunkerCall":false,"updateTS":1363689322000,"berthingArrival":1309845631000,"inheritedVoyage":"","adjustmentTime":70,"timeInPort":1680,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11454},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22166,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11454},"sequence":16,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":11.12,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":0,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636494,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638354},{"sequence":2,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636494,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638350}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304683235000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22167,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1363689322000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"isDeleted":false,"distanceInMiles":91,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":11453,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1363689322000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":21.23,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304654435000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1363689322000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"deleteUser":null,"updateTS":1363689322000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1363689322000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"proformavesselscheduleterminalcallId":638358}],"dieselConsumption":null},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1310208666000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371539139830,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":720276}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":720276},"berthingId":220816,"vesselServiceAssignmentId":3012,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1376605800000,"berthingArrivalDate":1376634600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NW333A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376566380000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":680348,"liveDepartureDate":1376674380000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NW333A","departureVoyage":"NW333A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1539,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC ANS","vesselId":2971,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1539,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1308009540000,"dateInService":1096243200000,"code":"04604","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC ANS","vesselId":5222,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1539,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1326499140000,"dateInService":1308009600000,"code":"07654","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC ANS","vesselId":8024,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1539,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MANS","dateOutService":null,"dateInService":1326499200000,"code":"08018","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":294.0,"imoNumber":"9282261","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"WCSA","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"daa520","laneCode":"NWSAW","useWeeklyVoyageNumbers":true,"name":"NWC TO SA WEST COAST (STR 1)","exceedingDateOffset":10080,"isScheduleDelayDisplayed":false,"serviceId":66,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NW","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1371578555783,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376742600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376922900000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RM334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371996308157,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722014,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304978400000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":3918,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305093600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14491},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":13152,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14491},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.9,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":718756,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949600000,"isBunkerCall":false,"updateTS":1371637220000,"berthingArrival":1304978400000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":3918,"proformaVesselSchedule":{"proformavesselscheduleId":1474,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"deleteUser":null,"updateTS":1371637238000,"isMaster":true,"isDeleted":false,"insertTS":1371637238000,"isInService":true,"versionInfo":"Bassens Montoir Brest","version":7,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":718755,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306021440000,"isBunkerCall":false,"updateTS":1371637220000,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":256,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1474,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304928000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14487},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":15420,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1358528439000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":26,"insertTS":1358528439000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"pilottimeId":14487,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1371637238000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":2.6,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304920800000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371637238000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"insertTS":1371637238000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718755,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":721358}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":718756,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":718757,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305374400000,"isBunkerCall":false,"updateTS":1371637220000,"berthingArrival":1305381600000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1474,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305446400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14490},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":7645,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"BIO/GJN","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"7fff00","laneCode":"BISCY","useWeeklyVoyageNumbers":true,"name":"BISCAY RELAY SERVICE","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":19,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"BR","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"deleteUser":null,"pilotStationFrom":null,"updateTS":1352113491000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"FRBASPO","isTBN":"false","name":"POSTE 432","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":166,"codePort":null}],"name":"BASSENS","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":752,"isRealPort":true,"displayName":"BASSENS","isDeleted":false,"isInService":true,"isoCode":"FRBAS","timeZoneDifference":1.0,"netpasName":"Bassens"},"isDeleted":false,"distanceInMiles":530,"insertTS":1352113491000,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Koen SEGERS","userId":19811}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":14490,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1371637238000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":53.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305439200000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1371637238000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1371637238000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718757,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":721361}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":718758,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305573600000,"isBunkerCall":false,"updateTS":1371637220000,"berthingArrival":1305584400000,"inheritedVoyage":"","adjustmentTime":12,"timeInPort":1500,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":752},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1474,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305681600000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":166},"pilottimeId":14489,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":752},"isDeleted":false,"insertTS":1371637238000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":7477,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":19},"deleteUser":null,"pilotStationFrom":null,"updateTS":1351690481000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":752},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"FRMTXTT","isTBN":"false","name":"TMDC - TERMINAL MARCHANDISE DIVERSE ET CONTENEURS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":177,"codePort":null}],"name":"MONTOIR DE BRETAGNE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":208,"isRealPort":true,"displayName":"MONTOIR DE BRETAGNE","isDeleted":false,"isInService":true,"isoCode":"FRMTX","timeZoneDifference":1.0,"netpasName":"Montoir De Bretagne"},"isDeleted":false,"distanceInMiles":178,"insertTS":1351690481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":166},"pilottimeId":14484,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":752},"isDeleted":false,"insertTS":1371637238000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":17.8,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305674400000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1371637238000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":166},"insertTS":1371637238000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718758,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":721356}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":718759,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305723600000,"isBunkerCall":false,"updateTS":1371637220000,"berthingArrival":1305727200000,"inheritedVoyage":"","adjustmentTime":20,"timeInPort":1620,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":208},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1474,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305828000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14488},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":15419,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"deleteUser":null,"pilotStationFrom":null,"updateTS":1358528439000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":208},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"FRBESQR","isTBN":"false","name":"QR2","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":167,"codePort":null}],"name":"BREST","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":753,"isRealPort":true,"displayName":"BREST","isDeleted":false,"isInService":true,"isoCode":"FRBES","timeZoneDifference":1.0,"netpasName":"Brest"},"isDeleted":false,"distanceInMiles":155,"insertTS":1358528439000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":177},"pilottimeId":14488,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":208},"isDeleted":false,"insertTS":1371637238000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":15.5,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305824400000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1371637238000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":177},"insertTS":1371637238000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718759,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":721359}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":718760,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305864000000,"isBunkerCall":false,"updateTS":1371637220000,"berthingArrival":1305871200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":753},"isDeleted":false,"bufferTime":616,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1474,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305921600000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":167},"pilottimeId":14486,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":753},"isDeleted":false,"insertTS":1371637238000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6449,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"deleteUser":null,"pilotStationFrom":null,"updateTS":1348069124000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":753},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":446,"insertTS":1348069124000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":167},"pilottimeId":14485,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":753},"isDeleted":false,"insertTS":1371637238000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":44.6,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305914400000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1371637238000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":167},"insertTS":1371637238000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718760,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":721362}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":718754,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306065600000,"isBunkerCall":false,"updateTS":1371637220000,"berthingArrival":1306072800000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14487},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":15420,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14487},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":2.6,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371637238000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"insertTS":1371637238000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718754,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":721360}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1305093600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14491},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13152,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1357233776000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":189,"insertTS":1357233776000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":14491,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1371637238000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.9,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305064800000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371637238000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1371637238000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371637238000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718756,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":721357}],"dieselConsumption":null},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305064800000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371996308157,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724625}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724625},"berthingId":220933,"vesselServiceAssignmentId":3077,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":null,"pilotArrivalDate":1376778900000,"berthingArrivalDate":1376807700000,"operatorContainerMoves40":null,"customArrivalVoyage":"RM334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376998080000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":684535,"liveDepartureDate":1377084480000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RM334A","departureVoyage":"RM334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1393,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"ARIES","vesselId":4231,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1393,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"ARIE","dateOutService":null,"dateInService":1227052800000,"code":"06402","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":193.2,"imoNumber":"9225421","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"MTXBR","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"b22222","laneCode":"MTXBR","useWeeklyVoyageNumbers":true,"name":"ANTWERP/MONTOIR/BREST SERVICE","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":5,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"RM","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376894100000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376935200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371996605423,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722020,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305432017000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304964000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":382104,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305432017000,"isBunkerCall":false,"updateTS":1349680634000,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":{"proformavesselscheduleId":715,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"deleteUser":null,"updateTS":1355478226000,"isMaster":true,"isDeleted":false,"insertTS":1349680634000,"isInService":true,"versionInfo":"vers. 2 10/2012","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":382104,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":382103,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305093632000,"isBunkerCall":false,"updateTS":1349680634000,"berthingArrival":1305100832000,"inheritedVoyage":"","adjustmentTime":26,"timeInPort":900,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":715,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305162032000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5841},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2843,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332176402000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"NOLARRS","isTBN":"false","name":"REVKAI SYD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":374,"codePort":null}],"name":"LARVIK","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":3,"pilotStations":[],"portId":449,"isRealPort":true,"displayName":"LARVIK","isDeleted":false,"isInService":true,"isoCode":"NOLAR","timeZoneDifference":1.0,"netpasName":"Larvik"},"isDeleted":false,"distanceInMiles":73,"insertTS":1332176402000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680634000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"pilottimeId":5841,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"isDeleted":false,"insertTS":1349680634000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305154832000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349680634000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680634000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"insertTS":1349680634000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382103,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382874}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382105,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305180017000,"isBunkerCall":false,"updateTS":1349680634000,"berthingArrival":1305187217000,"inheritedVoyage":"","adjustmentTime":20,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":449},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":715,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305266417000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5844},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2845,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332176402000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":449},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"isDeleted":false,"distanceInMiles":100,"insertTS":1332176402000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680634000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":374},"pilottimeId":5844,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":449},"isDeleted":false,"insertTS":1349680634000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305259217000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349680634000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680634000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":374},"insertTS":1349680634000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382105,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382872}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382106,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305291617000,"isBunkerCall":false,"updateTS":1349680634000,"berthingArrival":1305295217000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":600,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":715,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305334817000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5843},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332176402000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":448,"insertTS":1332176402000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680634000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"pilottimeId":5843,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"isDeleted":false,"insertTS":1349680634000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305331217000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349680634000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680634000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"insertTS":1349680634000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382106,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382873}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":382102,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304964000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304935200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349680634000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680634000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1349680634000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382104,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382871}],"dieselConsumption":null},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304935200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371996605423,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724631}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724631},"berthingId":220937,"vesselServiceAssignmentId":3065,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":null,"pilotArrivalDate":1376805600000,"berthingArrivalDate":1376834400000,"operatorContainerMoves40":null,"customArrivalVoyage":"BF333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376827200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":684541,"liveDepartureDate":1376899200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF333R","departureVoyage":"BF334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376906400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371996605423,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722024,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304834400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305468017000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382102,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371996605423,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724635}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724635},"berthingId":220938,"vesselServiceAssignmentId":3065,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":null,"pilotArrivalDate":1377410400000,"berthingArrivalDate":1377439200000,"operatorContainerMoves40":null,"customArrivalVoyage":"BF334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377432000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":684545,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF334R","departureVoyage":"BF334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376978400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BJ332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372025408673,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722067,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306068115000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304892000000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":382126,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306068115000,"isBunkerCall":false,"updateTS":1349681630000,"berthingArrival":1304892000000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":718,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"deleteUser":null,"updateTS":1355478360000,"isMaster":true,"isDeleted":false,"insertTS":1349681530000,"isInService":true,"versionInfo":"vers. 2 10/2012","version":3,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":382126,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":382125,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305068400000,"isBunkerCall":false,"updateTS":1349681530000,"berthingArrival":1305079200000,"inheritedVoyage":"","adjustmentTime":25,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":718,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305176400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2887,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1332179676000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"LVRIXAA","isTBN":"false","name":"RIGA UNIVERSAL TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1062,"codePort":null},{"codeMSC":"LVRIXAC","isTBN":"false","name":"RIGA CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1224,"codePort":null},{"codeMSC":"LVRIXBC","isTBN":"false","name":"BCT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":299,"codePort":null}],"name":"RIGA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":381,"isRealPort":true,"displayName":"RIGA","isDeleted":false,"isInService":true,"isoCode":"LVRIX","timeZoneDifference":2.0,"netpasName":"Riga"},"isDeleted":false,"distanceInMiles":893,"insertTS":1332179676000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349681530000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":5857,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1349681530000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305165600000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349681530000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349681530000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1349681530000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382125,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382893}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382127,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305446410000,"isBunkerCall":false,"updateTS":1349681530000,"berthingArrival":1305453610000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":381},"isDeleted":false,"bufferTime":300,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":718,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305590410000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5860},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2888,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332179676000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":381},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"isDeleted":false,"distanceInMiles":271,"insertTS":1332179676000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349681530000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1224},"pilottimeId":5860,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":381},"isDeleted":false,"insertTS":1349681530000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.5,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305583210000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349681530000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349681530000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1224},"insertTS":1349681530000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382127,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382891}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382128,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305691233000,"isBunkerCall":false,"updateTS":1349681630000,"berthingArrival":1305698433000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":718,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305792033000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5859},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2889,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332179676000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":1141,"insertTS":1332179676000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349681530000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"pilottimeId":5859,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"isDeleted":false,"insertTS":1349681530000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305784833000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349681530000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349681530000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"insertTS":1349681530000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382128,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382892}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":382124,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1305007200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349681530000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349681530000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1349681530000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382126,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382890}],"dieselConsumption":null},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372025408673,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724678}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724678},"berthingId":220947,"vesselServiceAssignmentId":4493,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":null,"pilotArrivalDate":1376834400000,"berthingArrivalDate":1376863200000,"operatorContainerMoves40":null,"customArrivalVoyage":"BJ332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376866800000,"customArrivalVoyage":"BJ332R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ334A","dailyvesselschedulecellcompactId":684588,"liveDepartureDate":1376953200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ332R","departureVoyage":"BJ332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376949600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BJ334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372025408673,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722071,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304863200000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306101655000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382124,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372025408673,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724682}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724682},"berthingId":220948,"vesselServiceAssignmentId":4493,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":null,"pilotArrivalDate":1378044000000,"berthingArrivalDate":1378072800000,"operatorContainerMoves40":null,"customArrivalVoyage":"BJ334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378072800000,"customArrivalVoyage":"BJ334R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ334R","dailyvesselschedulecellcompactId":684592,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ334R","departureVoyage":"BJ334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377000000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RB332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372048214487,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722087,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304877654000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304308800000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304424000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":651687,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304877654000,"isBunkerCall":false,"updateTS":1364910121000,"berthingArrival":1304308800000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":1306,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"deleteUser":null,"updateTS":1364910318000,"isMaster":true,"isDeleted":false,"insertTS":1364910121000,"isInService":true,"versionInfo":"ANTWERP & LE HAVRE TO/FROM LIVERPOOL - FEEDER SERVICE","version":16,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":651687,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":651688,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304553649000,"isBunkerCall":false,"updateTS":1364910121000,"berthingArrival":1304568049000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"isDeleted":false,"bufferTime":271,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1306,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304668849000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12268},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":23876,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"deleteUser":null,"pilotStationFrom":null,"updateTS":1364910121000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"isDeleted":false,"distanceInMiles":503,"insertTS":1364910121000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"deleteUser":null,"updateTS":1364910121000,"pilotOnOffBoard":240.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"pilottimeId":12268,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"isDeleted":false,"insertTS":1364910121000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1304654449000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1364910121000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"deleteUser":null,"updateTS":1364910121000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"insertTS":1364910121000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"proformavesselscheduleterminalcallId":653672}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":651689,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304798454000,"isBunkerCall":false,"updateTS":1364910121000,"berthingArrival":1304805654000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":600,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1306,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304848854000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12269},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":23875,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"deleteUser":null,"pilotStationFrom":null,"updateTS":1364910121000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":161,"insertTS":1364910121000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"deleteUser":null,"updateTS":1364910121000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":12269,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1364910121000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.1,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304841654000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1364910121000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"deleteUser":null,"updateTS":1364910121000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1364910121000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651689,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"proformavesselscheduleterminalcallId":653675}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":651686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304424000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1304395200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1364910121000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"deleteUser":null,"updateTS":1364910121000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1364910121000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651687,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":221},"proformavesselscheduleterminalcallId":653673}],"dieselConsumption":null},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304395200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372048214487,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724698}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724698},"berthingId":220952,"vesselServiceAssignmentId":5327,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1376856000000,"berthingArrivalDate":1376884800000,"operatorContainerMoves40":null,"customArrivalVoyage":"RB332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376884800000,"customArrivalVoyage":"RB332R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB333A","dailyvesselschedulecellcompactId":684608,"liveDepartureDate":1376971200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB332R","departureVoyage":"RB332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376971200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RB333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372048214487,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722090,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304884854000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304913654000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372048214487,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724701}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724701},"berthingId":220953,"vesselServiceAssignmentId":5327,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1377460800000,"berthingArrivalDate":1377489600000,"operatorContainerMoves40":null,"customArrivalVoyage":"RB333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377489600000,"customArrivalVoyage":"RB333R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB333R","dailyvesselschedulecellcompactId":684611,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB333R","departureVoyage":"RB333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376805600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NM333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371714908347,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":719485,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304690440000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304719240000,"inheritedVoyage":"","adjustmentTime":92,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304834440000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2734,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":55406,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304690440000,"isBunkerCall":false,"updateTS":1331906348000,"berthingArrival":1304719240000,"inheritedVoyage":"","adjustmentTime":92,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":237,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"deleteUser":null,"updateTS":1355477906000,"isMaster":true,"isDeleted":false,"insertTS":1331899189000,"isInService":true,"versionInfo":"NWC to Turkey - Marmara","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":55405,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306372252000,"isBunkerCall":false,"updateTS":1331906348000,"berthingArrival":1304578800000,"inheritedVoyage":"","adjustmentTime":26,"timeInPort":1500,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":237,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304676000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":263},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2738,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331905750000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":62,"insertTS":1331905750000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":263},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304668800000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1331899189000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331899189000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"insertTS":1331899189000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55405,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":53100}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":55406,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":55408,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305435645000,"isBunkerCall":false,"updateTS":1331906348000,"berthingArrival":1305439245000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":237,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305550845000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":387},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2733,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331899866000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"TRISTWT","isTBN":"false","name":"MARPORT WEST TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":508,"codePort":null},{"codeMSC":"TRISTMT","isTBN":"false","name":"MARPORT MAIN TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":507,"codePort":null},{"codeMSC":"TRISTET","isTBN":"false","name":"MARPORT EAST TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":506,"codePort":null},{"codeMSC":"TRISTAE","isTBN":"false","name":"MARDAS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1336,"codePort":null},{"codeMSC":"TRISTKU","isTBN":"false","name":"KUMPORT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1285,"codePort":null}],"name":"ISTANBUL","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":579,"isRealPort":true,"displayName":"ISTANBUL","isDeleted":false,"isInService":true,"isoCode":"TRIST","timeZoneDifference":2.0,"netpasName":"Istanbul"},"isDeleted":false,"distanceInMiles":30,"insertTS":1331899866000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1324401010237,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"pilottimeId":387,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"isDeleted":false,"insertTS":1324401010237,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305547245000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1331899866000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331899866000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"insertTS":1331899866000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55408,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":53104}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":55409,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305556245000,"isBunkerCall":false,"updateTS":1331906348000,"berthingArrival":1305563445000,"inheritedVoyage":"","adjustmentTime":64,"timeInPort":1650,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":579},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":237,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305669645000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":364},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2736,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331905750000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":579},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"TRGEMRP","isTBN":"false","name":"RODAPORT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":505,"codePort":null},{"codeMSC":"TRGEMGP","isTBN":"false","name":"GEMLIK PORT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":504,"codePort":null},{"codeMSC":"TRGEMBO","isTBN":"false","name":"BORUSAN","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":503,"codePort":null}],"name":"GEMLIK","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":577,"isRealPort":true,"displayName":"GEMLIK","isDeleted":false,"isInService":true,"isoCode":"TRGEM","timeZoneDifference":2.0,"netpasName":"Gemlik"},"isDeleted":false,"distanceInMiles":52,"insertTS":1331905750000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1324303321033,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":507},"pilottimeId":364,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":579},"isDeleted":false,"insertTS":1324303321033,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305662445000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1331899866000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331899866000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":507},"insertTS":1331899866000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55409,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":53105}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":55490,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305676816000,"isBunkerCall":false,"updateTS":1331906348000,"berthingArrival":1305680416000,"inheritedVoyage":"","adjustmentTime":110,"timeInPort":660,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":577},"isDeleted":false,"bufferTime":180,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":237,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305723616000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":388},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-2.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2737,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331905750000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":577},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"distanceInMiles":3080,"insertTS":1331905750000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1324401010237,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":504},"pilottimeId":388,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":577},"isDeleted":false,"insertTS":1324401010237,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305720016000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1331905750000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331905750000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":504},"insertTS":1331905750000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55490,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":53188}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":55404,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304571600000,"isBunkerCall":false,"updateTS":1331906348000,"berthingArrival":1306393252000,"inheritedVoyage":"","adjustmentTime":26,"timeInPort":1500,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":263},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2738,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":263},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1331899189000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331899189000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"insertTS":1331899189000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55404,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":53101}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304834440000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2734,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1331899866000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"isDeleted":false,"distanceInMiles":3092,"insertTS":1331899866000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805640000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1331899189000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331899189000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1331899189000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55406,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":53102}],"dieselConsumption":null},"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805640000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371714908347,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":722091}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":722091},"berthingId":220954,"vesselServiceAssignmentId":1775,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":null,"pilotArrivalDate":1376661600000,"berthingArrivalDate":1376690400000,"operatorContainerMoves40":null,"customArrivalVoyage":"NM333A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376690400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":682123,"liveDepartureDate":1376776800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NM333A","departureVoyage":"NM333A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1712,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC CAROUGE","vesselId":3846,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1712,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MCGE","dateOutService":null,"dateInService":1175212800000,"code":"05613","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":275.0,"imoNumber":"9320441","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"TUR EX","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"f4a460","laneCode":"MARSE","useWeeklyVoyageNumbers":true,"name":"NWC TO/FROM TURKEY - MARMARA SERVICE","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":57,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NM","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376776800000,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"TRGEBYL","isTBN":"false","name":"YILPORT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502,"codePort":null}],"name":"GEBZE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":576,"isRealPort":true,"displayName":"GEBZE","isDeleted":false,"isInService":true,"isoCode":"TRGEB","timeZoneDifference":2.0,"netpasName":null},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"68E35","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371684308877,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":719331,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371684308877,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":721933}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":721933},"berthingId":220956,"vesselServiceAssignmentId":524,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":null,"pilotArrivalDate":1378900800000,"berthingArrivalDate":1378929600000,"operatorContainerMoves40":null,"customArrivalVoyage":"68E35","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378936800000,"customArrivalVoyage":"68E35","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"68E35","dailyvesselschedulecellcompactId":681972,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"68E35","departureVoyage":"68E35","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1423,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376863200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371883524207,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":721322,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306513410000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304748000000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":750,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304892000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":681495,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306513410000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1304748000000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":750,"proformaVesselSchedule":{"proformavesselscheduleId":1375,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"updateTS":1367589783000,"isMaster":true,"isDeleted":false,"insertTS":1367588717000,"isInService":true,"versionInfo":"New Spain Portugal3","version":5,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":681495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":681492,"averageVesselFuelConsumptionPerHour":1.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305000004000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1305007204000,"inheritedVoyage":"","adjustmentTime":120,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":196,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1375,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305072004000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13070},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1037,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":null,"updateTS":1326454423517,"portFrom":{"isTBN":"false","terminals":[{"codeMSC":"ESCADCO","isTBN":"false","name":"REINA SOFIA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":443,"codePort":null}],"name":"CADIZ","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":174,"isRealPort":true,"displayName":"CADIZ","isDeleted":false,"isInService":true,"isoCode":"ESCAD","timeZoneDifference":1.0,"netpasName":"Cadiz (ES)"},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":1106,"insertTS":1326454423517,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":13070,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":125.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305064804000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681492,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683853}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":681493,"averageVesselFuelConsumptionPerHour":1.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305356404000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1305360004000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":360,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":174},"isDeleted":false,"bufferTime":34,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1375,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305385204000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13080},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":382,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":null,"updateTS":1325588849667,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":174},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ESVLCTC","isTBN":"false","name":"TERPORT COMBITERMINAL CESA STV. (TCV)","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":464,"codePort":null},{"codeMSC":"ESVLCTD","isTBN":"false","name":"TERMINALES DEL TURIA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":463,"codePort":null},{"codeMSC":"ESVLCAK","isTBN":"false","name":"NOATUM CONTAINER TERMINAL VALENCIA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1095,"codePort":null},{"codeMSC":"ESVLCMT","isTBN":"false","name":"M.S.C. TERMINAL VALENCIA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":461,"codePort":null}],"name":"VALENCIA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":786,"isRealPort":true,"displayName":"VALENCIA","isDeleted":false,"isInService":true,"isoCode":"ESVLC","timeZoneDifference":1.0,"netpasName":"Valencia"},"isDeleted":false,"distanceInMiles":455,"insertTS":1325588849667,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":443},"pilottimeId":13080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":174},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":48.34,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305381604000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":443},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681493,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683851}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":681494,"averageVesselFuelConsumptionPerHour":1.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305489619000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1305493219000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":786},"isDeleted":false,"bufferTime":4,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1375,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305615619000,"departurePilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":461},"pilottimeId":13079,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":786},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":25564,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":null,"updateTS":1367417444000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":786},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ESBCNAK","isTBN":"false","name":"TERMINAL PORT NOU","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1322,"codePort":null},{"codeMSC":"ESBCNCB","isTBN":"false","name":"TERMINAL CONTENEDORES DE BARCELONA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":441,"codePort":null},{"codeMSC":"ESBCNTC","isTBN":"false","name":"TERMINAL CATALUNYA SA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":440,"codePort":null},{"codeMSC":"ESBCNAL","isTBN":"false","name":"TERMINAL BEST","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1334,"codePort":null}],"name":"BARCELONA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":172,"isRealPort":true,"displayName":"BARCELONA","isDeleted":false,"isInService":true,"isoCode":"ESBCN","timeZoneDifference":1.0,"netpasName":"Barcelona (ES)"},"isDeleted":false,"distanceInMiles":167,"insertTS":1367417444000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1095},"pilottimeId":13072,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":786},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":17.74,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305608419000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1095},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681494,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683858},{"sequence":2,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":461},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681494,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683848}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":681496,"averageVesselFuelConsumptionPerHour":1.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305653434000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1305657034000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":600,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":172},"isDeleted":false,"bufferTime":139,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1375,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305696634000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13078},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":25562,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":null,"updateTS":1367417088000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":172},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":174},"isDeleted":false,"distanceInMiles":579,"insertTS":1367417088000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1334},"pilottimeId":13078,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":172},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":61.52,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305693034000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1334},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681496,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683850}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":681500,"averageVesselFuelConsumptionPerHour":1.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305835249000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1305838849000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":174},"isDeleted":false,"bufferTime":228,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1375,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305885649000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13075},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":385,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":null,"updateTS":1325588849667,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":174},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"distanceInMiles":198,"insertTS":1325588849667,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":443},"pilottimeId":13075,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":174},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":22.44,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305882049000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":443},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681500,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683849}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":681498,"averageVesselFuelConsumptionPerHour":1.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305943249000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1305946849000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"bufferTime":475,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1375,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306015249000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13077},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":383,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":null,"updateTS":1325588849667,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"PTLEITC","isTBN":"false","name":"TERMINAL DE CONTENTORES DE LEIXOES S A (TCL)","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":403,"codePort":null}],"name":"LEIXOES","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":504,"isRealPort":true,"displayName":"LEIXOES","isDeleted":false,"isInService":true,"isoCode":"PTLEI","timeZoneDifference":0.0,"netpasName":"Leixoes"},"isDeleted":false,"distanceInMiles":211,"insertTS":1325588849667,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"pilottimeId":13077,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":25.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306011649000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681498,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683855}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":681497,"averageVesselFuelConsumptionPerHour":1.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306098006000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1306101606000,"inheritedVoyage":"","adjustmentTime":2,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":504},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1375,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306191606000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13071},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":384,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":null,"updateTS":1325588849667,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":504},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ESVGOTT","isTBN":"false","name":"TERMAVI - TERMINAL MARITIMA DE VIGO","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":465,"codePort":null}],"name":"VIGO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":193,"isRealPort":true,"displayName":"VIGO","isDeleted":false,"isInService":true,"isoCode":"ESVGO","timeZoneDifference":1.0,"netpasName":"Vigo"},"isDeleted":false,"distanceInMiles":77,"insertTS":1325588849667,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":403},"pilottimeId":13071,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":504},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.45,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306188006000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":403},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681497,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683854}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":681501,"averageVesselFuelConsumptionPerHour":1.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306213210000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1306216810000,"inheritedVoyage":"","adjustmentTime":14,"timeInPort":840,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":193},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1375,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306270810000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13076},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":211,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"deleteUser":null,"pilotStationFrom":null,"updateTS":1325520234497,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":193},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":667,"insertTS":1324390287000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":465},"pilottimeId":13076,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":193},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":9,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":66.7,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306267210000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":465},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681501,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683857}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":681499,"averageVesselFuelConsumptionPerHour":1.7,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306411217000,"isBunkerCall":false,"updateTS":1367588717000,"berthingArrival":1306418417000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":217,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1375,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306483217000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13074},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":13074,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1367588717000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":17.66,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306476017000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683852}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":681491,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304892000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304863200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1367588717000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1367588717000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1367588717000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":683856}],"dieselConsumption":null},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304863200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371883524207,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":723932}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":723932},"berthingId":220959,"vesselServiceAssignmentId":5074,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1376690400000,"berthingArrivalDate":1376719200000,"operatorContainerMoves40":null,"customArrivalVoyage":"NP332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376719200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":683849,"liveDepartureDate":1376834400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP332R","departureVoyage":"NP333A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3617,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376834400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371883524207,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":721332,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306533630000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306562430000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681491,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1371883524207,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":723943}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":723943},"berthingId":220960,"vesselServiceAssignmentId":5074,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1378504800000,"berthingArrivalDate":1378533600000,"operatorContainerMoves40":null,"customArrivalVoyage":"NP335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378533600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":683859,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP335R","departureVoyage":"NP335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3617,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377405960000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NZ333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371838830627,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":721082,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305165602000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305198002000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305345602000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13480},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701517,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305313202000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371838830627,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":723692}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":723692},"berthingId":220967,"vesselServiceAssignmentId":5484,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":null,"pilotArrivalDate":1377225960000,"berthingArrivalDate":1377258360000,"operatorContainerMoves40":null,"customArrivalVoyage":"NZ333A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377578400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":683656,"liveDepartureDate":1377693600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NZ333A","departureVoyage":"NZ333A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1569,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC SUSANNA","vesselId":3106,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1569,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSSS","dateOutService":null,"dateInService":1126656000000,"code":"04752","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":336.7,"imoNumber":"9290543","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377373560000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377369000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NU334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372052134250,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722097,"averageVesselFuelConsumptionPerHour":2.8,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304627431000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304656231000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304793031000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1059,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246168,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304764231000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372052134250,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724708}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724708},"berthingId":220969,"vesselServiceAssignmentId":4874,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":null,"pilotArrivalDate":1377203400000,"berthingArrivalDate":1377232200000,"operatorContainerMoves40":null,"customArrivalVoyage":"NU334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377232200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":684618,"liveDepartureDate":1377340200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NU334A","departureVoyage":"NU334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1922,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"RHL FIDUCIA","vesselId":5497,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1922,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1352851140000,"dateInService":1318204800000,"code":"07859","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"RHL FIDUCIA","vesselId":9071,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1922,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MHFI","dateOutService":null,"dateInService":1364083200000,"code":"08838","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":293.8,"imoNumber":"9426817","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377340200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377021600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372014647720,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722025,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309056347000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304877600000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305050400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":617450,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309056347000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1304877600000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":1142,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"updateTS":1364908786000,"isMaster":true,"isDeleted":false,"insertTS":1361956470000,"isInService":true,"versionInfo":"NWC to USA - South Atlantic + Rotterdam","version":11,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":617450,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":617453,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305061200000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1305068400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305133200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9874},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19374,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"distanceInMiles":93,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"pilottimeId":9874,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305126000000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617453,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619356}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617448,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305151200000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1305154800000,"inheritedVoyage":"","adjustmentTime":300,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305230400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9870},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19378,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":267,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"pilottimeId":9870,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305226800000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617448,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619355}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617447,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305313222000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1305324022000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1680,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305435622000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9872},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19376,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":410,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":9872,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.82,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305424822000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617447,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619352}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617454,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305518451000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1305525651000,"inheritedVoyage":"","adjustmentTime":4,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305590451000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9876},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":-6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19365,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"isDeleted":false,"distanceInMiles":3600,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":9876,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.75,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305583251000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617454,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619354}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617452,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306342822000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1306350022000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306400422000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9880},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19379,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"isTBN":"false","terminals":[{"codeMSC":"BSFPOFC","isTBN":"false","name":"FREEPORT CONTAINER PORT LTD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":600,"codePort":null}],"name":"FREEPORT, BAHAMAS","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":679,"isRealPort":true,"displayName":"FREEPORT BS","isDeleted":false,"isInService":true,"isoCode":"BSFPO","timeZoneDifference":-5.0,"netpasName":"Freeport (BS)"},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"isDeleted":false,"distanceInMiles":406,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"pilottimeId":9880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":20.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306393222000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617452,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619348}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617449,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306472422000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1306476022000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1680,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":679},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306580422000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9878},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19369,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":679},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"MXVERDC","isTBN":"false","name":"INTERNACIONAL DE CONTENEDORES Y ASOCIADOS DE VERAC","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":329,"codePort":null}],"name":"VERACRUZ","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":779,"isRealPort":true,"displayName":"VERACRUZ","isDeleted":false,"isInService":true,"isoCode":"MXVER","timeZoneDifference":-6.0,"netpasName":"Veracruz"},"isDeleted":false,"distanceInMiles":1080,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":600},"pilottimeId":9878,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":679},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306576822000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":600},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617449,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619350}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617456,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306792822000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1306796422000,"inheritedVoyage":"","adjustmentTime":4,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":779},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306886422000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9883},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19371,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":779},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"MXATMAT","isTBN":"false","name":"ALTAMIRA TERMINAL PORTUARIA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":324,"codePort":null}],"name":"ALTAMIRA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":780,"isRealPort":true,"displayName":"ALTAMIRA","isDeleted":false,"isInService":true,"isoCode":"MXATM","timeZoneDifference":-6.0,"netpasName":"Altamira (MX)"},"isDeleted":false,"distanceInMiles":239,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":329},"pilottimeId":9883,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":779},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1306882822000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":329},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617456,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619346}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617451,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306940437000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1306947637000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":780},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307026837000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9879},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19366,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":780},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USHOUBP","isTBN":"false","name":"BAYPORT CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":543,"codePort":null},{"codeMSC":"USHOUFB","isTBN":"false","name":"BARBOURS CUT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":542,"codePort":null}],"name":"HOUSTON, TX","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":4,"pilotStations":[],"portId":609,"isRealPort":true,"displayName":"HOUSTON","isDeleted":false,"isInService":true,"isoCode":"USHOU","timeZoneDifference":-6.0,"netpasName":"Houston"},"isDeleted":false,"distanceInMiles":470,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":324},"pilottimeId":9879,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":780},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":9,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307019637000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":324},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617451,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619351}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617455,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307156451000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1307170851000,"inheritedVoyage":"","adjustmentTime":608,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":609},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307300451000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9873},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19375,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":31,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":609},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USMSYPO","isTBN":"false","name":"P & O PORTS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":551,"codePort":null},{"codeMSC":"USMSYNA","isTBN":"false","name":"NEW ORLEANS TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":550,"codePort":null},{"codeMSC":"USMSYTC","isTBN":"false","name":"NAPOLEON AVENUE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1373,"codePort":null}],"name":"NEW ORLEANS, LA (USA)","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":11,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Southwest Pass","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":31,"netpasName":"Southwest Pass (RP)"}],"portId":615,"isRealPort":true,"displayName":"NEW ORLEANS, LA (USA)","isDeleted":false,"isInService":true,"isoCode":"USMSY","timeZoneDifference":-6.0,"netpasName":"New Orleans"},"isDeleted":false,"distanceInMiles":292,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":240.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":543},"pilottimeId":9873,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":609},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307286051000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":543},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619345}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617459,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307412017000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1307430017000,"inheritedVoyage":"","adjustmentTime":280,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":615},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307534417000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9882},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19367,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":31,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":615},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"USMOB9Z","isTBN":"false","name":"MOBILE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":938,"codePort":null},{"codeMSC":"USMOBAD","isTBN":"false","name":"APM TERMINALS MOBILE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1041,"codePort":null}],"name":"MOBILE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":800,"isRealPort":true,"displayName":"MOBILE","isDeleted":false,"isInService":true,"isoCode":"USMOB","timeZoneDifference":-5.0,"netpasName":"Mobile"},"isDeleted":false,"distanceInMiles":155,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":300.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":550},"pilottimeId":9882,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":615},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307516417000,"pilotStation":{"?p":"true","pilotstationId":31,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":550},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617459,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619347}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617458,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307592017000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1307602817000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":800},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307678417000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9881},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19373,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":800},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":679},"isDeleted":false,"distanceInMiles":766,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1041},"pilottimeId":9881,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":800},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307667617000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1041},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617458,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619349}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617461,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307854847000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1307858447000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1680,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":679},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307962847000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9877},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19370,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":679},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":630},"isDeleted":false,"distanceInMiles":385,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":600},"pilottimeId":9877,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":679},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":13,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307959247000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":600},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617461,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619353}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617457,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308042047000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1308056447000,"inheritedVoyage":"","adjustmentTime":100,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":630},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308128447000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9875},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19377,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":630},"isDeleted":false,"distanceInMiles":76,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":240.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":566},"pilottimeId":9875,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":630},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":12.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308114047000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":566},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617457,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619357}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":617460,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308157247000,"isBunkerCall":false,"updateTS":1361956470000,"berthingArrival":1308164447000,"inheritedVoyage":"","adjustmentTime":45,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1142,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308229247000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9869},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":19372,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"deleteUser":null,"pilotStationFrom":null,"updateTS":1361956470000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":3708,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"pilottimeId":9869,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"isDeleted":false,"insertTS":1361956470000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733}},"sequence":15,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308222047000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617460,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619360}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":617446,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1305050400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305021600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1361956470000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1361956470000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1361956470000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617450,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":619359}],"dieselConsumption":null},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305021600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372014647720,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724636}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724636},"berthingId":220970,"vesselServiceAssignmentId":5605,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":null,"pilotArrivalDate":1376820000000,"berthingArrivalDate":1376848800000,"operatorContainerMoves40":null,"customArrivalVoyage":"NG330R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376848800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":684546,"liveDepartureDate":1376992800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG330R","departureVoyage":"NG334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3594,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376992800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG337R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372014647720,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722040,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309082447000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1309111247000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":16,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617446,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372014647720,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724651}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724651},"berthingId":220971,"vesselServiceAssignmentId":5605,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":null,"pilotArrivalDate":1381053600000,"berthingArrivalDate":1381082400000,"operatorContainerMoves40":null,"customArrivalVoyage":"NG337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381082400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":684561,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG337R","departureVoyage":"NG337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3594,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1378587600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NQ336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1371609908313,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":718457,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1315501296000,"isBunkerCall":false,"updateTS":1375868569000,"berthingArrival":1315530096000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1315645296000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":21027,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":41.58,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1315616496000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1371609908313,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":721057}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":721057},"berthingId":220977,"vesselServiceAssignmentId":4926,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":null,"pilotArrivalDate":1378443600000,"berthingArrivalDate":1378472400000,"operatorContainerMoves40":null,"customArrivalVoyage":"NQ336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378522800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":681118,"liveDepartureDate":1378609200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NQ336A","departureVoyage":"NQ336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1782,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC CARMEN","vesselId":4122,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1782,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MCAM","dateOutService":null,"dateInService":1212969600000,"code":"06168","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":275.0,"imoNumber":"9349813","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372086695003,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378558800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377410400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NM334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372323011110,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":726094,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304690440000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304719240000,"inheritedVoyage":"","adjustmentTime":92,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304834440000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2734,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55406,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805640000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372323011110,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":728804}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":728804},"berthingId":221189,"vesselServiceAssignmentId":3975,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":null,"pilotArrivalDate":1377266400000,"berthingArrivalDate":1377295200000,"operatorContainerMoves40":null,"customArrivalVoyage":"NM334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377295200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":688528,"liveDepartureDate":1377381600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NM334A","departureVoyage":"NM334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1711,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC LEIGH","vesselId":3700,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1711,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSLH","dateOutService":null,"dateInService":1164672000000,"code":"05424","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":275.0,"imoNumber":"9320439","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377381600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377237600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"22E32","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372285207047,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":725849,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306933252000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304546400000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304661600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":4046,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17758},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306933252000,"isBunkerCall":false,"updateTS":1334595923000,"berthingArrival":1304546400000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":33,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"deleteUser":null,"updateTS":1357206460000,"isMaster":true,"isDeleted":false,"insertTS":1323875365000,"isInService":true,"versionInfo":"Montreal Express","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":4046,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":4047,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17758},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304708452000,"isBunkerCall":false,"updateTS":1334595923000,"berthingArrival":1304719252000,"inheritedVoyage":"","adjustmentTime":42,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":33,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304773252000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":264},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":31,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1323877529000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":410,"insertTS":1323877529000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1331853617000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":264,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1323875365000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":2,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":24.7,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.6,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304762452000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1323875365000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1326373982077,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1323875365000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4047,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":23}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":4048,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17758},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304859648000,"isBunkerCall":false,"updateTS":1334595923000,"berthingArrival":1304866848000,"inheritedVoyage":"","adjustmentTime":201,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":33,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304917248000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":265},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":24,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"deleteUser":null,"pilotStationFrom":null,"updateTS":1323875365283,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"isDeleted":false,"distanceInMiles":503,"insertTS":1323875365283,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1323875365283,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171},"pilottimeId":265,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1323875365283,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":27.34,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.4,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304910048000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1323875365000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1326373982077,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171},"insertTS":1323875365000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4048,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":24}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":4049,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17758},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305000001000,"isBunkerCall":false,"updateTS":1334595923000,"berthingArrival":1305014401000,"inheritedVoyage":"","adjustmentTime":1097,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":33,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305072001000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":259},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-5.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":47,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":7033},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":4,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1323951332563,"portFrom":{"isTBN":"false","terminals":[{"codeMSC":"CAMTRTE","isTBN":"false","name":"TERMONT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":81,"codePort":null},{"codeMSC":"CARAC","isTBN":"false","name":"RACINE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":80,"codePort":null},{"codeMSC":"CACA1","isTBN":"false","name":"CAST","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":79,"codePort":null}],"name":"MONTREAL, QU","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[{"isDeleted":false,"isDefault":true,"name":"Les escoumins","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":4,"netpasName":"Les Escoumins"}],"portId":706,"isRealPort":true,"displayName":"MONTREAL","isDeleted":false,"isInService":true,"isoCode":"CAMTR","timeZoneDifference":-5.0,"netpasName":"Montreal"},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"isDeleted":false,"distanceInMiles":2497,"insertTS":1323951332563,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Wim VERMAELEN","userId":7033}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1323872409627,"pilotOnOffBoard":240.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"pilottimeId":259,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"isDeleted":false,"insertTS":1323872409627,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":168.72,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305057601000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1323875365000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1326373982077,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"insertTS":1323875365000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4049,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":25}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":4050,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17758},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305727199000,"isBunkerCall":false,"updateTS":1334595923000,"berthingArrival":1305791999000,"inheritedVoyage":"","adjustmentTime":470,"timeInPort":4320,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":706},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":33,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306115999000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":266},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":5.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":47,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1323875365283,"pilotOnOffBoard":1080.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":81},"pilottimeId":266,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":706},"isDeleted":false,"insertTS":1323875365283,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":145.17,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.2,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1306051199000,"pilotStation":{"?p":"true","pilotstationId":4,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1323875365000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1326373982077,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":81},"insertTS":1323875365000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4050,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":26}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":4044,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17758},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306684827000,"isBunkerCall":false,"updateTS":1334595923000,"berthingArrival":1306699227000,"inheritedVoyage":"","adjustmentTime":240,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":33,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306800027000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":259},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":21,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"deleteUser":null,"pilotStationFrom":null,"updateTS":1323875365283,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":611,"insertTS":1323875365283,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":259},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":41.01,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306785627000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1323875365000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1326373982077,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"insertTS":1323875365000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4044,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":20}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304661600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304632800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1323875365000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1326373982077,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1323875365000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4046,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":22}],"dieselConsumption":null},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304632800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372285207047,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":728557}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":728557},"berthingId":221191,"vesselServiceAssignmentId":525,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":null,"pilotArrivalDate":1377093600000,"berthingArrivalDate":1377122400000,"operatorContainerMoves40":null,"customArrivalVoyage":"22E32","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377122400000,"customArrivalVoyage":"22E32","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"23W34","dailyvesselschedulecellcompactId":688283,"liveDepartureDate":1377208800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"22E32","departureVoyage":"22E32","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1287,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377208800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"23W36","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372285207047,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":725855,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372285207047,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":728563}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":728563},"berthingId":221192,"vesselServiceAssignmentId":525,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":null,"pilotArrivalDate":1379512800000,"berthingArrivalDate":1379541600000,"operatorContainerMoves40":null,"customArrivalVoyage":"23W36","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379541600000,"customArrivalVoyage":"23E36","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"23E36","dailyvesselschedulecellcompactId":688289,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"23E36","departureVoyage":"23E36","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1287,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377973800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NU335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372653334513,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727949,"averageVesselFuelConsumptionPerHour":2.8,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304627431000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304656231000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304793031000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1059,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246168,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304764231000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372653334513,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730690}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730690},"berthingId":221196,"vesselServiceAssignmentId":4640,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":null,"pilotArrivalDate":1377808200000,"berthingArrivalDate":1377837000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NU335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377837000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":690354,"liveDepartureDate":1377945000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NU335A","departureVoyage":"NU335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1132,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MELINA","vesselId":5190,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1132,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MMEN","dateOutService":null,"dateInService":1307577600000,"code":"07626","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":299.8,"imoNumber":"9122605","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377945000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1378360800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372197635080,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":723788,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308809355000,"isBunkerCall":false,"updateTS":1375861875000,"berthingArrival":1308838155000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1308953355000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374699,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308924555000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372197635080,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":726405}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":726405},"berthingId":221203,"vesselServiceAssignmentId":3648,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":null,"pilotArrivalDate":1378216800000,"berthingArrivalDate":1378245600000,"operatorContainerMoves40":null,"customArrivalVoyage":"NA332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378245600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":686280,"liveDepartureDate":1378332000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA332R","departureVoyage":"NA336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1778,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378332000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377540000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372605005250,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727866,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305432017000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304964000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382104,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304935200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372605005250,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730607}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730607},"berthingId":221207,"vesselServiceAssignmentId":3065,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":null,"pilotArrivalDate":1377410400000,"berthingArrivalDate":1377439200000,"operatorContainerMoves40":null,"customArrivalVoyage":"BF334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377432000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":690271,"liveDepartureDate":1377504000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF334R","departureVoyage":"BF335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377511200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372605005250,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727870,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304834400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305468017000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382102,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372605005250,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730611}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730611},"berthingId":221208,"vesselServiceAssignmentId":3065,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":null,"pilotArrivalDate":1378015200000,"berthingArrivalDate":1378044000000,"operatorContainerMoves40":null,"customArrivalVoyage":"BF335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378036800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":690275,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF335R","departureVoyage":"BF335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373628357000,"noonPositionTelex":null,"pilotDepartureDate":1377043200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372231507440,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":724104,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305650141000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304604000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":382113,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305650141000,"isBunkerCall":false,"updateTS":1349680872000,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":716,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"deleteUser":null,"updateTS":1355478325000,"isMaster":true,"isDeleted":false,"insertTS":1349680872000,"isInService":true,"versionInfo":"vers. 2 10/2012","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":382113,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":382109,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304665200000,"isBunkerCall":false,"updateTS":1349680872000,"berthingArrival":1304676000000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":716,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304773200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5851},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6822,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":47,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1349107328000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"distanceInMiles":108,"insertTS":1349107328000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":5851,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1349680872000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304762400000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349680872000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1349680872000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382109,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382875}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382110,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304802051000,"isBunkerCall":false,"updateTS":1349680872000,"berthingArrival":1304805651000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":716,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304809251000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5850},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6821,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":47,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1349107328000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"LTKLJSM","isTBN":"false","name":"SMELTE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":307,"codePort":null}],"name":"KLAIPEDA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":380,"isRealPort":true,"displayName":"KLAIPEDA","isDeleted":false,"isInService":true,"isoCode":"LTKLJ","timeZoneDifference":2.0,"netpasName":"Klaipeda"},"isDeleted":false,"distanceInMiles":390,"insertTS":1349107328000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"pilottimeId":5850,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"insertTS":1349680872000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805651000,"pilotStation":{"?p":"true","pilotstationId":47,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1349680872000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"insertTS":1349680872000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382110,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382877}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382111,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304913617000,"isBunkerCall":false,"updateTS":1349680872000,"berthingArrival":1304920817000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":380},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":716,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304985617000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5845},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6823,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"deleteUser":null,"pilotStationFrom":null,"updateTS":1349107328000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":380},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"SESTOFH","isTBN":"false","name":"CONTAINER TERMINAL FRIHAMNEN (CTF)","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":476,"codePort":null}],"name":"STOCKHOLM","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":546,"isRealPort":true,"displayName":"STOCKHOLM","isDeleted":false,"isInService":true,"isoCode":"SESTO","timeZoneDifference":1.0,"netpasName":"Stockholm"},"isDeleted":false,"distanceInMiles":269,"insertTS":1349107328000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":307},"pilottimeId":5845,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":380},"isDeleted":false,"insertTS":1349680872000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978417000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349680872000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":307},"insertTS":1349680872000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382111,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382883}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382114,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305046841000,"isBunkerCall":false,"updateTS":1349680872000,"berthingArrival":1305064841000,"inheritedVoyage":"","adjustmentTime":12,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":546},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":716,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305169241000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5849},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6818,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"deleteUser":null,"pilotStationFrom":null,"updateTS":1349107328000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":546},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"SEGVXGC","isTBN":"false","name":"GAVLE CONTAINERTERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":471,"codePort":null}],"name":"GAVLE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":540,"isRealPort":true,"displayName":"GAVLE","isDeleted":false,"isInService":true,"isoCode":"SEGVX","timeZoneDifference":1.0,"netpasName":"Gavle"},"isDeleted":false,"distanceInMiles":162,"insertTS":1349107328000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"pilotOnOffBoard":300.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":476},"pilottimeId":5849,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":546},"isDeleted":false,"insertTS":1349680872000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305151241000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349680872000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":476},"insertTS":1349680872000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382114,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382876}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382115,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305208841000,"isBunkerCall":false,"updateTS":1349680872000,"berthingArrival":1305216041000,"inheritedVoyage":"","adjustmentTime":12,"timeInPort":900,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":540},"isDeleted":false,"bufferTime":180,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":716,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305277241000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5847},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6817,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"deleteUser":null,"pilotStationFrom":null,"updateTS":1349107328000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":540},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"SEPATER","isTBN":"false","name":"PAMPUSTERMINALEN","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":475,"codePort":null},{"codeMSC":"SENORON","isTBN":"false","name":"OHMANSKAJEN","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":474,"codePort":null}],"name":"NORRKOPING","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":544,"isRealPort":true,"displayName":"NORRKOPING","isDeleted":false,"isInService":true,"isoCode":"SENRK","timeZoneDifference":1.0,"netpasName":"Norrkoping"},"isDeleted":false,"distanceInMiles":237,"insertTS":1349107328000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":471},"pilottimeId":5847,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":540},"isDeleted":false,"insertTS":1349680872000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305270041000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349680872000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":471},"insertTS":1349680872000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382115,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382878}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382116,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305345641000,"isBunkerCall":false,"updateTS":1349680872000,"berthingArrival":1305352841000,"inheritedVoyage":"","adjustmentTime":25,"timeInPort":900,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":544},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":716,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305414041000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5848},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6820,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":46,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"deleteUser":null,"pilotStationFrom":null,"updateTS":1349107328000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":544},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"distanceInMiles":437,"insertTS":1349107328000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":475},"pilottimeId":5848,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":544},"isDeleted":false,"insertTS":1349680872000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":12.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305406841000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349680872000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":475},"insertTS":1349680872000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382116,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382880}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":382112,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305547241000,"isBunkerCall":false,"updateTS":1349680872000,"berthingArrival":1305550841000,"inheritedVoyage":"","adjustmentTime":35,"timeInPort":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"bufferTime":300,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":716,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305554441000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5850},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":46,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1349107328000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":331,"insertTS":1349107328000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5850},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":12.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305550841000,"pilotStation":{"?p":"true","pilotstationId":46,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1349680872000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"insertTS":1349680872000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382112,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382882}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":382107,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304604000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304575200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349680872000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1349680872000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1349680872000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382113,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":382881}],"dieselConsumption":null},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304575200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372231507440,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":726721}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":726721},"berthingId":221209,"vesselServiceAssignmentId":2933,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1376899200000,"berthingArrivalDate":1376928000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377007200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":686596,"liveDepartureDate":1377093600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH332R","departureVoyage":"BH334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377014400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373628357000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372231507440,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":724112,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305698441000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382107,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372231507440,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":726729}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":726729},"berthingId":221210,"vesselServiceAssignmentId":2933,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1378108800000,"berthingArrivalDate":1378137600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378216800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":686604,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH334R","departureVoyage":"BH334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373628357000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1372348074000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372348074000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":726414,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305669641000,"isBunkerCall":false,"updateTS":1372348074000,"berthingArrival":1305698441000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382107,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372348074000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":729140}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":729140},"berthingId":221213,"vesselServiceAssignmentId":5704,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1377597600000,"berthingArrivalDate":1377626400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377565200000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":688876,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH333R","departureVoyage":"BH333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3240,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"AALDERDIJK","vesselId":8479,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3240,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MDIJ","dateOutService":null,"dateInService":1343520000000,"code":"08406","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":168.1,"imoNumber":"9491496","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377583200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BJ333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372633810420,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727913,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306068115000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304892000000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382126,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372633810420,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730654}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730654},"berthingId":221221,"vesselServiceAssignmentId":4494,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":null,"pilotArrivalDate":1377439200000,"berthingArrivalDate":1377468000000,"operatorContainerMoves40":null,"customArrivalVoyage":"BJ333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377432000000,"customArrivalVoyage":"BJ333R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ335A","dailyvesselschedulecellcompactId":690318,"liveDepartureDate":1377518400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ333R","departureVoyage":"BJ333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3133,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377554400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BJ335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372633810420,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727917,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304863200000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306101655000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382124,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372633810420,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730658}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730658},"berthingId":221222,"vesselServiceAssignmentId":4494,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":null,"pilotArrivalDate":1378648800000,"berthingArrivalDate":1378677600000,"operatorContainerMoves40":null,"customArrivalVoyage":"BJ335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378641600000,"customArrivalVoyage":"BJ335R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ335R","dailyvesselschedulecellcompactId":690322,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ335R","departureVoyage":"BJ335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3133,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377727200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372773602763,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":729913,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305551521000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304431200000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304546400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":403968,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305551521000,"isBunkerCall":false,"updateTS":1350996139000,"berthingArrival":1304431200000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":{"proformavesselscheduleId":742,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"deleteUser":null,"updateTS":1355478138000,"isMaster":true,"isDeleted":false,"insertTS":1350996139000,"isInService":true,"versionInfo":"vers.11/2012","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":403968,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":403967,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304607615000,"isBunkerCall":false,"updateTS":1350996139000,"berthingArrival":1304618415000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":742,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304737215000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6094},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2799,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1332158488000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"FIKTKSO","isTBN":"false","name":"STEVECO OY","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1157,"codePort":null},{"codeMSC":"FIKTKMT","isTBN":"false","name":"MULTILINK TERMINAL (MLT)","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":161,"codePort":null},{"codeMSC":"FIKTKFO","isTBN":"false","name":"FINNSTEVE OY AB","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":160,"codePort":null}],"name":"KOTKA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":201,"isRealPort":true,"displayName":"KOTKA","isDeleted":false,"isInService":true,"isoCode":"FIKTK","timeZoneDifference":2.0,"netpasName":"Kotka"},"isDeleted":false,"distanceInMiles":1126,"insertTS":1332158488000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1350996139000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":6094,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1350996139000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":2,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.6,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304726415000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1350996139000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1350996139000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1350996139000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403967,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":404827}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":403969,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305000001000,"isBunkerCall":false,"updateTS":1350996139000,"berthingArrival":1305007201000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":201},"isDeleted":false,"bufferTime":1020,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":742,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305100801000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6097},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6890,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"deleteUser":null,"pilotStationFrom":null,"updateTS":1349274002000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":201},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"isDeleted":false,"distanceInMiles":79,"insertTS":1349274002000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1350996139000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":161},"pilottimeId":6097,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":201},"isDeleted":false,"insertTS":1350996139000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305093601000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1350996139000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1350996139000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":161},"insertTS":1350996139000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403969,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":404825}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":403970,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305176401000,"isBunkerCall":false,"updateTS":1370350858050,"berthingArrival":1305183601000,"inheritedVoyage":"","adjustmentTime":48,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"isDeleted":false,"bufferTime":840,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":742,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305262801000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6096},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2804,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332158488000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":1233,"insertTS":1332158488000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1350996139000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"pilottimeId":6096,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"isDeleted":false,"insertTS":1350996139000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305255601000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1350996139000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1350996139000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"insertTS":1350996139000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403970,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":404826}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":403966,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304546400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304517600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1350996139000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1350996139000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1350996139000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403968,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":404824}],"dieselConsumption":null},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304517600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372773602763,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":732661}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":732661},"berthingId":221225,"vesselServiceAssignmentId":3064,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":null,"pilotArrivalDate":1377583200000,"berthingArrivalDate":1377612000000,"operatorContainerMoves40":null,"customArrivalVoyage":"BB333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377612000000,"customArrivalVoyage":"BB333R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB335A","dailyvesselschedulecellcompactId":692301,"liveDepartureDate":1377698400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB333R","departureVoyage":"BB333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":768,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377698400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372773602763,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":729917,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304402400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305640801000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403966,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372773602763,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":732665}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":732665},"berthingId":221226,"vesselServiceAssignmentId":3064,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":null,"pilotArrivalDate":1378792800000,"berthingArrivalDate":1378821600000,"operatorContainerMoves40":null,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378821600000,"customArrivalVoyage":"BB335R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB335R","dailyvesselschedulecellcompactId":692305,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB335R","departureVoyage":"BB335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":768,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377122400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BB332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372172402797,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":723438,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305551521000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304431200000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304546400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403968,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304517600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372172402797,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":726055}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":726055},"berthingId":221230,"vesselServiceAssignmentId":3063,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":null,"pilotArrivalDate":1376978400000,"berthingArrivalDate":1377007200000,"operatorContainerMoves40":null,"customArrivalVoyage":"BB332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377007200000,"customArrivalVoyage":"BB332R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB334A","dailyvesselschedulecellcompactId":685931,"liveDepartureDate":1377093600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB332R","departureVoyage":"BB332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377093600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BB334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372172402797,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":723442,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304402400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305640801000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403966,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372172402797,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":726059}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":726059},"berthingId":221231,"vesselServiceAssignmentId":3063,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":null,"pilotArrivalDate":1378188000000,"berthingArrivalDate":1378216800000,"operatorContainerMoves40":null,"customArrivalVoyage":"BB334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378216800000,"customArrivalVoyage":"BB334R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB334R","dailyvesselschedulecellcompactId":685935,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB334R","departureVoyage":"BB334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373621319000,"noonPositionTelex":null,"pilotDepartureDate":1377669600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372721704437,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":729467,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305543885000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304373600000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304488800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":439882,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305543885000,"isBunkerCall":false,"updateTS":1352898257000,"berthingArrival":1304373600000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":819,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"deleteUser":null,"updateTS":1355478478000,"isMaster":true,"isDeleted":false,"insertTS":1352898257000,"isInService":true,"versionInfo":"vers. 3 10/2012","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":439882,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":439880,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304539215000,"isBunkerCall":false,"updateTS":1352898257000,"berthingArrival":1304546415000,"inheritedVoyage":"","adjustmentTime":20,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"isDeleted":false,"bufferTime":240,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":819,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304640015000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6665},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6718,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"deleteUser":null,"pilotStationFrom":null,"updateTS":1348675744000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":325,"insertTS":1348675744000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"pilottimeId":6665,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"isDeleted":false,"insertTS":1352898257000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304632815000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1352898257000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"insertTS":1352898257000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439880,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":441167}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":439879,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304737215000,"isBunkerCall":false,"updateTS":1352898257000,"berthingArrival":1304748015000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":819,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304845215000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6667},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6719,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":47,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1348675744000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"distanceInMiles":110,"insertTS":1348675744000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":6667,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1352898257000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304834415000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1352898257000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1352898257000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439879,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":441169}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":439881,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304870445000,"isBunkerCall":false,"updateTS":1352898257000,"berthingArrival":1304874045000,"inheritedVoyage":"","adjustmentTime":12,"timeInPort":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":819,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304877645000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6668},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":4035,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":47,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1338306034000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"RUKGDBS","isTBN":"false","name":"BALTIC STEVEDORING COMPANY","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":412,"codePort":null}],"name":"KALININGRAD","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":524,"isRealPort":true,"displayName":"KALININGRAD","isDeleted":false,"isInService":true,"isoCode":"RUKGD","timeZoneDifference":2.0,"netpasName":"Kaliningrad"},"isDeleted":false,"distanceInMiles":372,"insertTS":1338306034000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"pilottimeId":6668,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"insertTS":1352898257000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1304874045000,"pilotStation":{"?p":"true","pilotstationId":47,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1352898257000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"insertTS":1352898257000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439881,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":441170}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":439885,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304971245000,"isBunkerCall":false,"updateTS":1352898257000,"berthingArrival":1304978445000,"inheritedVoyage":"","adjustmentTime":15,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":524},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":819,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305115245000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6666},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2809,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332172887000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":524},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"FIRAURS","isTBN":"false","name":"EUROPORTS RAUMA OY","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":163,"codePort":null}],"name":"RAUMA (RAUMO)","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":203,"isRealPort":true,"displayName":"RAUMA","isDeleted":false,"isInService":true,"isoCode":"FIRAU","timeZoneDifference":2.0,"netpasName":"Rauma"},"isDeleted":false,"distanceInMiles":452,"insertTS":1332172887000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":412},"pilottimeId":6666,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":524},"isDeleted":false,"insertTS":1352898257000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305108045000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1352898257000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":412},"insertTS":1352898257000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439885,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":441168}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":439883,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305216045000,"isBunkerCall":false,"updateTS":1352898257000,"berthingArrival":1305223245000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":203},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":819,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305316845000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6663},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6715,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":46,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"deleteUser":null,"pilotStationFrom":null,"updateTS":1348675744000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":203},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"distanceInMiles":619,"insertTS":1348675744000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":163},"pilottimeId":6663,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":203},"isDeleted":false,"insertTS":1352898257000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305309645000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1352898257000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":163},"insertTS":1352898257000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439883,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":441171}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":439884,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305460845000,"isBunkerCall":false,"updateTS":1352898257000,"berthingArrival":1305464445000,"inheritedVoyage":"","adjustmentTime":4,"timeInPort":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":819,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305468045000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6668},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6717,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":46,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1348675744000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":331,"insertTS":1348675744000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6668},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305464445000,"pilotStation":{"?p":"true","pilotstationId":46,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1352898257000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"insertTS":1352898257000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439884,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":441173}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":439877,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304488800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304460000000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1352898257000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"deleteUser":null,"updateTS":1352898257000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1352898257000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439882,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"proformavesselscheduleterminalcallId":441174}],"dieselConsumption":null},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304460000000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372721704437,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":732210}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":732210},"berthingId":221254,"vesselServiceAssignmentId":5329,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1377525600000,"berthingArrivalDate":1377554400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377626400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":691857,"liveDepartureDate":1377712800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC333R","departureVoyage":"BC335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1801,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377640800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373621319000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372721704437,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":729474,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304344800000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305583245000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439877,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372721704437,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":732217}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":732217},"berthingId":221255,"vesselServiceAssignmentId":5329,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1378735200000,"berthingArrivalDate":1378764000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378814400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":691864,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC335R","departureVoyage":"BC335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1801,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1376851500000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FS333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372184408547,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":723712,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304649950000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304678750000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304880350000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12635,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":559561,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304649950000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1304678750000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":990,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"updateTS":1363692824000,"isMaster":true,"isDeleted":false,"insertTS":1356609341000,"isInService":true,"versionInfo":"silk vers. 3","version":7,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":559557,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1311720324000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1304445600000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304539200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8334},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12634,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"distanceInMiles":88,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":995},"pilottimeId":8334,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304532000000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":995},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559557,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561160}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559564,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304560400000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1304567600000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304643200000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"pilottimeId":8324,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12641,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":30,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"pilottimeId":8321,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":2,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304639600000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559564,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561147}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":559561,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":559551,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304894235000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1304901435000,"inheritedVoyage":"","adjustmentTime":20,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305016635000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8319},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12642,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ITGITMC","isTBN":"false","name":"MEDCENTER CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":246,"codePort":null}],"name":"GIOIA TAURO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":777,"isRealPort":true,"displayName":"GIOIA TAURO","isDeleted":false,"isInService":true,"isoCode":"ITGIT","timeZoneDifference":1.0,"netpasName":"Gioia Tauro"},"isDeleted":false,"distanceInMiles":2356,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"pilottimeId":8319,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.2,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305009435000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559551,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561150}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559555,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305538991000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1305546191000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":2340,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":777},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305693791000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":246},"pilottimeId":8322,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":777},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12648,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":777},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"EGSUZST","isTBN":"false","name":"SUEZ TRANSIT CANAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151,"codePort":null}],"name":"SUEZ","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[{"isDeleted":false,"isDefault":false,"name":"Suez south","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":38,"netpasName":"Suez Canal (RP)"},{"isDeleted":false,"isDefault":true,"name":"Suez north (Port Said)","isInService":true,"?t":"com.msc.medlog.mwp.entities.PilotStation","pilotstationId":26,"netpasName":"Port Said"}],"portId":166,"isRealPort":false,"displayName":"SUEZ","isDeleted":false,"isInService":true,"isoCode":"EGSUZ","timeZoneDifference":2.0,"netpasName":"Suez Canal (RP)"},"isDeleted":false,"distanceInMiles":963,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":246},"pilottimeId":8323,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":777},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.1,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305686591000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":246},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559555,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561155}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559560,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305913380000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1305913380000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":60,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305916980000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8327},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12646,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"distanceInMiles":82,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":0.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"pilottimeId":8327,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":7.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305916980000,"pilotStation":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559560,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561159}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559556,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305959511000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1305959511000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":560,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305993111000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8327},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12647,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"AEJAC","isTBN":"false","name":"JEBEL ALI CONTAINER TERMINAL - AEJAC","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":520,"codePort":null}],"name":"JEBEL ALI","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":13,"isRealPort":true,"displayName":"JEBEL ALI","isDeleted":false,"isInService":true,"isoCode":"AEJEA","timeZoneDifference":4.0,"netpasName":"Jebel Ali"},"isDeleted":false,"distanceInMiles":2876,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8327},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305993111000,"pilotStation":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559556,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561154}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559553,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306739854000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1306747054000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":2100,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":13},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306880254000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8328},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":4.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12651,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":13},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"SGSINAZ","isTBN":"false","name":"PSA TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1083,"codePort":null},{"codeMSC":"SGSINPP","isTBN":"false","name":"PASIR PANJANG TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":429,"codePort":null},{"codeMSC":"SGSINBA","isTBN":"false","name":"MPAT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084,"codePort":null}],"name":"SINGAPORE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":550,"isRealPort":true,"displayName":"SINGAPORE","isDeleted":false,"isInService":true,"isoCode":"SGSIN","timeZoneDifference":8.0,"netpasName":"Singapore"},"isDeleted":false,"distanceInMiles":3462,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":520},"pilottimeId":8328,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":13},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":13.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306873054000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":520},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559553,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561151}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559549,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307800605000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1307807805000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1560,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307905005000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"pilottimeId":8338,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12650,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"HKMTL","isTBN":"false","name":"MODERN TERMINALS LIMITED","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":213,"codePort":null},{"codeMSC":"HKHIT","isTBN":"false","name":"HONG KONG INTERNATIONAL TERMINALS LTD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":212,"codePort":null},{"codeMSC":"HKHKGDP","isTBN":"false","name":"DP WORLD HONG KONG TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":211,"codePort":null}],"name":"HONG KONG","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":259,"isRealPort":true,"displayName":"HONG KONG","isDeleted":false,"isInService":true,"isoCode":"HKHKG","timeZoneDifference":8.0,"netpasName":"Hong Kong"},"isDeleted":false,"distanceInMiles":1417,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"pilottimeId":8339,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.2,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307901405000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559549,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561149}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559552,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308185770000,"isBunkerCall":false,"updateTS":1356609341000,"berthingArrival":1308192970000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":259},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308243370000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8325},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12633,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":259},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CNTXGAP","isTBN":"false","name":"TIANJIN PORT EUROASIA INTERNATIONAL CONTAINER TERM","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1256,"codePort":null},{"codeMSC":"CNTXGAO","isTBN":"false","name":"TIANJIN PORT CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1255,"codePort":null},{"codeMSC":"CNTXGAN","isTBN":"false","name":"TIANJIN FIVE CONTINENTS INTERNATIONAL CONTAINER TE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1254,"codePort":null},{"codeMSC":"CNTXGAM","isTBN":"false","name":"TIAN JIN PACIFIC INTERNATIONAL CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1253,"codePort":null}],"name":"TIANJINXINGANG","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":111,"isRealPort":true,"displayName":"TIANJINXINGANG","isDeleted":false,"isInService":true,"isoCode":"CNTXG","timeZoneDifference":8.0,"netpasName":"Xingang (Tianjin)"},"isDeleted":false,"distanceInMiles":1421,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":213},"pilottimeId":8325,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":259},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":10,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308236170000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":213},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559552,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561153}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559550,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308552747000,"isBunkerCall":false,"updateTS":1356617550000,"berthingArrival":1308559947000,"inheritedVoyage":"","adjustmentTime":120,"timeInPort":1680,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":111},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308667947000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8333},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-2.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12649,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":111},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"KRKANCT","isTBN":"false","name":"KWANGYANG CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1001,"codePort":null},{"codeMSC":"KRKANKT","isTBN":"false","name":"KOREA EXPRESS WORLD CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1002,"codePort":null},{"codeMSC":"KRKAN9Z","isTBN":"false","name":"GWANGYANG","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":826,"codePort":null}],"name":"GWANGYANG","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":365,"isRealPort":true,"displayName":"GWANGYANG","isDeleted":false,"isInService":true,"isoCode":"KRKAN","timeZoneDifference":6.0,"netpasName":"Kwangyang"},"isDeleted":false,"distanceInMiles":662,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1253},"pilottimeId":8333,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":111},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1308660747000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1253},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559550,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561146}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559554,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308796768000,"isBunkerCall":false,"updateTS":1356616192000,"berthingArrival":1308803968000,"inheritedVoyage":"","adjustmentTime":180,"timeInPort":660,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":365},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308850768000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8329},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12643,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":365},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"KRPUSTK","isTBN":"false","name":"THE KOREA EXPRESS COMPANY LIMITED","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":609,"codePort":null},{"codeMSC":"KRPUSAB","isTBN":"false","name":"PUSAN NEWPORT INTERNATIONAL TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":610,"codePort":null},{"codeMSC":"KRPUSPN","isTBN":"false","name":"PUSAN NEWPORT COMPANY LIMITED","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":608,"codePort":null},{"codeMSC":"KRPUSPE","isTBN":"false","name":"PUSAN EXPRESS CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":607,"codePort":null},{"codeMSC":"KRPUSEP","isTBN":"false","name":"PUSAN EAST CONTAINER TERMINAL - PECT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":606,"codePort":null},{"codeMSC":"KRPUSAD","isTBN":"false","name":"OLD PORT FEEDER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":983,"codePort":null},{"codeMSC":"KRPUSAE","isTBN":"false","name":"NEWPORT FEEDER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":984,"codePort":null},{"codeMSC":"KRPUSAG","isTBN":"false","name":"KBCT - KOREA EXPRESS BUSAN CONTAINER TERMINAL CO.,","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1347,"codePort":null},{"codeMSC":"KRBUHHI","isTBN":"false","name":"HANJIN HEAVY INDUSTRIES","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":605,"codePort":null},{"codeMSC":"KRPUSDP","isTBN":"false","name":"DONGBU PUSAN CONTAINER TERMINAL - DPCT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":604,"codePort":null},{"codeMSC":"KRBUSPN","isTBN":"false","name":"BUSAN NEW PORT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1276,"codePort":null},{"codeMSC":"KRPUSAF","isTBN":"false","name":"BUSAN NEW CONTAINER TERMINAL - BNCT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1233,"codePort":null},{"codeMSC":"KRPUSBI","isTBN":"false","name":"BUSAN INTERNATIONAL CONTAINER TERMINAL - BICT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":603,"codePort":null}],"name":"BUSAN","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":367,"isRealPort":true,"displayName":"BUSAN","isDeleted":false,"isInService":true,"isoCode":"KRPUS","timeZoneDifference":9.0,"netpasName":"Busan"},"isDeleted":false,"distanceInMiles":106,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1001},"pilottimeId":8329,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":365},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":12,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308843568000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1001},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559554,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561145}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559558,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308871395000,"isBunkerCall":false,"updateTS":1356616192000,"berthingArrival":1308878595000,"inheritedVoyage":"","adjustmentTime":60,"timeInPort":900,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":367},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308939795000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8326},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12645,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":367},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CNTAOAI","isTBN":"false","name":"QINGDAO QIANWAN UNITED CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1198,"codePort":null},{"codeMSC":"CNTAOAK","isTBN":"false","name":"QINGDAO QIANWAN UNITED ADVANCE CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1304,"codePort":null},{"codeMSC":"CNTAOQQ","isTBN":"false","name":"QINGDAO QIANWAN CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":108,"codePort":null},{"codeMSC":"CNTSTQQ","isTBN":"false","name":"QINGDAO QIANWAN CONTAINER CO LTD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1277,"codePort":null}],"name":"QINGDAO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":787,"isRealPort":true,"displayName":"QINGDAO","isDeleted":false,"isInService":true,"isoCode":"CNTAO","timeZoneDifference":8.0,"netpasName":"Qingdao"},"isDeleted":false,"distanceInMiles":499,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":610},"pilottimeId":8326,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":367},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":13,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308932595000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":610},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559558,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561162}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559562,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309039595000,"isBunkerCall":false,"updateTS":1356616192000,"berthingArrival":1309046795000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1260,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":787},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1309129595000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8340},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12644,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":787},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CNNGNYT","isTBN":"false","name":"NINGBO YUANDONG TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1048,"codePort":null},{"codeMSC":"CNNGBAG","isTBN":"false","name":"NINGBO MEISHAN ISLAND INTERNATIONAL CONTAINER TERM","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1202,"codePort":null},{"codeMSC":"CNNDCMT","isTBN":"false","name":"NINGBO DAXIE CHINA MERCHANTS INTERNATIONAL CONTAIN","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":107,"codePort":null},{"codeMSC":"CNNGBBT","isTBN":"false","name":"BEILUN THIRD CONTAINER TERMINALS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":106,"codePort":null},{"codeMSC":"CNNGBBS","isTBN":"false","name":"BEILUN SECOND CONTAINER TERMINALS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":105,"codePort":null},{"codeMSC":"CNNGBBF","isTBN":"false","name":"BEILUN FIRST CONTAINER TERMINALS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":104,"codePort":null}],"name":"NINGBO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":3,"pilotStations":[],"portId":102,"isRealPort":true,"displayName":"NINGBO","isDeleted":false,"isInService":true,"isoCode":"CNNGB","timeZoneDifference":8.0,"netpasName":"Ningbo"},"isDeleted":false,"distanceInMiles":435,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":108},"pilottimeId":8340,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":787},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":14,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309122395000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":108},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559562,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561142}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559566,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309211956000,"isBunkerCall":false,"updateTS":1356616192000,"berthingArrival":1309219156000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":102},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1309291156000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":106},"pilottimeId":8331,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":102},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12640,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":102},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CNSHAWT","isTBN":"false","name":"WAIGAOQIAO CNTR TML PHASE 4 - HU DONG","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":113,"codePort":null},{"codeMSC":"CNSHASS","isTBN":"false","name":"SHANGHAI SHENGDONG INTERNATIONAL CONTAINER TERMINA","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":112,"codePort":null},{"codeMSC":"CNSHACM","isTBN":"false","name":"SHANGHAI MINGDONG CONTAINER TERMINALS LTD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":111,"codePort":null},{"codeMSC":"CNSHABP","isTBN":"false","name":"SHANGHAI INTERNATIONAL PORT GROUP CO LTD - WGQ6","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1203,"codePort":null},{"codeMSC":"CNSHAPG","isTBN":"false","name":"SHANGHAI INTERNATIONAL PORT CO.LTD ZHENDONG CONTAI","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":110,"codePort":null},{"codeMSC":"CNSHAGI","isTBN":"false","name":"SHANGHAI GUANDONG INTERNATIONAL CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1081,"codePort":null},{"codeMSC":"CNSHASE","isTBN":"false","name":"SHANGHAI EAST CONTAINER TERMINAL CO LTD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":109,"codePort":null},{"codeMSC":"CNSHABI","isTBN":"false","name":"SHA YST IV","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1074,"codePort":null},{"codeMSC":"CNSHABH","isTBN":"false","name":"SHA YST III","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1073,"codePort":null},{"codeMSC":"CNSHABG","isTBN":"false","name":"SHA YST I","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1072,"codePort":null},{"codeMSC":"CNSHABK","isTBN":"false","name":"SHA WGQ V","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1076,"codePort":null},{"codeMSC":"CNSHABL","isTBN":"false","name":"SHA WGQ IV","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1077,"codePort":null},{"codeMSC":"CNSHABM","isTBN":"false","name":"SHA WGQ II","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1078,"codePort":null},{"codeMSC":"CNSHABJ","isTBN":"false","name":"SHA WGQ I","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1075,"codePort":null},{"codeMSC":"CNSHABN","isTBN":"false","name":"SHA SCT 10","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1079,"codePort":null},{"codeMSC":"CNSHACS","isTBN":"false","name":"CIC CHANGXING SHIPYARD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1080,"codePort":null}],"name":"SHANGHAI","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":4,"pilotStations":[],"portId":105,"isRealPort":true,"displayName":"SHANGHAI","isDeleted":false,"isInService":true,"isoCode":"CNSHA","timeZoneDifference":8.0,"netpasName":"Shanghai"},"isDeleted":false,"distanceInMiles":143,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":106},"pilottimeId":8332,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":102},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":15,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309283956000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":2,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":106},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559566,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561143}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559563,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309318983000,"isBunkerCall":false,"updateTS":1356616192000,"berthingArrival":1309326183000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":105},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1309398183000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8336},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12639,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":105},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"distanceInMiles":2197,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1081},"pilottimeId":8336,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":105},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":16,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309390983000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1081},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559563,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561157}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559568,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309837583000,"isBunkerCall":false,"updateTS":1356616192000,"berthingArrival":1309844783000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1680,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1309952783000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"pilottimeId":8337,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12638,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"MYPKGWT","isTBN":"false","name":"WESTPORT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":315,"codePort":null},{"codeMSC":"MYPKGNT","isTBN":"false","name":"NORTHPORT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":314,"codePort":null}],"name":"PORT KELANG","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":418,"isRealPort":true,"displayName":"PORT KELANG","isDeleted":false,"isInService":true,"isoCode":"MYPKG","timeZoneDifference":8.0,"netpasName":"Port Kelang"},"isDeleted":false,"distanceInMiles":210,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"pilottimeId":8335,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":17,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309945583000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559568,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561152}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559567,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309994783000,"isBunkerCall":false,"updateTS":1356616192000,"berthingArrival":1310001983000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":900,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":418},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1310063183000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8330},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12637,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":null,"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":418},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"distanceInMiles":4800,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":315},"pilottimeId":8330,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":418},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":18,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":17.3,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1310055983000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":315},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559567,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561156}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559565,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1311040427000,"isBunkerCall":false,"updateTS":1356616192000,"berthingArrival":1311040427000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":60,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1311044027000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8327},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12646,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8327},"sequence":19,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":6.15,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1311044027000,"pilotStation":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559565,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561158}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":559559,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1311092027000,"isBunkerCall":false,"updateTS":1356616203000,"berthingArrival":1311092027000,"inheritedVoyage":"","adjustmentTime":285,"timeInPort":139,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":990,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1311100367000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8327},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-2.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12636,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"distanceInMiles":3272,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8327},"sequence":20,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1311100367000,"pilotStation":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559559,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561161}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":559547,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304438400000,"isBunkerCall":false,"updateTS":1356617550000,"berthingArrival":1311703224000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8334},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12634,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8334},"sequence":21,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356617550000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":995},"insertTS":1356617550000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559547,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561321}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304880350000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":12635,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1356609341000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":54,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":8320,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1356609341000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304851550000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1356609341000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1356609341000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1356609341000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559561,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":561144}],"dieselConsumption":null},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304851550000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372184408547,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":726329}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":726329},"berthingId":221257,"vesselServiceAssignmentId":4061,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"BEZEEAE","isTBN":"false","name":"ZEEBRUGGE INTERNATIONAL PORT (ZIP)","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1366,"codePort":null},{"codeMSC":"BEZEEPT","isTBN":"false","name":"PSA WZ ZIP TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49,"codePort":null},{"codeMSC":"BEZEEAD","isTBN":"false","name":"CONTAINER HANDLING ZEEBRUGGE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1249,"codePort":null}],"name":"ZEEBRUGGE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":744,"isRealPort":true,"displayName":"ZEEBRUGGE","isDeleted":false,"isInService":true,"isoCode":"BEZEE","timeZoneDifference":1.0,"netpasName":"Zeebrugge"},"draftArrivalAFT":null,"pilotArrivalDate":1376621100000,"berthingArrivalDate":1376649900000,"operatorContainerMoves40":null,"customArrivalVoyage":"FS333A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376817720000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":686204,"liveDepartureDate":1376990520000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FS333A","departureVoyage":"FS333A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3043,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC AURORA","vesselId":8161,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3043,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MAUO","dateOutService":null,"dateInService":1331078400000,"code":"08129","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":366.0,"imoNumber":"9484481","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"SILK","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":1345417740000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":7,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"f4a460","laneCode":"SILK","useWeeklyVoyageNumbers":true,"name":"SILK EXPRESS","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":89,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"FS","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376822700000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377640800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372615866047,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727871,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309284047000,"isBunkerCall":false,"updateTS":1373024106000,"berthingArrival":1309312847000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1309485647000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617450,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309456847000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372615866047,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730612}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730612},"berthingId":221262,"vesselServiceAssignmentId":5685,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":null,"pilotArrivalDate":1377439200000,"berthingArrivalDate":1377468000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NG331R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377439260000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":690276,"liveDepartureDate":1377583260000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG331R","departureVoyage":"NG335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3313,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"YM MOBILITY","vesselId":8576,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3313,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MYMB","dateOutService":null,"dateInService":1345161600000,"code":"08492","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":305.6,"imoNumber":"9457737","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377612000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1379192400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NQ337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372218003047,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":723934,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1310986852000,"isBunkerCall":false,"updateTS":1373012410000,"berthingArrival":1311015652000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1311130852000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":21027,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":41.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1311102052000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372218003047,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":726551}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":726551},"berthingId":221265,"vesselServiceAssignmentId":4930,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":null,"pilotArrivalDate":1379048400000,"berthingArrivalDate":1379077200000,"operatorContainerMoves40":null,"customArrivalVoyage":"NQ337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379077200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":686426,"liveDepartureDate":1379163600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NQ337A","departureVoyage":"NQ337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1592,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MAERSK DANVILLE","vesselId":4645,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1592,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1354147140000,"dateInService":1268265600000,"code":"07019","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"JPO CAPRICORNUS","vesselId":8885,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1592,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MJCN","dateOutService":null,"dateInService":1355443200000,"code":"08667","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":264.0,"imoNumber":"9295414","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379163600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373616752000,"noonPositionTelex":null,"pilotDepartureDate":1377482400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NW334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372140026220,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722666,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1315626097000,"isBunkerCall":false,"updateTS":1375867608000,"berthingArrival":1315654897000,"inheritedVoyage":"","adjustmentTime":2396,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1315791697000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22167,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":21.23,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1315762897000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372140026220,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":725279}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":725279},"berthingId":221266,"vesselServiceAssignmentId":1914,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1377316800000,"berthingArrivalDate":1377345600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NW334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377122400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":685184,"liveDepartureDate":1377230400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NW334A","departureVoyage":"NW334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1522,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC LINZIE","vesselId":2490,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1522,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSLZ","dateOutService":1313625540000,"dateInService":1042416000000,"code":"03053","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC ROMANOS","vesselId":5388,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1522,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MRNV","dateOutService":null,"dateInService":1313625600000,"code":"07756","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":294.0,"imoNumber":"9275634","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377453600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373616752000,"noonPositionTelex":null,"pilotDepartureDate":1377950460000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NW335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372748428467,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":729675,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1310071866000,"isBunkerCall":false,"updateTS":1374824129000,"berthingArrival":1310100666000,"inheritedVoyage":"","adjustmentTime":2396,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1310237466000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22167,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":21.23,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1310208666000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372748428467,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":732422}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":732422},"berthingId":221270,"vesselServiceAssignmentId":2967,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1377784860000,"berthingArrivalDate":1377813660000,"operatorContainerMoves40":0,"customArrivalVoyage":"NW335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377678960000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":692063,"liveDepartureDate":1377786960000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NW335A","departureVoyage":"NW335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":2980,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CSAV SUAPE","vesselId":8079,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2980,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MCSU","dateOutService":null,"dateInService":1328227200000,"code":"08064","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":294.1,"imoNumber":"9437048","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377921660000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377604800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RB333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372656612013,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727958,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304877654000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304308800000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304424000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651687,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304395200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372656612013,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730699}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730699},"berthingId":221310,"vesselServiceAssignmentId":5327,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1377460800000,"berthingArrivalDate":1377489600000,"operatorContainerMoves40":null,"customArrivalVoyage":"RB333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377489600000,"customArrivalVoyage":"RB333R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB334A","dailyvesselschedulecellcompactId":690363,"liveDepartureDate":1377576000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB333R","departureVoyage":"RB333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377576000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RB334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372656612013,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727961,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304884854000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304913654000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372656612013,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730702}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730702},"berthingId":221311,"vesselServiceAssignmentId":5327,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1378065600000,"berthingArrivalDate":1378094400000,"operatorContainerMoves40":null,"customArrivalVoyage":"RB334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378094400000,"customArrivalVoyage":"RB334R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB334R","dailyvesselschedulecellcompactId":690366,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB334R","departureVoyage":"RB334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"operatorContainerMoves20":0,"updateTS":1374854382000,"noonPositionTelex":null,"pilotDepartureDate":1377669600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RM335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"deleteUser":null,"updateTS":1374854381000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374854381000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":748738,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306240050000,"isBunkerCall":false,"updateTS":1374854576000,"berthingArrival":1306268850000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":3918,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1306384050000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12890},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":13152,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12890},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.9,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":676870,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949600000,"isBunkerCall":false,"updateTS":1367249564000,"berthingArrival":1304978400000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":3918,"proformaVesselSchedule":{"proformavesselscheduleId":1359,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"deleteUser":null,"updateTS":1371637238000,"isMaster":false,"isDeleted":false,"insertTS":1367249564000,"isInService":true,"versionInfo":"Le Verdon Montoir Brest","version":5,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":676871,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306021440000,"isBunkerCall":false,"updateTS":1367249564000,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":256,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1359,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304928000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12888},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":15420,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"pilottimeId":12888,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1367249564000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":2.6,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304920800000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1367249564000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"insertTS":1367249564000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":676871,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":679185}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":676870,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":676872,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305374400000,"isBunkerCall":false,"updateTS":1367249564000,"berthingArrival":1305381600000,"inheritedVoyage":"","adjustmentTime":29,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":9,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1359,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305446400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12885},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13145,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357233776000,"portFrom":{"isTBN":"false","terminals":[{"codeMSC":"FRLVEVV","isTBN":"false","name":"VAT - VERDON AQUITAINE TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":175,"codePort":null}],"name":"LE VERDON","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":2,"pilotStations":[],"portId":757,"isRealPort":true,"displayName":"LE VERDON","isDeleted":false,"isInService":true,"isoCode":"FRLVE","timeZoneDifference":1.0,"netpasName":"Le Verdon"},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":485,"insertTS":1357233776000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":12885,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1367249564000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":48.5,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305439200000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1367249564000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1367249564000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":676872,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":679188}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":676874,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305561600000,"isBunkerCall":false,"updateTS":1367249564000,"berthingArrival":1305568800000,"inheritedVoyage":"","adjustmentTime":42,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":757},"isDeleted":false,"bufferTime":86,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1359,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305684000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12887},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":15421,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"deleteUser":null,"pilotStationFrom":null,"updateTS":1358528439000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":757},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":208},"isDeleted":false,"distanceInMiles":133,"insertTS":1358528439000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":175},"pilottimeId":12887,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":757},"isDeleted":false,"insertTS":1367249564000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":13.3,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305676800000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367249564000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":175},"insertTS":1367249564000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":676874,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":679183}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":676873,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305723600000,"isBunkerCall":false,"updateTS":1367249564000,"berthingArrival":1305727200000,"inheritedVoyage":"","adjustmentTime":20,"timeInPort":1620,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":208},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1359,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305828000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12889},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":15419,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":177},"pilottimeId":12889,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":208},"isDeleted":false,"insertTS":1367249564000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":15.5,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305824400000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367249564000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":177},"insertTS":1367249564000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":676873,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":679186}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":676875,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305864000000,"isBunkerCall":false,"updateTS":1367249564000,"berthingArrival":1305871200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":753},"isDeleted":false,"bufferTime":616,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1359,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305921600000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":167},"pilottimeId":12886,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":753},"isDeleted":false,"insertTS":1367249564000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6449,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":167},"pilottimeId":12891,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":753},"isDeleted":false,"insertTS":1367249564000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":44.6,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305914400000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1367249564000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":167},"insertTS":1367249564000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":676875,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":679189}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":676869,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306065600000,"isBunkerCall":false,"updateTS":1367249564000,"berthingArrival":1306072800000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12888},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":15420,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12888},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":2.6,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1367249564000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"insertTS":1367249564000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":676869,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":679187}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1305093600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12890},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":13152,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":12890,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1367249564000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.9,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305064800000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1367249564000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1367249564000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1367249564000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":676870,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":679184}],"dieselConsumption":null},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306355250000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374854381000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":751829}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"proformavesselscheduleterminalcallId":751829},"berthingId":221312,"vesselServiceAssignmentId":4472,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1377525600000,"berthingArrivalDate":1377554400000,"operatorContainerMoves40":0,"customArrivalVoyage":"RM335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377554400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":711161,"liveDepartureDate":1377640800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RM335A","departureVoyage":"RM335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3593,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"FRISIA BONN","vesselId":8996,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3593,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"WFRB","dateOutService":null,"dateInService":1360713600000,"code":"08776","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9470961","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377640800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377468000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372491620750,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727680,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306513410000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304748000000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":750,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304892000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304863200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372491620750,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730418}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730418},"berthingId":221315,"vesselServiceAssignmentId":2972,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1377295200000,"berthingArrivalDate":1377324000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NP333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377324000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":690085,"liveDepartureDate":1377439200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP333R","departureVoyage":"NP334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1293,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377439200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372491620750,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727690,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306533630000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306562430000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681491,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372491620750,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730429}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730429},"berthingId":221316,"vesselServiceAssignmentId":2972,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":null,"pilotArrivalDate":1379109600000,"berthingArrivalDate":1379138400000,"operatorContainerMoves40":null,"customArrivalVoyage":"NP336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379138400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":690095,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP336R","departureVoyage":"NP336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1293,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377921600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NZ334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372446941123,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727408,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305165602000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305198002000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305345602000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13480},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701517,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305313202000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372446941123,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730146}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730146},"berthingId":221320,"vesselServiceAssignmentId":5486,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":null,"pilotArrivalDate":1377741600000,"berthingArrivalDate":1377774000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NZ334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378006800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":689817,"liveDepartureDate":1378122000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NZ334A","departureVoyage":"NZ334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1556,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC LUCY","vesselId":3099,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1556,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSLY","dateOutService":null,"dateInService":1115856000000,"code":"04745","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":324.8,"imoNumber":"9289104","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372783708840,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377889200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1378965600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372806021920,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":730602,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308628094000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304460000000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304575200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374699,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304546400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372806021920,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":733350}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":733350},"berthingId":221324,"vesselServiceAssignmentId":1036,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":null,"pilotArrivalDate":1378821600000,"berthingArrivalDate":1378850400000,"operatorContainerMoves40":null,"customArrivalVoyage":"NA333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378850400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":692979,"liveDepartureDate":1378936800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA333R","departureVoyage":"NA337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1353,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372859978143,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378936800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373628357000,"noonPositionTelex":null,"pilotDepartureDate":1377784800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372832706953,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":730750,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305650141000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304604000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382113,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304575200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372832706953,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":733504}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":733504},"berthingId":221326,"vesselServiceAssignmentId":5704,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1377640800000,"berthingArrivalDate":1377669600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377565200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":693127,"liveDepartureDate":1377651600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH333R","departureVoyage":"BH335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3240,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372859978143,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377756000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373628357000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372832706953,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":730758,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305698441000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382107,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372832706953,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":733512}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":733512},"berthingId":221327,"vesselServiceAssignmentId":5704,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1378850400000,"berthingArrivalDate":1378879200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378774800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":693135,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH335R","departureVoyage":"BH335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3240,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1372859978143,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377456780000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FS334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372792808703,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":730459,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Soon Peng Andy TAN","userId":8412},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1326736024000,"isBunkerCall":false,"updateTS":1373599658000,"berthingArrival":1326764824000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1326966424000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12635,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559561,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1326937624000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372792808703,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":733207}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":733207},"berthingId":221330,"vesselServiceAssignmentId":4759,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"draftArrivalAFT":null,"pilotArrivalDate":1377226380000,"berthingArrivalDate":1377255180000,"operatorContainerMoves40":null,"customArrivalVoyage":"FS334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377269520000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":692836,"liveDepartureDate":1377442320000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FS334A","departureVoyage":"FS334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1879,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC BETTINA","vesselId":4427,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1879,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MBET","dateOutService":null,"dateInService":1253059200000,"code":"06704","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":366.0,"imoNumber":"9399038","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372859978143,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377427980000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1379797200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NQ338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372819202920,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":730633,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1320015740000,"isBunkerCall":false,"updateTS":1375868832000,"berthingArrival":1320044540000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1320159740000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":21027,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":41.58,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1320130940000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372819202920,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":733381}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":733381},"berthingId":221332,"vesselServiceAssignmentId":4931,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":null,"pilotArrivalDate":1379653200000,"berthingArrivalDate":1379682000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NQ338A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379682000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":693010,"liveDepartureDate":1379768400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NQ338A","departureVoyage":"NQ338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1926,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CSAV LLANQUIHUE","vesselId":5506,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1926,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVLQ","dateOutService":null,"dateInService":1319932800000,"code":"07866","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":261.0,"imoNumber":"9431800","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372859978143,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379768400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1377856800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372892709783,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":731631,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306933252000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304546400000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304661600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4046,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304632800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372892709783,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":734394}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":734394},"berthingId":221342,"vesselServiceAssignmentId":5545,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":null,"pilotArrivalDate":1377712800000,"berthingArrivalDate":1377741600000,"operatorContainerMoves40":null,"customArrivalVoyage":"692W31","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377727200000,"customArrivalVoyage":"692E33","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"693W35","dailyvesselschedulecellcompactId":694004,"liveDepartureDate":1377813600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"692E33","departureVoyage":"692E33","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1337,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372937024767,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377828000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372892709783,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":731637,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372892709783,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":734400}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":734400},"berthingId":221343,"vesselServiceAssignmentId":5545,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":null,"pilotArrivalDate":1380132000000,"berthingArrivalDate":1380160800000,"operatorContainerMoves40":null,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380146400000,"customArrivalVoyage":"693E37","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"693E37","dailyvesselschedulecellcompactId":694010,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"693E37","departureVoyage":"693E37","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1337,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372937024767,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":null,"operatorContainerMoves20":null,"updateTS":null,"noonPositionTelex":null,"pilotDepartureDate":1378015200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NM335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372923310677,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":731845,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304690440000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304719240000,"inheritedVoyage":"","adjustmentTime":92,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304834440000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2734,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55406,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805640000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372923310677,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":734613}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":734613},"berthingId":221344,"vesselServiceAssignmentId":693,"draftDeparture":null,"isLocked":false,"draftArrivalFW":null,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":null,"pilotArrivalDate":1377871200000,"berthingArrivalDate":1377900000000,"operatorContainerMoves40":null,"customArrivalVoyage":"NM335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377900000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":694218,"liveDepartureDate":1377986400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NM335A","departureVoyage":"NM335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":null,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1000},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1781,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC CORDOBA","vesselId":4020,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1781,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVCR","dateOutService":null,"dateInService":1202860800000,"code":"05989","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":275.0,"imoNumber":"9349801","vesselServiceChange":null},"operatorReeferMoves":null,"amountOfRestows":null,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":null,"insertTS":1372937024767,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377986400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"operatorFullMoves":null},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1373549802000,"noonPositionTelex":null,"pilotDepartureDate":1377619200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1373549801000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373549801000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":738103,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304294400000,"isBunkerCall":false,"updateTS":1373549801000,"berthingArrival":1304323200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304438400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":200338,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305486030000,"isBunkerCall":false,"updateTS":1355933520000,"berthingArrival":1304323200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":515,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"deleteUser":null,"updateTS":1355933520000,"isMaster":false,"isDeleted":false,"insertTS":1345477994000,"isInService":true,"versionInfo":"testnewprof","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":200338,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":323911,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304497800000,"isBunkerCall":false,"updateTS":1355933520000,"berthingArrival":1304512200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":515,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304613000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":502},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6053,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1347270514000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"distanceInMiles":280,"insertTS":1347270514000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":502},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304598600000,"pilotStation":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1347270514000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1347270514000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"insertTS":1347270514000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":323911,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":324537}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":200337,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304679600000,"isBunkerCall":false,"updateTS":1355933561000,"berthingArrival":1304686800000,"inheritedVoyage":"","adjustmentTime":120,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":515,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304737200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3530},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3307,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"deleteUser":null,"pilotStationFrom":null,"updateTS":1333031495000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"distanceInMiles":1041,"insertTS":1333031495000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345477994000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"pilottimeId":3530,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"insertTS":1345477994000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304730000000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1345477994000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345477994000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"insertTS":1345477994000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200337,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":200583}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":200339,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304964225000,"isBunkerCall":false,"updateTS":1355933520000,"berthingArrival":1304967825000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"bufferTime":128,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":515,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305014625000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3532},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3306,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"deleteUser":null,"pilotStationFrom":null,"updateTS":1333031495000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":920,"insertTS":1333031495000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345477994000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"pilottimeId":3532,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"insertTS":1345477994000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305011025000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1345477994000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345477994000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"insertTS":1345477994000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200339,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":200582}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":200340,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305232905000,"isBunkerCall":false,"updateTS":1347270514000,"berthingArrival":1305240105000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":515,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305290505000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3533},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6050,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"deleteUser":null,"pilotStationFrom":null,"updateTS":1347270514000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":410,"insertTS":1347270514000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345477994000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":3533,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1345477994000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305283305000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1345477994000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345477994000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1345477994000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200340,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":200585}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":323912,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305382755000,"isBunkerCall":false,"updateTS":1347270514000,"berthingArrival":1305393555000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":515,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305447555000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":264},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3285,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1332941947000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":251,"insertTS":1332941947000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":264},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305436755000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1347270514000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1347270514000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1347270514000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":323912,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":324538}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":200335,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304294400000,"isBunkerCall":false,"updateTS":1355933561000,"berthingArrival":1305532800000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1347270514000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"distanceInMiles":264,"insertTS":1347270514000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345477994000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":3531,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1345477994000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1345477994000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1355933561000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1355933561000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200335,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":557102}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304438400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304409600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1345477994000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1345477994000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1345477994000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200338,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":200584}],"dieselConsumption":null},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304409600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373549801000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":741047}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":741047},"berthingId":221579,"vesselServiceAssignmentId":5794,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1377475200000,"berthingArrivalDate":1377504000000,"operatorContainerMoves40":0,"customArrivalVoyage":"335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377504000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":700576,"liveDepartureDate":1377590400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"335A","departureVoyage":"335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3016,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"TBN FEEDER","vesselId":2616,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3016,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":null,"dateInService":1048636800000,"code":"03243","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":true,"length":null,"imoNumber":"99999992","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"TMW","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":1323182300000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"0000cd","laneCode":"TS127","useWeeklyVoyageNumbers":true,"name":"Test Service Matthew","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":127,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":null,"dailyVesselScheduleAllowedDelay":300,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373549802000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377590400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1373549802000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1373549801000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373549801000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":738121,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305504000000,"isBunkerCall":false,"updateTS":1373549801000,"berthingArrival":1305532800000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200335,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373549801000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":741036}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":741036},"berthingId":221591,"vesselServiceAssignmentId":5794,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1378684800000,"berthingArrivalDate":1378713600000,"operatorContainerMoves40":0,"customArrivalVoyage":"336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378713600000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":700557,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"336R","departureVoyage":"336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3016,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373549802000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1373549802000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1373549801000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373549801000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":738094,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305504000000,"isBunkerCall":false,"updateTS":1373549801000,"berthingArrival":1305532800000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200335,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373549801000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":741058}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":741058},"berthingId":221616,"vesselServiceAssignmentId":5794,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1377475200000,"berthingArrivalDate":1377504000000,"operatorContainerMoves40":0,"customArrivalVoyage":"334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377504000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":700596,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"334R","departureVoyage":"334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3016,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373549802000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1373550187000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1373550186000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373550186000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":738185,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305504000000,"isBunkerCall":false,"updateTS":1373550186000,"berthingArrival":1305532800000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200335,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373550186000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":741137}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":741137},"berthingId":221654,"vesselServiceAssignmentId":5795,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1377475200000,"berthingArrivalDate":1377504000000,"operatorContainerMoves40":0,"customArrivalVoyage":"334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377504000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":700655,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"334R","departureVoyage":"334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3015,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"TBN","vesselId":2617,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3015,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":null,"dateInService":1048636800000,"code":"03244","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":true,"length":null,"imoNumber":"99999991","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373550187000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1373550187000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1373550186000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373550186000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":738186,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305504000000,"isBunkerCall":false,"updateTS":1373550186000,"berthingArrival":1305532800000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200335,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373550186000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":741147}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":741147},"berthingId":221663,"vesselServiceAssignmentId":5795,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1378684800000,"berthingArrivalDate":1378713600000,"operatorContainerMoves40":0,"customArrivalVoyage":"336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378713600000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":700649,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"336R","departureVoyage":"336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3015,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373550187000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1373550187000,"noonPositionTelex":null,"pilotDepartureDate":1377619200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1373550186000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373550186000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":738180,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304294400000,"isBunkerCall":false,"updateTS":1373550186000,"berthingArrival":1304323200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304438400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200338,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304409600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373550186000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":741130}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":741130},"berthingId":221667,"vesselServiceAssignmentId":5795,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1377475200000,"berthingArrivalDate":1377504000000,"operatorContainerMoves40":0,"customArrivalVoyage":"335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377504000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":700652,"liveDepartureDate":1377590400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"335A","departureVoyage":"335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3015,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373550187000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377590400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1373554110000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP337R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373093716253,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":733951,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306533630000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306562430000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681491,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373093716253,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":736735}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":736735},"berthingId":221678,"vesselServiceAssignmentId":4913,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1379714400000,"berthingArrivalDate":1379743200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NP337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379743200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":696293,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP337R","departureVoyage":"NP337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1042,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373554110000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1373554110000,"noonPositionTelex":null,"pilotDepartureDate":1378072800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373093716253,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":733941,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306513410000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304748000000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":750,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304892000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304863200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373093716253,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":736724}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":736724},"berthingId":221689,"vesselServiceAssignmentId":4913,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1377900000000,"berthingArrivalDate":1377928800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NP334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377928800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":696283,"liveDepartureDate":1378044000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP334R","departureVoyage":"NP335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1042,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373554110000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378044000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1373555183000,"noonPositionTelex":null,"pilotDepartureDate":1378231200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373224832253,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734559,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309284047000,"isBunkerCall":false,"updateTS":1373904448000,"berthingArrival":1309312847000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1309485647000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617450,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309456847000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373224832253,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737350}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737350},"berthingId":221804,"vesselServiceAssignmentId":5735,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":0.0,"pilotArrivalDate":1378029600000,"berthingArrivalDate":1378058400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NG332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378319460000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":696899,"liveDepartureDate":1378463460000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG332R","departureVoyage":"NG336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1588,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC TOKYO","vesselId":3244,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1588,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVTK","dateOutService":null,"dateInService":1119916800000,"code":"04902","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":274.7,"imoNumber":"9295361","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373555183000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378202400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1373904450000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"deleteUser":null,"updateTS":1373904448000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373904448000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740311,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308990447000,"isBunkerCall":false,"updateTS":1373904448000,"berthingArrival":1309019247000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617446,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373904448000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":743286}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"proformavesselscheduleterminalcallId":743286},"berthingId":221875,"vesselServiceAssignmentId":5735,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":0.0,"pilotArrivalDate":1378029600000,"berthingArrivalDate":1378058400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NG332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378319460000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":702772,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG332R","departureVoyage":"NG332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1588,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373555183000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1373555183000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG331R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"deleteUser":null,"updateTS":1373024106000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373024106000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":733062,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308990447000,"isBunkerCall":false,"updateTS":1373024106000,"berthingArrival":1309019247000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":15,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617446,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373024106000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":735844}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"proformavesselscheduleterminalcallId":735844},"berthingId":221894,"vesselServiceAssignmentId":5685,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":0.0,"pilotArrivalDate":1377424800000,"berthingArrivalDate":1377453600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NG331R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377439260000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":695412,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG331R","departureVoyage":"NG331R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3313,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373555183000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"operatorContainerMoves20":0,"updateTS":1373555892000,"noonPositionTelex":null,"pilotDepartureDate":1378209600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RB335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373258408783,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734661,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304877654000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304308800000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304424000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651687,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304395200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373258408783,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737452}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737452},"berthingId":221976,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1378065600000,"berthingArrivalDate":1378094400000,"operatorContainerMoves40":0,"customArrivalVoyage":"RB334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378094400000,"customArrivalVoyage":"RB334R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB335A","dailyvesselschedulecellcompactId":697001,"liveDepartureDate":1378180800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB334R","departureVoyage":"RB334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Agnello MARESCA","userId":21897},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373555892000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378180800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"operatorContainerMoves20":0,"updateTS":1373555892000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RB335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373258408783,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734664,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304884854000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304913654000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373258408783,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737455}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737455},"berthingId":221983,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1378670400000,"berthingArrivalDate":1378699200000,"operatorContainerMoves40":0,"customArrivalVoyage":"RB335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378699200000,"customArrivalVoyage":"RB335R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB335R","dailyvesselschedulecellcompactId":697004,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB335R","departureVoyage":"RB335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373555892000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1373555974000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373496006187,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":737645,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373496006187,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":740458}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":740458},"berthingId":222021,"vesselServiceAssignmentId":527,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":0.0,"pilotArrivalDate":1380722400000,"berthingArrivalDate":1380751200000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380751200000,"customArrivalVoyage":"27E38","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"27E38","dailyvesselschedulecellcompactId":699973,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"27E38","departureVoyage":"27E38","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1265,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373555974000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1373555974000,"noonPositionTelex":null,"pilotDepartureDate":1378447200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373496006187,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":737639,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306933252000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304546400000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304661600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4046,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304632800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373496006187,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":740452}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":740452},"berthingId":222027,"vesselServiceAssignmentId":527,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":0.0,"pilotArrivalDate":1378303200000,"berthingArrivalDate":1378332000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378332000000,"customArrivalVoyage":"26E34","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"27W36","dailyvesselschedulecellcompactId":699967,"liveDepartureDate":1378418400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"26E34","departureVoyage":"26E34","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1265,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373555974000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378418400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8412},"operatorContainerMoves20":0,"updateTS":1373598702000,"noonPositionTelex":null,"pilotDepartureDate":1378061100000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FS335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373394909657,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":736604,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304649950000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304678750000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304880350000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12635,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559561,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304851550000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373394909657,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":739407}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":739407},"berthingId":223154,"vesselServiceAssignmentId":5698,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"draftArrivalAFT":0.0,"pilotArrivalDate":1377830700000,"berthingArrivalDate":1377859500000,"operatorContainerMoves40":0,"customArrivalVoyage":"FS335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378133940000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":698933,"liveDepartureDate":1378306740000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FS335A","departureVoyage":"FS335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8412},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3164,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC KATRINA","vesselId":8366,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3164,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSKT","dateOutService":null,"dateInService":1337126400000,"code":"08308","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":366.0,"imoNumber":"9467445","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373598702000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378032300000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20111},"operatorContainerMoves20":0,"updateTS":1373613102000,"noonPositionTelex":null,"pilotDepartureDate":1378792800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NC336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373357402593,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":735990,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304843432000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304872232000,"inheritedVoyage":"","adjustmentTime":97,"timeInPort":1770,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007232000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2673,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52229,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978432000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373357402593,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":738790}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":738790},"berthingId":223834,"vesselServiceAssignmentId":5162,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1378629000000,"berthingArrivalDate":1378657800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NC336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378657800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":698329,"liveDepartureDate":1378764000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NC336A","departureVoyage":"NC336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Eleftherios MANIATIS","userId":20111},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1784,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC TAMARA","vesselId":3995,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1784,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MTAM","dateOutService":null,"dateInService":1200268800000,"code":"05942","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":265.0,"imoNumber":"9351579","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373613102000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378764000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373616752000,"noonPositionTelex":null,"pilotDepartureDate":1378468800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NW336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373350226390,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":735804,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1310071866000,"isBunkerCall":false,"updateTS":1375451172000,"berthingArrival":1310100666000,"inheritedVoyage":"","adjustmentTime":2396,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1310237466000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22167,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":21.23,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1310208666000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373350226390,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":738601}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":738601},"berthingId":224874,"vesselServiceAssignmentId":3577,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1378303200000,"berthingArrivalDate":1378332000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NW336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378314060000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":698143,"liveDepartureDate":1378422060000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NW336A","departureVoyage":"NW336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1709,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC LORENA","vesselId":3475,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1709,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSLO","dateOutService":null,"dateInService":1138579200000,"code":"05151","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":275.0,"imoNumber":"9320403","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373616752000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378440000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1373617474000,"noonPositionTelex":null,"pilotDepartureDate":1378620000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NM336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373526606000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":737819,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304690440000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304719240000,"inheritedVoyage":"","adjustmentTime":92,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304834440000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2734,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55406,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805640000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373526606000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":740634}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":740634},"berthingId":225389,"vesselServiceAssignmentId":1775,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1378476000000,"berthingArrivalDate":1378504800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NM336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378504800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":700144,"liveDepartureDate":1378591200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NM336A","departureVoyage":"NM336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Charalampos KARAKASIS","userId":20110},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1712,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373617474000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378591200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373619991000,"noonPositionTelex":null,"pilotDepartureDate":1380402000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NQ339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373428503233,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":736762,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1320015740000,"isBunkerCall":false,"updateTS":1375868874000,"berthingArrival":1320044540000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1320159740000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":21027,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":41.58,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1320130940000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373428503233,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":739565}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":739565},"berthingId":225756,"vesselServiceAssignmentId":4925,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1380258000000,"berthingArrivalDate":1380286800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NQ339A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380286800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":699091,"liveDepartureDate":1380373200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NQ339A","departureVoyage":"NQ339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1947,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CSAV LUMACO","vesselId":5532,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1947,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVLC","dateOutService":null,"dateInService":1320537600000,"code":"07890","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":261.0,"imoNumber":"9443487","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373619991000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380373200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620021000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BA331R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373007736000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373007736000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732779,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305957600000,"isBunkerCall":false,"updateTS":1373007736000,"berthingArrival":1305986400000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732081,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305957600000,"isBunkerCall":false,"updateTS":1372930726000,"berthingArrival":1305986400000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":14295},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1342803173763,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"isDeleted":false,"distanceInMiles":1311,"insertTS":1342803173763,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Mario VINACCIA","userId":14295}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930726000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":14832,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1372930726000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372930726000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930726000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372930726000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732081,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":734853}],"dieselConsumption":null},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373007736000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":735564}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":735564},"berthingId":225895,"vesselServiceAssignmentId":5311,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"RULEDNM","isTBN":"false","name":"NEVA METALL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":419,"codePort":null},{"codeMSC":"RULEMDK","isTBN":"false","name":"MOBY DIK - KRONSHTADT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":418,"codePort":null},{"codeMSC":"RULEDFF","isTBN":"false","name":"FCT - FIRST CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417,"codePort":null},{"codeMSC":"RULEDAH","isTBN":"false","name":"CONTAINER TERMINAL SAINT-PETERSBURG","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640,"codePort":null}],"name":"ST PETERSBURG","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":6,"pilotStations":[],"portId":525,"isRealPort":true,"displayName":"ST PETERSBURG","isDeleted":false,"isInService":true,"isoCode":"RULED","timeZoneDifference":3.0,"netpasName":"Saint Petersburg"},"draftArrivalAFT":0.0,"pilotArrivalDate":1376719200000,"berthingArrivalDate":1376748000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BA331R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376748000000,"customArrivalVoyage":"BA331R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA331R","dailyvesselschedulecellcompactId":695142,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA331R","departureVoyage":"BA331R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC JOY","vesselId":4863,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MJOY","dateOutService":null,"dateInService":1286150400000,"code":"07282","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"NORTHERN JOY","vesselId":7299,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MNJY","dateOutService":1238716740000,"dateInService":1219968000000,"code":"06282","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":202.0,"imoNumber":"9039250","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"BAL1","isStandardMSCVoyageCoding":false,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ff6347","laneCode":"BALT1","useWeeklyVoyageNumbers":false,"name":"BALTIC LOOP 01","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":7,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"BA","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620021000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620021000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BA335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373126101987,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734379,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305957600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305986400000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732081,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373126101987,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737164}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737164},"berthingId":225898,"vesselServiceAssignmentId":5311,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1379138400000,"berthingArrivalDate":1379167200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BA335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379167200000,"customArrivalVoyage":"BA335R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA335R","dailyvesselschedulecellcompactId":696719,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA335R","departureVoyage":"BA335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620021000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620021000,"noonPositionTelex":null,"pilotDepartureDate":1378101600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BA335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373126101987,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734377,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305861840000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304776800000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":1680,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304920800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732082,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305861840000,"isBunkerCall":false,"updateTS":1372930726000,"berthingArrival":1304776800000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":1680,"proformaVesselSchedule":{"proformavesselscheduleId":1503,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"deleteUser":null,"updateTS":1372930726000,"isMaster":false,"isDeleted":false,"insertTS":1372930726000,"isInService":true,"versionInfo":"vers. 06/2013","version":11,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":732082,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":732083,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305345600000,"isBunkerCall":false,"updateTS":1372930726000,"berthingArrival":1305363600000,"inheritedVoyage":"","adjustmentTime":24,"timeInPort":3060,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"isDeleted":false,"bufferTime":1440,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1503,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305565200000,"departurePilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930726000,"pilotOnOffBoard":300.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"pilottimeId":14830,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"isDeleted":false,"insertTS":1372930726000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":-2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930726000,"pilotOnOffBoard":300.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"pilottimeId":14831,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"isDeleted":false,"insertTS":1372930726000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"sequence":2,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305547200000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1372930726000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930726000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"insertTS":1372930726000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732083,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":734850},{"sequence":2,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930726000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"insertTS":1372930726000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732083,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":734851}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":732081,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304920800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304892000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372930726000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930726000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372930726000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732082,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":734852}],"dieselConsumption":null},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304892000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373126101987,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737161}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737161},"berthingId":225901,"vesselServiceAssignmentId":5311,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1377928800000,"berthingArrivalDate":1377957600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BA333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377957600000,"customArrivalVoyage":"BA333R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA335A","dailyvesselschedulecellcompactId":696717,"liveDepartureDate":1378072800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA333R","departureVoyage":"BA333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620021000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378072800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620021000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BA334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373007736000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373007736000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732787,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305957600000,"isBunkerCall":false,"updateTS":1373007736000,"berthingArrival":1305986400000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732081,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373007736000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":735547}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":735547},"berthingId":225902,"vesselServiceAssignmentId":2920,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1378533600000,"berthingArrivalDate":1378562400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BA334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378562400000,"customArrivalVoyage":"BA334R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA334R","dailyvesselschedulecellcompactId":695151,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA334R","departureVoyage":"BA334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":770,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC LIESELOTTE","vesselId":2577,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":770,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1333584000000,"dateInService":1051574400000,"code":"03186","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC LIESELOTTE","vesselId":8309,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":770,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSLE","dateOutService":null,"dateInService":1333670400000,"code":"08253","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":203.0,"imoNumber":"8201674","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620021000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620021000,"noonPositionTelex":null,"pilotDepartureDate":1377496800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BA334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373007736000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373007736000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732772,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304748000000,"isBunkerCall":false,"updateTS":1373007736000,"berthingArrival":1304776800000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":1680,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304920800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732082,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304892000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373007736000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":735553}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":735553},"berthingId":225905,"vesselServiceAssignmentId":2920,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1377324000000,"berthingArrivalDate":1377352800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BA332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377352800000,"customArrivalVoyage":"BA332R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA334A","dailyvesselschedulecellcompactId":695155,"liveDepartureDate":1377468000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA332R","departureVoyage":"BA332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":770,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620021000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377468000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620021000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BA333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373007736000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373007736000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732789,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305957600000,"isBunkerCall":false,"updateTS":1373007736000,"berthingArrival":1305986400000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732081,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373007736000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":735563}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":735563},"berthingId":225906,"vesselServiceAssignmentId":5311,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1377928800000,"berthingArrivalDate":1377957600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BA333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377957600000,"customArrivalVoyage":"BA333R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA333R","dailyvesselschedulecellcompactId":695154,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA333R","departureVoyage":"BA333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620021000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620021000,"noonPositionTelex":null,"pilotDepartureDate":1376892000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BA333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373007736000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373007736000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732774,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304748000000,"isBunkerCall":false,"updateTS":1373007736000,"berthingArrival":1304776800000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":1680,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304920800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732082,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304892000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373007736000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":735556}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":735556},"berthingId":225909,"vesselServiceAssignmentId":5311,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1376719200000,"berthingArrivalDate":1376748000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BA331R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376748000000,"customArrivalVoyage":"BA331R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA333A","dailyvesselschedulecellcompactId":695153,"liveDepartureDate":1376863200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA331R","departureVoyage":"BA331R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620021000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376863200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620021000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BA332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373007736000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373007736000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732791,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305957600000,"isBunkerCall":false,"updateTS":1373007736000,"berthingArrival":1305986400000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732081,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373007736000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":735562}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":735562},"berthingId":225910,"vesselServiceAssignmentId":2920,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1377324000000,"berthingArrivalDate":1377352800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BA332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377352800000,"customArrivalVoyage":"BA332R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA332R","dailyvesselschedulecellcompactId":695137,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA332R","departureVoyage":"BA332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":770,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620021000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620298000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BB336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373382905343,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":736277,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304402400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305640801000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403966,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373382905343,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":739080}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":739080},"berthingId":226037,"vesselServiceAssignmentId":3063,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":0.0,"pilotArrivalDate":1379397600000,"berthingArrivalDate":1379426400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BB336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379426400000,"customArrivalVoyage":"BB336R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB336R","dailyvesselschedulecellcompactId":698616,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB336R","departureVoyage":"BB336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620298000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373620298000,"noonPositionTelex":null,"pilotDepartureDate":1378332000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BB336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373382905343,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":736273,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305551521000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304431200000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304546400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403968,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304517600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373382905343,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":739076}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":739076},"berthingId":226041,"vesselServiceAssignmentId":3063,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":0.0,"pilotArrivalDate":1378188000000,"berthingArrivalDate":1378216800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BB334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378216800000,"customArrivalVoyage":"BB334R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB336A","dailyvesselschedulecellcompactId":698612,"liveDepartureDate":1378303200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB334R","departureVoyage":"BB334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620298000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378303200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373620912000,"noonPositionTelex":null,"pilotDepartureDate":1379570400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373408135843,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":736686,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308628094000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304460000000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304575200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374699,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304546400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373408135843,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":739489}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":739489},"berthingId":226088,"vesselServiceAssignmentId":5102,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":0.0,"pilotArrivalDate":1379426400000,"berthingArrivalDate":1379455200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NA334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379455200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":699015,"liveDepartureDate":1379541600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA334R","departureVoyage":"NA338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3542,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373620912000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379541600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373621319000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373323507437,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":735710,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304344800000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305583245000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439877,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373323507437,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":738506}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":738506},"berthingId":226577,"vesselServiceAssignmentId":5733,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1379340000000,"berthingArrivalDate":1379368800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379448000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":698049,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC336R","departureVoyage":"BC336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1379,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"SANDY RICKMERS","vesselId":4317,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1379,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MRIK","dateOutService":null,"dateInService":1237680000000,"code":"06544","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":158.5,"imoNumber":"9220079","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373621319000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373621319000,"noonPositionTelex":null,"pilotDepartureDate":1378274400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373323507437,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":735703,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305543885000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304373600000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304488800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439882,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304460000000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373323507437,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":738499}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":738499},"berthingId":226582,"vesselServiceAssignmentId":5733,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1378130400000,"berthingArrivalDate":1378159200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378260000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":698042,"liveDepartureDate":1378346400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC334R","departureVoyage":"BC336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1379,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373621319000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378245600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373621319000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930126000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372930126000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732009,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305554445000,"isBunkerCall":false,"updateTS":1372930126000,"berthingArrival":1305583245000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439877,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372930126000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":734778}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":734778},"berthingId":226589,"vesselServiceAssignmentId":5733,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1378130400000,"berthingArrivalDate":1378159200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378260000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":694407,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC334R","departureVoyage":"BC334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1379,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373621319000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373621319000,"noonPositionTelex":null,"pilotDepartureDate":1377064800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930126000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372930126000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732008,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304344800000,"isBunkerCall":false,"updateTS":1372930126000,"berthingArrival":1304373600000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304488800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439882,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304460000000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372930126000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":734786}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":734786},"berthingId":226594,"vesselServiceAssignmentId":5733,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1376920800000,"berthingArrivalDate":1376949600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377072000000,"customArrivalVoyage":"BC332R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":694406,"liveDepartureDate":1377158400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC332R","departureVoyage":"BC334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1379,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373621319000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377036000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373621319000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC332R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1372930126000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1372930126000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":732029,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305554445000,"isBunkerCall":false,"updateTS":1372930126000,"berthingArrival":1305583245000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439877,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1372930126000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":734789}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":734789},"berthingId":226601,"vesselServiceAssignmentId":5733,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1376920800000,"berthingArrivalDate":1376949600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC332R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377072000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":694410,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC332R","departureVoyage":"BC332R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1379,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373621319000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373627884000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373206805410,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734528,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304834400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305468017000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382102,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373206805410,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737319}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737319},"berthingId":227336,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1378620000000,"berthingArrivalDate":1378648800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378641600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":696868,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF336R","departureVoyage":"BF336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373627884000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373627884000,"noonPositionTelex":null,"pilotDepartureDate":1378144800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373206805410,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734524,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305432017000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304964000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382104,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304935200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373206805410,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737315}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737315},"berthingId":227340,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1378015200000,"berthingArrivalDate":1378044000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378036800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":696864,"liveDepartureDate":1378108800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF335R","departureVoyage":"BF336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373627884000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378116000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373628357000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373442008703,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":736872,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305698441000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382107,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373442008703,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":739681}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":739681},"berthingId":227392,"vesselServiceAssignmentId":2933,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1379455200000,"berthingArrivalDate":1379484000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379426400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":699201,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH336R","departureVoyage":"BH336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373628357000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373628357000,"noonPositionTelex":null,"pilotDepartureDate":1378389600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373442008703,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":736864,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305650141000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304604000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382113,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304575200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373442008703,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":739673}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":739673},"berthingId":227398,"vesselServiceAssignmentId":2933,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1378245600000,"berthingArrivalDate":1378274400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378216800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":699193,"liveDepartureDate":1378303200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH334R","departureVoyage":"BH336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373628357000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378360800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373633807000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BJ336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373235608957,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734605,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304863200000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306101655000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382124,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373235608957,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737396}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737396},"berthingId":227866,"vesselServiceAssignmentId":4493,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":0.0,"pilotArrivalDate":1379253600000,"berthingArrivalDate":1379282400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BJ336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379282400000,"customArrivalVoyage":"BJ336R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ336R","dailyvesselschedulecellcompactId":696945,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ336R","departureVoyage":"BJ336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373633807000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373633807000,"noonPositionTelex":null,"pilotDepartureDate":1378188000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BJ336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373235608957,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734601,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306068115000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304892000000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382126,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373235608957,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737392}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737392},"berthingId":227870,"vesselServiceAssignmentId":4493,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":0.0,"pilotArrivalDate":1378044000000,"berthingArrivalDate":1378072800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BJ334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378072800000,"customArrivalVoyage":"BJ334R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ336A","dailyvesselschedulecellcompactId":696941,"liveDepartureDate":1378159200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ334R","departureVoyage":"BJ334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373633807000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378159200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373635949000,"noonPositionTelex":null,"pilotDepartureDate":1378202400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373635948000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373635948000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739091,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304301600000,"isBunkerCall":false,"updateTS":1373635948000,"berthingArrival":1304330400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304416800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":640213,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304902561000,"isBunkerCall":false,"updateTS":1363795862000,"berthingArrival":1304330400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":1277,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"deleteUser":null,"updateTS":1365000150000,"isMaster":true,"isDeleted":false,"insertTS":1363795862000,"isInService":true,"versionInfo":"reshuffle Denmark1","version":5,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":640213,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":640212,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304575235000,"isBunkerCall":false,"updateTS":1363795862000,"berthingArrival":1304578835000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":420,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1277,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304607635000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22956,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363795862000,"portFrom":{"isTBN":"false","terminals":[{"codeMSC":"DKAARAA","isTBN":"false","name":"APM TERMINALS CS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":602,"codePort":null}],"name":"AARHUS","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":141,"isRealPort":true,"displayName":"AARHUS","isDeleted":false,"isInService":true,"isoCode":"DKAAR","timeZoneDifference":1.0,"netpasName":"Arhus"},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"isDeleted":false,"distanceInMiles":110,"insertTS":1363795862000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1363795862000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"pilottimeId":11858,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"isDeleted":false,"insertTS":1363795862000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":13.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":11.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304604035000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363795862000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1363795862000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"insertTS":1363795862000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640212,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":642085}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":640214,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304647235000,"isBunkerCall":false,"updateTS":1363795862000,"berthingArrival":1304665235000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":600,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":141},"isDeleted":false,"bufferTime":224,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1277,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304719235000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11859},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22954,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363795862000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":141},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"isDeleted":false,"distanceInMiles":47,"insertTS":1363795862000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1363795862000,"pilotOnOffBoard":300.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":602},"pilottimeId":11859,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":141},"isDeleted":false,"insertTS":1363795862000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":5.55,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":11.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304701235000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363795862000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1363795862000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":602},"insertTS":1363795862000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640214,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":642086}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":640215,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304748057000,"isBunkerCall":false,"updateTS":1363795862000,"berthingArrival":1304751657000,"inheritedVoyage":"","adjustmentTime":4,"timeInPort":420,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1277,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304780457000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11860},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22955,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363795862000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":639,"insertTS":1363795862000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1363795862000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"pilottimeId":11860,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"isDeleted":false,"insertTS":1363795862000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":45.39,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.3,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304776857000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1363795862000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1363795862000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"insertTS":1363795862000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640215,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":642088}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":640211,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304906401000,"isBunkerCall":false,"updateTS":1363795862000,"berthingArrival":1304935201000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"deleteUser":null,"pilotStationFrom":null,"updateTS":1363795862000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":630,"insertTS":1363795862000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1363795862000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":11857,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1363795862000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1363795862000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1363795862000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1363795862000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640211,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":642084}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304416800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304388000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1363795862000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1363795862000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1363795862000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640213,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":642087}],"dieselConsumption":null},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304388000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373635948000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742042}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":742042},"berthingId":227926,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"DKFRCCN","isTBN":"false","name":"CENTERHAVN","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137,"codePort":null}],"name":"FREDERICIA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":145,"isRealPort":true,"displayName":"FREDERICIA","isDeleted":false,"isInService":true,"isoCode":"DKFRC","timeZoneDifference":1.0,"netpasName":"Fredericia"},"draftArrivalAFT":0.0,"pilotArrivalDate":1378087200000,"berthingArrivalDate":1378116000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378147680000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":701547,"liveDepartureDate":1378205280000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI336A","departureVoyage":"BI336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"DS AGILITY","vesselId":6970,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1368230340000,"dateInService":1246060800000,"code":"06662","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"DS AGILITY","vesselId":9336,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MDAG","dateOutService":null,"dateInService":1373846400000,"code":"09070","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9395616","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"BAL9","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ff6347","laneCode":"BALT9","useWeeklyVoyageNumbers":true,"name":"BALTIC LOOP 09","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":15,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"BI","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373635949000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378173600000,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"DKCPHCT","isTBN":"false","name":"CMP TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136,"codePort":null}],"name":"COPENHAGEN","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":142,"isRealPort":true,"displayName":"COPENHAGEN","isDeleted":false,"isInService":true,"isoCode":"DKCPH","timeZoneDifference":1.0,"netpasName":"Copenhagen"},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373635949000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373635948000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373635948000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739084,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304906401000,"isBunkerCall":false,"updateTS":1373635948000,"berthingArrival":1304935201000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640211,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373635948000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742018}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":742018},"berthingId":227934,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1378692000000,"berthingArrivalDate":1378720800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378735440000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":701552,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI336R","departureVoyage":"BI336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373635949000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373635949000,"noonPositionTelex":null,"pilotDepartureDate":1377597600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373635948000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373635948000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739082,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304301600000,"isBunkerCall":false,"updateTS":1373635948000,"berthingArrival":1304330400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304416800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640213,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304388000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373635948000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742033}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":742033},"berthingId":227937,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1377482400000,"berthingArrivalDate":1377511200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377559920000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":701551,"liveDepartureDate":1377617520000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI335A","departureVoyage":"BI335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373635949000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377568800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373635949000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373635948000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373635948000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739066,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304906401000,"isBunkerCall":false,"updateTS":1373635948000,"berthingArrival":1304935201000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640211,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373635948000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742032}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":742032},"berthingId":227945,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1378087200000,"berthingArrivalDate":1378116000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378147680000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":701546,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI335R","departureVoyage":"BI335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373635949000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373635949000,"noonPositionTelex":null,"pilotDepartureDate":1376992800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373635948000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373635948000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739068,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304301600000,"isBunkerCall":false,"updateTS":1373635948000,"berthingArrival":1304330400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304416800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640213,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304388000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373635948000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742037}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":742037},"berthingId":227948,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1376877600000,"berthingArrivalDate":1376906400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376972160000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":701554,"liveDepartureDate":1377029760000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI334A","departureVoyage":"BI334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373635949000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376964000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373635949000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373635948000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373635948000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739072,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304906401000,"isBunkerCall":false,"updateTS":1373635948000,"berthingArrival":1304935201000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640211,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373635948000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742045}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":742045},"berthingId":227956,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1377482400000,"berthingArrivalDate":1377511200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377559920000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":701531,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI334R","departureVoyage":"BI334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373635949000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373635949000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"deleteUser":null,"updateTS":1373635948000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373635948000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739092,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305626402000,"isBunkerCall":false,"updateTS":1375692079000,"berthingArrival":1305655202000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":30101,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1375692079000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1375692079000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640211,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373635948000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742019}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"proformavesselscheduleterminalcallId":742019},"berthingId":227961,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1376877600000,"berthingArrivalDate":1376906400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376972160000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":701534,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI333R","departureVoyage":"BI333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373635949000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19805},"operatorContainerMoves20":0,"updateTS":1373639829000,"noonPositionTelex":null,"pilotDepartureDate":1378274400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RM336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373206507377,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734518,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304978400000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":3918,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305093600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14491},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":13152,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14491},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.9,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718756,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305064800000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373206507377,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737309}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737309},"berthingId":228242,"vesselServiceAssignmentId":3077,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1378130400000,"berthingArrivalDate":1378159200000,"operatorContainerMoves40":0,"customArrivalVoyage":"RM336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378159200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":696858,"liveDepartureDate":1378245600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RM336A","departureVoyage":"RM336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Majeed ARIAN","userId":19805},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1393,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373639829000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378245600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1375118542000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1375118539000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375118539000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750669,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307730217000,"isBunkerCall":false,"updateTS":1375118539000,"berthingArrival":1307759017000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":29208,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1373902276000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1373902276000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":427150,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":1352210159000,"berthingArrival":1308117607000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1332852561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"distanceInMiles":62,"insertTS":1332852561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":6479,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352210159000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1352210159000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427150,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Francesco DI MAIO","userId":15436},"proformavesselscheduleterminalcallId":428275}],"dieselConsumption":null},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375118539000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753764}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":753764},"berthingId":228423,"vesselServiceAssignmentId":3103,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"isTBN":"false","terminals":[{"codeMSC":"MAAGACA","isTBN":"false","name":"TERMINAL A CONTENEURS AGADIR","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331,"codePort":null}],"name":"AGADIR","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":385,"isRealPort":true,"displayName":"AGADIR","isDeleted":false,"isInService":true,"isoCode":"MAAGA","timeZoneDifference":0.0,"netpasName":"Agadir"},"draftArrivalAFT":0.0,"pilotArrivalDate":1378245600000,"berthingArrivalDate":1378274400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378540980000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":713065,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY333R","departureVoyage":null,"isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1187,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC REBECCA","vesselId":2330,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1187,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1329523140000,"dateInService":1030665600000,"code":"02788","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC REBECCA","vesselId":8123,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1187,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSRC","dateOutService":null,"dateInService":1329523200000,"code":"08094","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":242.8,"imoNumber":"9139505","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"WAF","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"00008b","laneCode":"NWWAF","useWeeklyVoyageNumbers":true,"name":"NWC - CANARY - WAF SERVICE","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":63,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NY","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373641264000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1373641264000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY331R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1373469544000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373469544000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":737420,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308088807000,"isBunkerCall":false,"updateTS":1373469544000,"berthingArrival":1308117607000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":28551,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1373042538000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1373042538000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427150,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373469544000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":740261}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":740261},"berthingId":228435,"vesselServiceAssignmentId":3080,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1377036000000,"berthingArrivalDate":1377064800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY331R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377958800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":699777,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY331R","departureVoyage":null,"isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1102,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC JAPAN","vesselId":3346,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1102,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVJP","dateOutService":null,"dateInService":1125446400000,"code":"05009","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":242.8,"imoNumber":"9110975","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373641264000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373648848000,"noonPositionTelex":null,"pilotDepartureDate":1378965600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"insertTS":1373269544493,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":734738,"averageVesselFuelConsumptionPerHour":4.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208218371000,"isBunkerCall":false,"updateTS":null,"berthingArrival":-2208189571000,"inheritedVoyage":"","adjustmentTime":151,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":-2208103171000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3610,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":211.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":378193,"averageVesselFuelConsumptionPerHour":4.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208218371000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2208189571000,"inheritedVoyage":"","adjustmentTime":151,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":705,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"updateTS":1357206641000,"isMaster":true,"isDeleted":false,"insertTS":1349426752000,"isInService":true,"versionInfo":"NWC 2 05/10/2012","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":378196,"averageVesselFuelConsumptionPerHour":1.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2204800851000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2208967200000,"inheritedVoyage":"","adjustmentTime":873,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2208908400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5777},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3612,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":null,"updateTS":1336583669000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":215,"insertTS":1336583669000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":20.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1243},"pilottimeId":5777,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":29.03,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":13.33,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208909600000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1243},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378196,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378977}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":378195,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208797956000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2208790756000,"inheritedVoyage":"","adjustmentTime":22,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2208707956000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":342},"pilottimeId":5783,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3611,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1336583669000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"distanceInMiles":213,"insertTS":1336583669000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":342},"pilottimeId":5784,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.94,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":8.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208718756000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":342},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378195,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378971}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":378194,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208610786000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2208589186000,"inheritedVoyage":"","adjustmentTime":1140,"timeInPort":1320,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2208488386000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":360.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"pilottimeId":5782,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3609,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1336583669000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"distanceInMiles":13,"insertTS":1336583669000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":360.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"pilottimeId":5788,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":19.5,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":1.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208509986000,"pilotStation":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378194,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378970}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":378192,"averageVesselFuelConsumptionPerHour":3.25,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208373186000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2208362386000,"inheritedVoyage":"","adjustmentTime":319,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2208293986000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5789},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3608,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1336583669000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":251,"insertTS":1336583669000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"pilottimeId":5789,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":50.98,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208304786000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378192,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378967}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":378193,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":378191,"averageVesselFuelConsumptionPerHour":3.9,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2207908758000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2207901558000,"inheritedVoyage":"","adjustmentTime":22,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2207851158000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"pilottimeId":5776,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1412,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331832620000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"distanceInMiles":4396,"insertTS":1327053542000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"pilottimeId":5778,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":968.61,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2207858358000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378191,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378979}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":378197,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2206958376000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2206954776000,"inheritedVoyage":"","adjustmentTime":735,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2206864776000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5787},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1420,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331832620000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"distanceInMiles":166,"insertTS":1327053542000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":68},"pilottimeId":5787,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":31.13,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":8.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2206868376000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":68},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378197,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378968}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":378200,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2206745976000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2206738776000,"inheritedVoyage":"","adjustmentTime":1400,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2206673976000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5790},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1419,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":null,"updateTS":1331832620000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":66},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"distanceInMiles":95,"insertTS":1327053542000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"pilottimeId":5790,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":19.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":7.5,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":-2206681176000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378200,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378969}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":378198,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2206544376000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2206540776000,"inheritedVoyage":"","adjustmentTime":1042,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":66},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2206450776000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5779},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3613,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":null,"updateTS":1336583669000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":66},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"distanceInMiles":222,"insertTS":1336583669000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":61},"pilottimeId":5779,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":66},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":51.54,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":5.6,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2206454376000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":61},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378198,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378976}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":378199,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2206245542000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2206241942000,"inheritedVoyage":"","adjustmentTime":368,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2206173542000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5785},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3615,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":null,"updateTS":1336583669000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":791},"isDeleted":false,"distanceInMiles":216,"insertTS":1336583669000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":70},"pilottimeId":5785,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":45.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2206177142000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":70},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378199,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378972}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":378201,"averageVesselFuelConsumptionPerHour":3.25,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2206105176000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2206097976000,"inheritedVoyage":"","adjustmentTime":330,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":791},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2206025976000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5781},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3618,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":null,"updateTS":1336583669000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":791},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"BRSSATS","isTBN":"false","name":"TECON SALVADOR","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":66,"codePort":null}],"name":"SALVADOR, BA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":72,"isRealPort":true,"displayName":"SALVADOR","isDeleted":false,"isInService":true,"isoCode":"BRSSA","timeZoneDifference":-3.0,"netpasName":"Salvador (Bahia)"},"isDeleted":false,"distanceInMiles":728,"insertTS":1336583669000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":64},"pilottimeId":5781,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":791},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":147.88,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2206033176000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":64},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378201,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378975}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":378202,"averageVesselFuelConsumptionPerHour":3.25,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2205842376000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2205838776000,"inheritedVoyage":"","adjustmentTime":1041,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":72},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":705,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":-2205777576000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5780},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":4.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3621,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":null,"updateTS":1336583669000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":72},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":4357,"insertTS":1336583669000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":66},"pilottimeId":5780,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":72},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":885.02,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2205781176000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":66},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378202,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378978}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":378190,"averageVesselFuelConsumptionPerHour":1.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208968400000,"isBunkerCall":false,"updateTS":1349426752000,"berthingArrival":-2204733559000,"inheritedVoyage":"","adjustmentTime":873,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5777},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3612,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5777},"sequence":13,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":29.03,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":13.33,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1243},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378190,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378974}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":-2208103171000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3610,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1336583669000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"isDeleted":false,"distanceInMiles":1004,"insertTS":1336583669000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"pilottimeId":5786,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1349426752000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":211.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208131971000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1349426752000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1349426752000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"insertTS":1349426752000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378193,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":378973}],"dieselConsumption":null},"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208131971000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373269544493,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":737531}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":737531},"berthingId":228578,"vesselServiceAssignmentId":3022,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1378850400000,"berthingArrivalDate":1378879200000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"dailyVesselScheduleCell":{"liveArrivalDate":1378879200000,"customArrivalVoyage":"00499S","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"00499S","dailyvesselschedulecellcompactId":697078,"liveDepartureDate":1378936800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"00499S","departureVoyage":"00499S","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3129,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CMA CGM SAMBHAR","vesselId":8311,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3129,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCSB","dateOutService":null,"dateInService":1335916800000,"code":"08255","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9295969","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"SAEC2","isStandardMSCVoyageCoding":false,"useVoyageLinking":true,"isDeleted":false,"startDate":1354039200000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ffdead","laneCode":"NWSA2","useWeeklyVoyageNumbers":true,"name":"NWC TO SAEC - STRING II","exceedingDateOffset":10080,"isScheduleDelayDisplayed":false,"serviceId":68,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"NB","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373648848000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378936800000,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"PTLISAB","isTBN":"false","name":"SOTAGUS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":619,"codePort":null},{"codeMSC":"PTLISLT","isTBN":"false","name":"LISCONT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404,"codePort":null}],"name":"LISBOA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":506,"isRealPort":true,"displayName":"LISBOA","isDeleted":false,"isInService":true,"isoCode":"PTLIS","timeZoneDifference":0.0,"netpasName":"Lisbon"},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373648848000,"noonPositionTelex":null,"pilotDepartureDate":1378360800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"00497S","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"insertTS":1372660529453,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":727982,"averageVesselFuelConsumptionPerHour":4.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208218371000,"isBunkerCall":false,"updateTS":null,"berthingArrival":-2208189571000,"inheritedVoyage":"","adjustmentTime":151,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":-2208103171000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3610,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":211.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378193,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208131971000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372660529453,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":730723}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":730723},"berthingId":228591,"vesselServiceAssignmentId":3021,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1378245600000,"berthingArrivalDate":1378274400000,"operatorContainerMoves40":0,"customArrivalVoyage":"00497S","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"dailyVesselScheduleCell":{"liveArrivalDate":1378274400000,"customArrivalVoyage":"00497S","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"00497S","dailyvesselschedulecellcompactId":690387,"liveDepartureDate":1378332000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"00497S","departureVoyage":"00497S","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":2912,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"LOA","vesselId":5696,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2912,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MLOA","dateOutService":1122854340000,"dateInService":1111104000000,"code":"04817","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"LOA","vesselId":8303,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2912,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCLA","dateOutService":null,"dateInService":1335312000000,"code":"08249","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9290804","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373648848000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378332000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373648848000,"noonPositionTelex":null,"pilotDepartureDate":1377756000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"00495S","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"insertTS":1372059330110,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":722184,"averageVesselFuelConsumptionPerHour":4.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208218371000,"isBunkerCall":false,"updateTS":null,"berthingArrival":-2208189571000,"inheritedVoyage":"","adjustmentTime":151,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":-2208103171000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3610,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":211.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378193,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208131971000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372059330110,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":724797}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":724797},"berthingId":228604,"vesselServiceAssignmentId":3026,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1377640800000,"berthingArrivalDate":1377669600000,"operatorContainerMoves40":0,"customArrivalVoyage":"00495S","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"dailyVesselScheduleCell":{"liveArrivalDate":1377669600000,"customArrivalVoyage":"00495S","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"00495S","dailyvesselschedulecellcompactId":684705,"liveDepartureDate":1377727200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"00495S","departureVoyage":"00495S","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3128,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CMA CGM AMERICA","vesselId":8310,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3128,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCCA","dateOutService":null,"dateInService":1334707200000,"code":"08254","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9295971","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373648848000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377727200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373648848000,"noonPositionTelex":null,"pilotDepartureDate":1377151200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"00493S","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1372843426000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"insertTS":1372843426000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":731106,"averageVesselFuelConsumptionPerHour":4.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305064829000,"isBunkerCall":false,"updateTS":1372843426000,"berthingArrival":1305093629000,"inheritedVoyage":"","adjustmentTime":151,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305180029000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3610,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":211.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378193,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305151229000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1372843426000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":733865}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":733865},"berthingId":228616,"vesselServiceAssignmentId":5238,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1377036000000,"berthingArrivalDate":1377064800000,"operatorContainerMoves40":0,"customArrivalVoyage":"00493S","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"dailyVesselScheduleCell":{"liveArrivalDate":1376978400000,"customArrivalVoyage":"00493S","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"00493S","dailyvesselschedulecellcompactId":693482,"liveDepartureDate":1377036000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"00493S","departureVoyage":"00493S","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3727,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"JPO CANCER","vesselId":9168,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3727,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SLJC","dateOutService":1372723140000,"dateInService":1368057600000,"code":"08920","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"JPO CANOPUS","vesselId":9300,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3727,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCNO","dateOutService":null,"dateInService":1372723200000,"code":"09036","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9295402","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373648848000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377122400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1373707849000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP338R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373698822857,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739512,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306533630000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306562430000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681491,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373698822857,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742475}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742475},"berthingId":229435,"vesselServiceAssignmentId":5074,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1380319200000,"berthingArrivalDate":1380348000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NP338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380348000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":701974,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP338R","departureVoyage":"NP338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3617,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373707849000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1373707849000,"noonPositionTelex":null,"pilotDepartureDate":1378677600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373698822857,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739502,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306513410000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304748000000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":750,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304892000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304863200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373698822857,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742464}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742464},"berthingId":229440,"vesselServiceAssignmentId":5074,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1378504800000,"berthingArrivalDate":1378533600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NP335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378533600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":701964,"liveDepartureDate":1378648800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP335R","departureVoyage":"NP336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3617,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373707849000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378648800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"operatorContainerMoves20":0,"updateTS":1373711066000,"noonPositionTelex":null,"pilotDepartureDate":1379131200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NZ336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373654125577,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739373,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305165602000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305198002000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305345602000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13480},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701517,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305313202000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373654125577,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742335}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742335},"berthingId":229451,"vesselServiceAssignmentId":5489,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1378951200000,"berthingArrivalDate":1378983600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NZ336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378983600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":701835,"liveDepartureDate":1379098800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NZ336A","departureVoyage":"NZ336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"hiddenBerthings":[],"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Pierluigi GUARRACINO","userId":17751},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3718,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC ABIDJAN","vesselId":9156,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3718,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MABJ","dateOutService":null,"dateInService":1368057600000,"code":"08909","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":299.0,"imoNumber":"9618264","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373711066000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379098800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"operatorContainerMoves20":0,"updateTS":1373711066000,"noonPositionTelex":null,"pilotDepartureDate":1378526400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NZ335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373047255973,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":733772,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305165602000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305198002000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305345602000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13480},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701517,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305313202000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373047255973,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":736555}],"dieselConsumption":null},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":736555},"berthingId":229465,"vesselServiceAssignmentId":5485,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1378346400000,"berthingArrivalDate":1378378800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NZ335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378378800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":696114,"liveDepartureDate":1378494000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NZ335A","departureVoyage":"NZ335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3703,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"HYUNDAI SINGAPORE","vesselId":9136,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3703,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MYSP","dateOutService":null,"dateInService":1368403200000,"code":"08893","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":303.8,"imoNumber":"9305685","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373711066000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378494000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":4001},"operatorContainerMoves20":0,"updateTS":1373850811000,"noonPositionTelex":null,"pilotDepartureDate":1377118800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FL333A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373646307467,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739250,"averageVesselFuelConsumptionPerHour":4.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304946059000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304974859000,"inheritedVoyage":"","adjustmentTime":5,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305147659000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13406},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":10623,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13406},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":5.65,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":698940,"averageVesselFuelConsumptionPerHour":4.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304946059000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1304974859000,"inheritedVoyage":"","adjustmentTime":5,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":1402,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"updateTS":1369836904000,"isMaster":true,"isDeleted":false,"insertTS":1369836481000,"isInService":true,"versionInfo":"Lion add Sie 29_05_2013","version":10,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":698933,"averageVesselFuelConsumptionPerHour":8.79,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1311333051000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1304694000000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1500,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304791200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13398},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":true,"serviceportdistanceId":26650,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1369836481000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":215,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":13398,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":96.92,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304784000000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698933,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701416}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698937,"averageVesselFuelConsumptionPerHour":4.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304830832000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1304838032000,"inheritedVoyage":"","adjustmentTime":17,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304931632000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13403},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2169,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1329728435420,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":54,"insertTS":1329728435420,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"pilottimeId":13403,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":14.9,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304924432000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698937,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701412}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":698940,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":698919,"averageVesselFuelConsumptionPerHour":3.49,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305153041000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1305160241000,"inheritedVoyage":"","adjustmentTime":17,"timeInPort":900,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"isDeleted":false,"bufferTime":90,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305221441000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"pilottimeId":13409,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10620,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"distanceInMiles":67,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Marco APREDA","userId":8594}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"pilottimeId":13410,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":16.7,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305214241000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698919,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701406}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698936,"averageVesselFuelConsumptionPerHour":2.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305239450000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1305246650000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1980,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305372650000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13413},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":11804,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355841055000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"distanceInMiles":1041,"insertTS":1355841055000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":995},"pilottimeId":13413,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":212.06,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":10.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305365450000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":995},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698936,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701407}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698930,"averageVesselFuelConsumptionPerHour":3.77,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305720010000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1305723610000,"inheritedVoyage":"","adjustmentTime":28,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305792010000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13416},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2166,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1329728435420,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"distanceInMiles":2164,"insertTS":1329728435420,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"pilottimeId":13416,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":578.6,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.1,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305788410000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698930,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701411}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698926,"averageVesselFuelConsumptionPerHour":2.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306350040000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1306350040000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":60,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306353640000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13419},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":1607,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17752},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1327144126987,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"distanceInMiles":82,"insertTS":1327144126987,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Francesco INDOVINO","userId":17752}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":0.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"pilottimeId":13419,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.63,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":6.3,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306353640000,"pilotStation":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698926,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701415}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698922,"averageVesselFuelConsumptionPerHour":4.38,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306400437000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1306400437000,"inheritedVoyage":"","adjustmentTime":60,"timeInPort":480,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306429237000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13419},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10627,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":418},"isDeleted":false,"distanceInMiles":4800,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13419},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":1401.6,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306429237000,"pilotStation":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698922,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701421}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698923,"averageVesselFuelConsumptionPerHour":2.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307606437000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1307610037000,"inheritedVoyage":"","adjustmentTime":74,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":418},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307678437000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":315},"pilottimeId":13411,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":418},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10626,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":418},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"distanceInMiles":210,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":315},"pilottimeId":13423,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":418},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":40.17,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":11.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307674837000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":315},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698923,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701422}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698920,"averageVesselFuelConsumptionPerHour":2.54,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307748617000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1307755817000,"inheritedVoyage":"","adjustmentTime":14,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307831417000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"pilottimeId":13422,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10630,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CNYTNYI","isTBN":"false","name":"YANTIAN INTERNATIONAL CONTAINER TERMINALS LTD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":121,"codePort":null},{"codeMSC":"CNYTNAJ","isTBN":"false","name":"WEST YANTIAN PORT TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1265,"codePort":null}],"name":"YANTIAN","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":118,"isRealPort":true,"displayName":"YANTIAN","isDeleted":false,"isInService":true,"isoCode":"CNYTN","timeZoneDifference":8.0,"netpasName":"Yantian"},"isDeleted":false,"distanceInMiles":1442,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"pilottimeId":13421,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":10,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":297.78,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":12.3,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307827817000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698920,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701413}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698924,"averageVesselFuelConsumptionPerHour":2.34,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308252625000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1308263425000,"inheritedVoyage":"","adjustmentTime":20,"timeInPort":1320,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":118},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308353425000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":121},"pilottimeId":13420,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":118},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10629,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":118},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CNCWNAE","isTBN":"false","name":"YIU LIAN","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":990,"codePort":null},{"codeMSC":"CNCWNSH","isTBN":"false","name":"SHENZHEN HAIXING HARBOUR DEVELOPMENT","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":96,"codePort":null},{"codeMSC":"CNCWNMT","isTBN":"false","name":"MAWAN CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":94,"codePort":null},{"codeMSC":"CNCWNAI","isTBN":"false","name":"CHIWAN HARBOUR CONTAINER CO, LTD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1315,"codePort":null},{"codeMSC":"CNCWNCC","isTBN":"false","name":"CHIWAN CONTAINER TERMINAL CO LTD","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":93,"codePort":null}],"name":"CHIWAN","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":4,"pilotStations":[],"portId":97,"isRealPort":true,"displayName":"CHIWAN","isDeleted":false,"isInService":true,"isoCode":"CNCWN","timeZoneDifference":8.0,"netpasName":"Chiwan"},"isDeleted":false,"distanceInMiles":50,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":121},"pilottimeId":13396,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":118},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":9.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":12.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308342625000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":121},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698924,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701425}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698928,"averageVesselFuelConsumptionPerHour":6.85,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308369625000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1308376825000,"inheritedVoyage":"","adjustmentTime":21,"timeInPort":660,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":97},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308423625000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":93},"pilottimeId":13417,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":97},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10613,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":97},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CNXMNST","isTBN":"false","name":"XIAMEN SONGYU CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":118,"codePort":null},{"codeMSC":"CNXMNXI","isTBN":"false","name":"XIAMEN INTERNATIONAL CONTAINERS TERMINALS","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":117,"codePort":null},{"codeMSC":"CNXMNTL","isTBN":"false","name":"XIAMEN HAIRUN CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":116,"codePort":null},{"codeMSC":"CNXMNAR","isTBN":"false","name":"NEW WORLD XIANGYU CONTAINER TERMINAL","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1098,"codePort":null},{"codeMSC":"CNXMHTN","isTBN":"false","name":"HAITIAN","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":115,"codePort":null}],"name":"XIAMEN (XIAN)","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":114,"isRealPort":true,"displayName":"XIAMEN","isDeleted":false,"isInService":true,"isoCode":"CNXMN","timeZoneDifference":8.0,"netpasName":"Xiamen"},"isDeleted":false,"distanceInMiles":300,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":93},"pilottimeId":13415,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":97},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":12,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":115.45,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":17.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308416425000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":93},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698928,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701405}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698932,"averageVesselFuelConsumptionPerHour":7.45,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308483039000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1308490239000,"inheritedVoyage":"","adjustmentTime":21,"timeInPort":660,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":114},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308537039000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13414},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10611,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":114},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":102},"isDeleted":false,"distanceInMiles":610,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":117},"pilottimeId":13414,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":114},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":13,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":246.98,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.4,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308529839000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":117},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698932,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701409}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698935,"averageVesselFuelConsumptionPerHour":5.65,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308657647000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1308664847000,"inheritedVoyage":"","adjustmentTime":2,"timeInPort":1500,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":102},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308762047000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":106},"pilottimeId":13412,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":102},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10622,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":102},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":105},"isDeleted":false,"distanceInMiles":100,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":106},"pilottimeId":13399,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":102},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":14,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":34.04,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":16.6,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1308754847000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":106},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698935,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701404}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698921,"averageVesselFuelConsumptionPerHour":8.16,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308783614000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1308790814000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1500,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":105},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308888014000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13408},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10621,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":105},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":114},"isDeleted":false,"distanceInMiles":610,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1081},"pilottimeId":13408,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":105},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":15,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":261.98,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308880814000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1081},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698921,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701424}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698927,"averageVesselFuelConsumptionPerHour":7.22,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309003233000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1309010433000,"inheritedVoyage":"","adjustmentTime":4,"timeInPort":720,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":114},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1309060833000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13414},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10618,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":114},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":118},"isDeleted":false,"distanceInMiles":290,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13414},"sequence":16,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":115.04,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.2,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309053633000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":117},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698927,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701419}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698938,"averageVesselFuelConsumptionPerHour":5.25,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309118436000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1309129236000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":780,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":118},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1309183236000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":121},"pilottimeId":13407,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":118},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":10629,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":121},"pilottimeId":13405,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":118},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":17,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":16.41,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309176036000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":121},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698938,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701410}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698939,"averageVesselFuelConsumptionPerHour":8.16,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309194006000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1309201206000,"inheritedVoyage":"","adjustmentTime":2,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":97},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1309294806000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":93},"pilottimeId":13404,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":97},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10617,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":97},"isDeleted":false,"distanceInMiles":1415,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":93},"pilottimeId":13402,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":97},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":18,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":607.71,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309287606000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":93},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698939,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701414}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698931,"averageVesselFuelConsumptionPerHour":7.34,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309563031000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1309570231000,"inheritedVoyage":"","adjustmentTime":38,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1309638631000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"pilottimeId":13401,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-6.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":4782,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":3998},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1341486670283,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"distanceInMiles":5010,"insertTS":1341486670283,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Alex CHEE","userId":3998}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"pilottimeId":13400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":550},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":19,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":2009.48,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":18.3,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309635031000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1084},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698931,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701418}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698934,"averageVesselFuelConsumptionPerHour":2.2,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1310604885000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1310604885000,"inheritedVoyage":"","adjustmentTime":63,"timeInPort":60,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1310608485000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13419},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1607,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13419},"sequence":20,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":27.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":6.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1310608485000,"pilotStation":{"?p":"true","pilotstationId":38,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698934,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701420}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698929,"averageVesselFuelConsumptionPerHour":9.05,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1310657680000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1310657680000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":86,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1310662840000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13419},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":-2.0,"servicePortDistance":{"isOverride":true,"serviceportdistanceId":26651,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1369836481000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":166},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"distanceInMiles":2170,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13419},"sequence":21,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":996.88,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":19.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1310662840000,"pilotStation":{"?p":"true","pilotstationId":26,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":151},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698929,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701423}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":698925,"averageVesselFuelConsumptionPerHour":8.92,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1311051648000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1311058848000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1680,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1402,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1311163248000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"pilottimeId":13418,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10614,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":null,"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":920,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"pilottimeId":13397,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":22,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":429.65,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":19.1,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1311159648000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698925,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701426}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":698918,"averageVesselFuelConsumptionPerHour":8.79,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1311339651000,"isBunkerCall":false,"updateTS":1369836481000,"berthingArrival":1311346851000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1500,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13398},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26650,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13398},"sequence":23,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":96.92,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":2,"matchingProformaVesselSchedulePort":null,"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698918,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701417}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1305147659000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13406},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":10623,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1355305561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"isDeleted":false,"distanceInMiles":24,"insertTS":1355305561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8594}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":13406,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1369836481000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":5.65,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305118859000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1369836481000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"deleteUser":null,"updateTS":1369836481000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1369836481000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698940,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"proformavesselscheduleterminalcallId":701408}],"dieselConsumption":null},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305118859000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373646307467,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742210}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742210},"berthingId":229849,"vesselServiceAssignmentId":5533,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1376917200000,"berthingArrivalDate":1376946000000,"operatorContainerMoves40":0,"customArrivalVoyage":"FL333A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377223620000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":701713,"liveDepartureDate":1377367620000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FL333A","departureVoyage":"FL333A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Chong Loon LIM","userId":4001},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3376,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC KATIE","vesselId":8671,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3376,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MKTE","dateOutService":null,"dateInService":1352678400000,"code":"08574","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":365.8,"imoNumber":"9467457","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"LION","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":1337409300000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":5,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"ff0000","laneCode":"LION","useWeeklyVoyageNumbers":true,"name":"LION SERVICE","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":46,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"FL","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373850811000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377090000000,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"FRDKKTN","isTBN":"false","name":"TERMINAL NFTI","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168,"codePort":null}],"name":"DUNKERQUE","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":754,"isRealPort":true,"displayName":"DUNKERQUE","isDeleted":false,"isInService":true,"isoCode":"FRDKK","timeZoneDifference":1.0,"netpasName":"Dunkirk (FR)"},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"operatorContainerMoves20":0,"updateTS":1373874806000,"noonPositionTelex":null,"pilotDepartureDate":1379183400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NU337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373867433700,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739905,"averageVesselFuelConsumptionPerHour":2.8,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304627431000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304656231000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304793031000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1059,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246168,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304764231000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373867433700,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742871}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742871},"berthingId":230168,"vesselServiceAssignmentId":4539,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1379017800000,"berthingArrivalDate":1379046600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NU337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379046600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702367,"liveDepartureDate":1379154600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NU337A","departureVoyage":"NU337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":891,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC FEDERICA","vesselId":5037,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":891,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MFED","dateOutService":null,"dateInService":1297296000000,"code":"07475","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":294.1,"imoNumber":"8715869","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373874806000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379154600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"operatorContainerMoves20":0,"updateTS":1373875199000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373863507937,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739898,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304884854000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304913654000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373863507937,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742864}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742864},"berthingId":230173,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1379275200000,"berthingArrivalDate":1379304000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379304000000,"customArrivalVoyage":"RB336R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB336R","dailyvesselschedulecellcompactId":702360,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB336R","departureVoyage":"RB336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373875199000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"operatorContainerMoves20":0,"updateTS":1373875199000,"noonPositionTelex":null,"pilotDepartureDate":1378814400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373863507937,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739895,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304877654000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304308800000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304424000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651687,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304395200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373863507937,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742861}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742861},"berthingId":230174,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1378670400000,"berthingArrivalDate":1378699200000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378699200000,"customArrivalVoyage":"RB335R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB336A","dailyvesselschedulecellcompactId":702357,"liveDepartureDate":1378785600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB335R","departureVoyage":"RB335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373875199000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378785600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1373876966000,"noonPositionTelex":null,"pilotDepartureDate":1378836000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373829935107,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739712,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309056347000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304877600000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305050400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617450,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305021600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373829935107,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742678}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742678},"berthingId":230236,"vesselServiceAssignmentId":4040,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":0.0,"pilotArrivalDate":1378634400000,"berthingArrivalDate":1378663200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NG333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378656000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702174,"liveDepartureDate":1378800000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG333R","departureVoyage":"NG337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1381,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373876966000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378807200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373877407000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373724002577,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739546,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305957600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305986400000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732081,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373724002577,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742510}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742510},"berthingId":230239,"vesselServiceAssignmentId":2920,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1379743200000,"berthingArrivalDate":1379772000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379772000000,"customArrivalVoyage":"BA336R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA336R","dailyvesselschedulecellcompactId":702008,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA336R","departureVoyage":"BA336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":770,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373877407000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373877407000,"noonPositionTelex":null,"pilotDepartureDate":1378706400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373724002577,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739544,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305861840000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304776800000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":1680,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304920800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732082,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304892000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373724002577,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742507}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742507},"berthingId":230240,"vesselServiceAssignmentId":2920,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1378533600000,"berthingArrivalDate":1378562400000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378562400000,"customArrivalVoyage":"BA334R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA336A","dailyvesselschedulecellcompactId":702006,"liveDepartureDate":1378677600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA334R","departureVoyage":"BA334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":770,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373877407000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378677600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1373879317000,"noonPositionTelex":null,"pilotDepartureDate":1379570400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"insertTS":1373874624047,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740002,"averageVesselFuelConsumptionPerHour":4.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208218371000,"isBunkerCall":false,"updateTS":null,"berthingArrival":-2208189571000,"inheritedVoyage":"","adjustmentTime":151,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":-2208103171000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3610,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":211.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378193,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208131971000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373874624047,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742968}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742968},"berthingId":230250,"vesselServiceAssignmentId":4423,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1379455200000,"berthingArrivalDate":1379484000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"dailyVesselScheduleCell":{"liveArrivalDate":1379484000000,"customArrivalVoyage":"00501S","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"00501S","dailyvesselschedulecellcompactId":702464,"liveDepartureDate":1379541600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"00501S","departureVoyage":"00501S","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1434,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC DONATA","vesselId":4003,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1434,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1330387140000,"dateInService":1199664000000,"code":"05957","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC DONATA","vesselId":8185,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1434,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSDN","dateOutService":null,"dateInService":1330387200000,"code":"08148","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":258.0,"imoNumber":"9237151","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373879317000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379541600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373880102000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF337R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373811905373,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739711,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304834400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305468017000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382102,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373811905373,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742677}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742677},"berthingId":230273,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1379224800000,"berthingArrivalDate":1379253600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379246400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702173,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF337R","departureVoyage":"BF337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373880102000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373880102000,"noonPositionTelex":null,"pilotDepartureDate":1378749600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373811905373,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739707,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305432017000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304964000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382104,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304935200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373811905373,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742673}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742673},"berthingId":230275,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1378620000000,"berthingArrivalDate":1378648800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378641600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702169,"liveDepartureDate":1378713600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF336R","departureVoyage":"BF337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373880102000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378720800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373881361000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373840709810,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739758,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304863200000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306101655000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382124,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373840709810,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742724}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742724},"berthingId":230282,"vesselServiceAssignmentId":4494,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":0.0,"pilotArrivalDate":1379858400000,"berthingArrivalDate":1379887200000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379851200000,"customArrivalVoyage":"BJ337R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ337R","dailyvesselschedulecellcompactId":702220,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ337R","departureVoyage":"BJ337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3133,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373881361000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373881361000,"noonPositionTelex":null,"pilotDepartureDate":1378792800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373840709810,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":739754,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306068115000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304892000000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382126,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373840709810,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742720}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742720},"berthingId":230284,"vesselServiceAssignmentId":4494,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":0.0,"pilotArrivalDate":1378648800000,"berthingArrivalDate":1378677600000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378641600000,"customArrivalVoyage":"BJ335R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ337A","dailyvesselschedulecellcompactId":702216,"liveDepartureDate":1378728000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ335R","departureVoyage":"BJ335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3133,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373881361000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378764000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"operatorContainerMoves20":0,"updateTS":1374854577000,"noonPositionTelex":null,"pilotDepartureDate":1378879200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RM337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"deleteUser":null,"updateTS":1374854576000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374854576000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":748748,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949600000,"isBunkerCall":false,"updateTS":1374854576000,"berthingArrival":1304978400000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":3918,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305093600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12890},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":13152,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12890},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.9,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":676870,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305064800000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374854576000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":751836}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"proformavesselscheduleterminalcallId":751836},"berthingId":230320,"vesselServiceAssignmentId":4472,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1378735200000,"berthingArrivalDate":1378764000000,"operatorContainerMoves40":0,"customArrivalVoyage":"RM337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378764000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":711170,"liveDepartureDate":1378850400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RM337A","departureVoyage":"RM337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19805},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3593,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373907356000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378850400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373975956000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI337R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373885407297,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740120,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304906401000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304935201000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640211,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373885407297,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":743085}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":743085},"berthingId":230607,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1379296800000,"berthingArrivalDate":1379325600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379325600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702582,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI337R","departureVoyage":"BI337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373975956000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1373975956000,"noonPositionTelex":null,"pilotDepartureDate":1378807200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373885407297,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740116,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304902561000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304330400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304416800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640213,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304388000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373885407297,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":743081}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":743081},"berthingId":230608,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1378692000000,"berthingArrivalDate":1378720800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378735440000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702578,"liveDepartureDate":1378793040000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI336R","departureVoyage":"BI337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1373975956000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378778400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8412},"operatorContainerMoves20":0,"updateTS":1374025297000,"noonPositionTelex":null,"pilotDepartureDate":1378665900000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FS336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373999706013,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":741556,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304649950000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304678750000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304880350000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12635,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559561,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304851550000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373999706013,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":744568}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":744568},"berthingId":230812,"vesselServiceAssignmentId":2462,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"draftArrivalAFT":0.0,"pilotArrivalDate":1378435500000,"berthingArrivalDate":1378464300000,"operatorContainerMoves40":0,"customArrivalVoyage":"FS336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378705140000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":704044,"liveDepartureDate":1378877940000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FS336A","departureVoyage":"FS336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8412},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1998,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC TRIESTE","vesselId":5638,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1998,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MTRI","dateOutService":null,"dateInService":1322697600000,"code":"07957","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":366.0,"imoNumber":"9484479","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374025297000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378637100000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1374047854000,"noonPositionTelex":null,"pilotDepartureDate":1379397600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NC337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373962501640,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":741081,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304843432000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304872232000,"inheritedVoyage":"","adjustmentTime":97,"timeInPort":1770,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007232000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2673,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52229,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978432000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373962501640,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":744090}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":744090},"berthingId":230827,"vesselServiceAssignmentId":5434,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1379233800000,"berthingArrivalDate":1379262600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NC337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379262600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":703575,"liveDepartureDate":1379368800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NC337A","departureVoyage":"NC337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":890,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374047854000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379368800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374052209000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373987701797,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":741321,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304402400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305640801000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403966,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373987701797,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":744333}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":744333},"berthingId":230940,"vesselServiceAssignmentId":3064,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":0.0,"pilotArrivalDate":1380002400000,"berthingArrivalDate":1380031200000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380031200000,"customArrivalVoyage":"BB337R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB337R","dailyvesselschedulecellcompactId":703815,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB337R","departureVoyage":"BB337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":768,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374052209000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374052209000,"noonPositionTelex":null,"pilotDepartureDate":1378936800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373987701797,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":741317,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305551521000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304431200000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304546400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403968,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304517600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373987701797,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":744329}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":744329},"berthingId":230942,"vesselServiceAssignmentId":3064,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":0.0,"pilotArrivalDate":1378792800000,"berthingArrivalDate":1378821600000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378821600000,"customArrivalVoyage":"BB335R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB337A","dailyvesselschedulecellcompactId":703811,"liveDepartureDate":1378908000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB335R","departureVoyage":"BB335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":768,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374052209000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378908000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374052603000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC337R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373928603107,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740766,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304344800000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305583245000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439877,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373928603107,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":743771}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":743771},"berthingId":230966,"vesselServiceAssignmentId":5329,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1379944800000,"berthingArrivalDate":1379973600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380002400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":703261,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC337R","departureVoyage":"BC337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1801,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374052603000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374052603000,"noonPositionTelex":null,"pilotDepartureDate":1378879200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373928603107,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740759,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305543885000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304373600000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304488800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439882,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304460000000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373928603107,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":743764}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":743764},"berthingId":230968,"vesselServiceAssignmentId":5329,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1378735200000,"berthingArrivalDate":1378764000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378814400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":703254,"liveDepartureDate":1378900800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC335R","departureVoyage":"BC337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1801,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374052603000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378850400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374053480000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH337R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374046806747,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":741770,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305698441000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382107,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374046806747,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":744782}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":744782},"berthingId":230979,"vesselServiceAssignmentId":5704,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1380060000000,"berthingArrivalDate":1380088800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379984400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":704258,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH337R","departureVoyage":"BH337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3240,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374053480000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374053480000,"noonPositionTelex":null,"pilotDepartureDate":1378994400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374046806747,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":741762,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305650141000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304604000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382113,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304575200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374046806747,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":744774}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":744774},"berthingId":230982,"vesselServiceAssignmentId":5704,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1378850400000,"berthingArrivalDate":1378879200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378774800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":704250,"liveDepartureDate":1378861200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH335R","departureVoyage":"BH337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3240,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374053480000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378965600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1374055141000,"noonPositionTelex":null,"pilotDepartureDate":1379073600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NW337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373955314997,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740856,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517635000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304546435000,"inheritedVoyage":"","adjustmentTime":2396,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304683235000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22167,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":21.23,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304654435000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373955314997,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":743862}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":743862},"berthingId":230999,"vesselServiceAssignmentId":2343,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1378908000000,"berthingArrivalDate":1378936800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NW337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378994400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":703351,"liveDepartureDate":1379102400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NW337A","departureVoyage":"NW337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1933,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CSAV RECIFE","vesselId":5373,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1933,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1351382340000,"dateInService":1314748800000,"code":"07741","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"CSAV RECIFE","vesselId":8823,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1933,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MCRE","dateOutService":null,"dateInService":1351382400000,"code":"08602","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":294.1,"imoNumber":"9437050","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374055141000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379044800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1374073931000,"noonPositionTelex":null,"pilotDepartureDate":1381006800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NQ340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374033302843,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":741609,"averageVesselFuelConsumptionPerHour":3.4,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306472408000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306501208000,"inheritedVoyage":"","adjustmentTime":47,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1306616408000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":21027,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":10540},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":41.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":632688,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306587608000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374033302843,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":744621}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":744621},"berthingId":231097,"vesselServiceAssignmentId":4929,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1380862800000,"berthingArrivalDate":1380891600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NQ340A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380891600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":704097,"liveDepartureDate":1380978000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NQ340A","departureVoyage":"NQ340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":615},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1945,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":227},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374073931000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380978000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1374134249000,"noonPositionTelex":null,"pilotDepartureDate":1380175200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374012918093,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":741575,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308628094000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304460000000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304575200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374699,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304546400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374012918093,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":744587}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":744587},"berthingId":231229,"vesselServiceAssignmentId":4729,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":0.0,"pilotArrivalDate":1380031200000,"berthingArrivalDate":1380060000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NA335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380060000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":704063,"liveDepartureDate":1380146400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA335R","departureVoyage":"NA339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1991,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374134249000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380146400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1374139431000,"noonPositionTelex":null,"pilotDepartureDate":1378828800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373876101390,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740037,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305486030000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304323200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304438400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200338,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304409600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373876101390,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":743002}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":743002},"berthingId":231360,"vesselServiceAssignmentId":5795,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1378684800000,"berthingArrivalDate":1378713600000,"operatorContainerMoves40":0,"customArrivalVoyage":"336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378713600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702499,"liveDepartureDate":1378800000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"336R","departureVoyage":"337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3015,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374139431000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378800000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1374139431000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"338R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373876101390,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740043,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304294400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305532800000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200335,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373876101390,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":743008}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":743008},"berthingId":231372,"vesselServiceAssignmentId":5795,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1379894400000,"berthingArrivalDate":1379923200000,"operatorContainerMoves40":0,"customArrivalVoyage":"338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379923200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702505,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"338R","departureVoyage":"338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3015,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374139431000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1374139431000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"338R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373876101047,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740036,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304294400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305532800000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200335,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1373876101047,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":743001}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":743001},"berthingId":231373,"vesselServiceAssignmentId":5794,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1379894400000,"berthingArrivalDate":1379923200000,"operatorContainerMoves40":0,"customArrivalVoyage":"338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379923200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702498,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"338R","departureVoyage":"338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3016,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374139431000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"operatorContainerMoves20":0,"updateTS":1374139431000,"noonPositionTelex":null,"pilotDepartureDate":1378828800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1373876101047,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":740030,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305486030000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304323200000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304438400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6049,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3531},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":200338,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304409600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1373876101047,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":742995}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":742995},"berthingId":231375,"vesselServiceAssignmentId":5794,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1378684800000,"berthingArrivalDate":1378713600000,"operatorContainerMoves40":0,"customArrivalVoyage":"336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378713600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":702492,"liveDepartureDate":1378800000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"336R","departureVoyage":"337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3016,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":127},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374139431000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378800000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1374151625000,"noonPositionTelex":null,"pilotDepartureDate":1379224800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NM337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374131105997,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":742565,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304690440000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304719240000,"inheritedVoyage":"","adjustmentTime":92,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304834440000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2734,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55406,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805640000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374131105997,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":745622}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":745622},"berthingId":231413,"vesselServiceAssignmentId":3975,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1379080800000,"berthingArrivalDate":1379109600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NM337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379109600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":705066,"liveDepartureDate":1379196000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NM337A","departureVoyage":"NM337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1711,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374151625000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379196000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1374154226000,"noonPositionTelex":null,"pilotDepartureDate":1378188000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NC335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"deleteUser":null,"updateTS":1374154225000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374154225000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":743380,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304843432000,"isBunkerCall":false,"updateTS":1374154225000,"berthingArrival":1304872232000,"inheritedVoyage":"","adjustmentTime":97,"timeInPort":1770,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007232000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2673,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52229,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978432000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374154225000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":746448}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"proformavesselscheduleterminalcallId":746448},"berthingId":231524,"vesselServiceAssignmentId":5473,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1378024200000,"berthingArrivalDate":1378053000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NC335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378053000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":705879,"liveDepartureDate":1378159200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NC335A","departureVoyage":"NC335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1537,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC LISA","vesselId":2974,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1537,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"LISA","dateOutService":null,"dateInService":1097020800000,"code":"04607","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":294.0,"imoNumber":"9281279","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374154226000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378159200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1374220928000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374100505310,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":742451,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306965651000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":7,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4045,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374100505310,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":745506}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":745506},"berthingId":231625,"vesselServiceAssignmentId":524,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":0.0,"pilotArrivalDate":1381327200000,"berthingArrivalDate":1381356000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381356000000,"customArrivalVoyage":"69E39","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"69E39","dailyvesselschedulecellcompactId":704952,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"69E39","departureVoyage":"69E39","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1423,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374220928000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1374220928000,"noonPositionTelex":null,"pilotDepartureDate":1379052000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374100505310,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":742445,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306933252000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304546400000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304661600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4046,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304632800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374100505310,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":745500}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":745500},"berthingId":231628,"vesselServiceAssignmentId":524,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":0.0,"pilotArrivalDate":1378908000000,"berthingArrivalDate":1378936800000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378936800000,"customArrivalVoyage":"68E35","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"69W37","dailyvesselschedulecellcompactId":704946,"liveDepartureDate":1379023200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"68E35","departureVoyage":"68E35","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1423,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374220928000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379023200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18511},"operatorContainerMoves20":0,"updateTS":1374248124000,"noonPositionTelex":null,"pilotDepartureDate":1377723600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FL334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374247207487,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":743933,"averageVesselFuelConsumptionPerHour":4.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304946059000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304974859000,"inheritedVoyage":"","adjustmentTime":5,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305147659000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13406},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":10623,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13406},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":5.65,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698940,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305118859000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374247207487,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747002}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747002},"berthingId":231706,"vesselServiceAssignmentId":4573,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1377522000000,"berthingArrivalDate":1377550800000,"operatorContainerMoves40":0,"customArrivalVoyage":"FL334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377741960000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":706429,"liveDepartureDate":1377885960000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FL334A","departureVoyage":"FL334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Gennaro Alessio GARGIULO","userId":18511},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1952,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC FABIOLA","vesselId":4934,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1952,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MFAB","dateOutService":null,"dateInService":1291161600000,"code":"07364","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":366.0,"imoNumber":"9447847","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374248124000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377694800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1374319373000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP339R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374306912050,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744216,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306533630000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306562430000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681491,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374306912050,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747288}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747288},"berthingId":231774,"vesselServiceAssignmentId":2972,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1380924000000,"berthingArrivalDate":1380952800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NP339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380952800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":706711,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP339R","departureVoyage":"NP339R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1293,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374319373000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1374319373000,"noonPositionTelex":null,"pilotDepartureDate":1379282400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374306912050,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744206,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306513410000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304748000000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":750,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304892000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304863200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374306912050,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747277}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747277},"berthingId":231779,"vesselServiceAssignmentId":2972,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1379109600000,"berthingArrivalDate":1379138400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NP336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379138400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":706701,"liveDepartureDate":1379253600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP336R","departureVoyage":"NP337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1293,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374319373000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379253600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374477435000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374332101567,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744278,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305957600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305986400000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732081,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374332101567,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747351}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747351},"berthingId":231786,"vesselServiceAssignmentId":5311,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1380348000000,"berthingArrivalDate":1380376800000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380376800000,"customArrivalVoyage":"BA337R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA337R","dailyvesselschedulecellcompactId":706773,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA337R","departureVoyage":"BA337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374477435000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374477435000,"noonPositionTelex":null,"pilotDepartureDate":1379311200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374332101567,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744276,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305861840000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304776800000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":1680,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304920800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732082,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304892000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374332101567,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747348}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747348},"berthingId":231787,"vesselServiceAssignmentId":5311,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1379138400000,"berthingArrivalDate":1379167200000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379167200000,"customArrivalVoyage":"BA335R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA337A","dailyvesselschedulecellcompactId":706771,"liveDepartureDate":1379282400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA335R","departureVoyage":"BA335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374477435000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379282400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"operatorContainerMoves20":0,"updateTS":1374481839000,"noonPositionTelex":null,"pilotDepartureDate":1379788200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NU338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374468325597,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744500,"averageVesselFuelConsumptionPerHour":2.8,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304627431000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304656231000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304793031000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1059,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246168,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304764231000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374468325597,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747573}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747573},"berthingId":231885,"vesselServiceAssignmentId":4607,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1379622600000,"berthingArrivalDate":1379651400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NU338A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379651400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":706995,"liveDepartureDate":1379759400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NU338A","departureVoyage":"NU338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1195,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374481839000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379759400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17734},"operatorContainerMoves20":0,"updateTS":1374484092000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374471609613,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744512,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304884854000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304913654000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374471609613,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747585}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747585},"berthingId":231902,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1379880000000,"berthingArrivalDate":1379908800000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379908800000,"customArrivalVoyage":"RB337R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB337R","dailyvesselschedulecellcompactId":707007,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB337R","departureVoyage":"RB337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Tamlyn WARD","userId":17734},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374484092000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17734},"operatorContainerMoves20":0,"updateTS":1374484092000,"noonPositionTelex":null,"pilotDepartureDate":1379419200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374471609613,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744509,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304877654000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304308800000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304424000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651687,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304395200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374471609613,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747582}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747582},"berthingId":231903,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1379275200000,"berthingArrivalDate":1379304000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379304000000,"customArrivalVoyage":"RB336R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB337A","dailyvesselschedulecellcompactId":707004,"liveDepartureDate":1379390400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB336R","departureVoyage":"RB336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17734},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374484092000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379390400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374485933000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF338R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374420005520,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744397,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304834400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305468017000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382102,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374420005520,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747470}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747470},"berthingId":231906,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1379829600000,"berthingArrivalDate":1379858400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379851200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":706892,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF338R","departureVoyage":"BF338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374485933000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374485933000,"noonPositionTelex":null,"pilotDepartureDate":1379354400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374420005520,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744393,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305432017000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304964000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382104,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304935200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374420005520,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747466}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747466},"berthingId":231908,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1379224800000,"berthingArrivalDate":1379253600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379246400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":706888,"liveDepartureDate":1379318400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF337R","departureVoyage":"BF338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374485933000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379325600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374487742000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374448820427,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744444,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304863200000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306101655000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382124,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374448820427,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747517}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747517},"berthingId":231932,"vesselServiceAssignmentId":4493,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":0.0,"pilotArrivalDate":1380463200000,"berthingArrivalDate":1380492000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380492000000,"customArrivalVoyage":"BJ338R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ338R","dailyvesselschedulecellcompactId":706939,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ338R","departureVoyage":"BJ338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374487742000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374487742000,"noonPositionTelex":null,"pilotDepartureDate":1379397600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374448820427,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744440,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306068115000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304892000000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382126,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374448820427,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747513}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747513},"berthingId":231934,"vesselServiceAssignmentId":4493,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":0.0,"pilotArrivalDate":1379253600000,"berthingArrivalDate":1379282400000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379282400000,"customArrivalVoyage":"BJ336R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ338A","dailyvesselschedulecellcompactId":706935,"liveDepartureDate":1379368800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ336R","departureVoyage":"BJ336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374487742000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379368800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1374493071000,"noonPositionTelex":null,"pilotDepartureDate":1380175200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"insertTS":1374475521487,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744533,"averageVesselFuelConsumptionPerHour":4.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2199526360000,"isBunkerCall":false,"updateTS":1374828393000,"berthingArrival":-2199497560000,"inheritedVoyage":"","adjustmentTime":151,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":-2199411160000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3610,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":211.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378193,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2199439960000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374475521487,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747606}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747606},"berthingId":231956,"vesselServiceAssignmentId":3024,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1380060000000,"berthingArrivalDate":1380088800000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"dailyVesselScheduleCell":{"liveArrivalDate":1380088800000,"customArrivalVoyage":"00503S","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"00503S","dailyvesselschedulecellcompactId":707028,"liveDepartureDate":1380146400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"00503S","departureVoyage":"00503S","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3125,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CSAV LLUTA","vesselId":8302,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3125,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCLT","dateOutService":null,"dateInService":1337126400000,"code":"08248","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9404209","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374493071000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380146400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"operatorContainerMoves20":0,"updateTS":1374503110000,"noonPositionTelex":null,"pilotDepartureDate":1379440800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374430834847,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744398,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309056347000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304877600000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305050400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617450,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305021600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374430834847,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747471}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747471},"berthingId":232008,"vesselServiceAssignmentId":4195,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":0.0,"pilotArrivalDate":1379239200000,"berthingArrivalDate":1379268000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NG334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379260800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":706893,"liveDepartureDate":1379404800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG334R","departureVoyage":"NG338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17737},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1524,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374503110000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379412000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"operatorContainerMoves20":0,"updateTS":1374506287000,"noonPositionTelex":null,"pilotDepartureDate":1379484000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RM338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374419707067,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744387,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304978400000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":3918,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305093600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14491},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":13152,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14491},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.9,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718756,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305064800000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374419707067,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747460}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747460},"berthingId":232014,"vesselServiceAssignmentId":3077,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1379340000000,"berthingArrivalDate":1379368800000,"operatorContainerMoves40":0,"customArrivalVoyage":"RM338A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379368800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":706882,"liveDepartureDate":1379455200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RM338A","departureVoyage":"RM338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19811},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1393,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374506287000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379455200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1375802264000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1375802262000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375802262000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":755287,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307557732000,"isBunkerCall":false,"updateTS":1375802262000,"berthingArrival":1307586532000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":20820,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1363192570000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"distanceInMiles":1039,"insertTS":1363192570000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427150,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375802262000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":758451}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":758451},"berthingId":232108,"vesselServiceAssignmentId":3082,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1380060000000,"berthingArrivalDate":1380088800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380051120000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":717661,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY336R","departureVoyage":"NY336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1051,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC SOPHIE","vesselId":1662,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1051,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSSP","dateOutService":null,"dateInService":863654400000,"code":"00209","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":242.8,"imoNumber":"9073062","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374510453000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1374510453000,"noonPositionTelex":null,"pilotDepartureDate":1377201600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1374510451000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374510451000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":745242,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1315844661000,"isBunkerCall":false,"updateTS":1375802262000,"berthingArrival":1315873461000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1316010261000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":427152,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308056647000,"isBunkerCall":false,"updateTS":1352210159000,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":790,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"updateTS":1355767493000,"isMaster":true,"isDeleted":false,"insertTS":1352209533000,"isInService":true,"versionInfo":"VERSION 2","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":427152,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":427155,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304640030000,"isBunkerCall":false,"updateTS":1352209533000,"berthingArrival":1304647230000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304740830000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6484},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":2758,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":null,"updateTS":1351093045000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":192,"insertTS":1331980430000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"pilottimeId":6484,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":2,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304733630000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427155,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428269}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":427153,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304787030000,"isBunkerCall":false,"updateTS":1352209533000,"berthingArrival":1304794230000,"inheritedVoyage":"","adjustmentTime":21,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304887830000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":6488,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":7677,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":null,"updateTS":1352209510000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"distanceInMiles":920,"insertTS":1352209510000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"pilottimeId":6481,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304880630000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427153,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428271}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":427157,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305092490000,"isBunkerCall":false,"updateTS":1352209533000,"berthingArrival":1305096090000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305186090000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6493},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":7678,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":null,"updateTS":1352209510000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"distanceInMiles":679,"insertTS":1352209510000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"pilottimeId":6493,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":511},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305182490000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":405},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427157,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428265}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":427154,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305349050000,"isBunkerCall":false,"updateTS":1352209533000,"berthingArrival":1305356250000,"inheritedVoyage":"","adjustmentTime":60,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305449850000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"pilottimeId":6495,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":7339,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":null,"updateTS":1351093045000,"portFrom":{"isTBN":"false","terminals":[{"codeMSC":"CISPYST","isTBN":"false","name":"TERMINAL DE SAN-PEDRO","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":130,"codePort":null}],"name":"SAN PEDRO","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":85,"isRealPort":true,"displayName":"SAN PEDRO","isDeleted":false,"isInService":true,"isoCode":"CISPY","timeZoneDifference":0.0,"netpasName":"San Pedro (CI)"},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"distanceInMiles":1793,"insertTS":1351093045000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"pilottimeId":6489,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305442650000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427154,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428263}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":427158,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305876570000,"isBunkerCall":false,"updateTS":1352209533000,"berthingArrival":1305880170000,"inheritedVoyage":"","adjustmentTime":120,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":85},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305973770000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":130},"pilottimeId":6487,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":85},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":7405,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17740},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":null,"updateTS":1351326490000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":85},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"GHTEMMP","isTBN":"false","name":"MERIDIAN PORT SERVICE LIMITED","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":194,"codePort":null},{"codeMSC":"GHTEMGP","isTBN":"false","name":"GHANA PORT AND HARBOUR AUTHORITIES","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":193,"codePort":null}],"name":"TEMA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":239,"isRealPort":true,"displayName":"TEMA","isDeleted":false,"isInService":true,"isoCode":"GHTEM","timeZoneDifference":0.0,"netpasName":"Tema"},"isDeleted":false,"distanceInMiles":416,"insertTS":1351326490000,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Giuseppe CAPPIELLO","userId":17740}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":130},"pilottimeId":6486,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":85},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305966570000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":130},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427158,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428268}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":427156,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306080810000,"isBunkerCall":false,"updateTS":1352209533000,"berthingArrival":1306088010000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":5760,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":239},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306440810000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6490},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3238,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332852561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":239},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"CIABJSD","isTBN":"false","name":"SOCIETE D-EXPLOTATION TERM. DE VRIDI","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":129,"codePort":null}],"name":"ABIDJAN","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":1,"pilotStations":[],"portId":84,"isRealPort":true,"displayName":"ABIDJAN","isDeleted":false,"isInService":true,"isoCode":"CIABJ","timeZoneDifference":0.0,"netpasName":"Abidjan"},"isDeleted":false,"distanceInMiles":267,"insertTS":1332852561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":193},"pilottimeId":6490,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":239},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1306433610000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":193},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427156,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428267}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":427159,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306505550000,"isBunkerCall":false,"updateTS":1352209533000,"berthingArrival":1306512750000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":4320,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":84},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306779150000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":129},"pilottimeId":6491,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":84},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":7335,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":null,"updateTS":1351093045000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":84},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":85},"isDeleted":false,"distanceInMiles":171,"insertTS":1351093045000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":129},"pilottimeId":6483,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":84},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306771950000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":129},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427159,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428264}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":427161,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306820190000,"isBunkerCall":false,"updateTS":1352209533000,"berthingArrival":1306827390000,"inheritedVoyage":"","adjustmentTime":240,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":85},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307007390000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":130},"pilottimeId":6494,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":85},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":7339,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":130},"pilottimeId":6492,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":85},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":9,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307000190000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":130},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427161,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428266}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":427160,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307454047000,"isBunkerCall":false,"updateTS":1352209533000,"berthingArrival":1307457647000,"inheritedVoyage":"","adjustmentTime":180,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307569247000,"departurePilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"pilottimeId":6480,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3236,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332852561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"isDeleted":false,"distanceInMiles":335,"insertTS":1332852561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":true,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"pilottimeId":6485,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":181},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":10,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307565647000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":452},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427160,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428270}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":427162,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307649647000,"isBunkerCall":false,"updateTS":1352210159000,"berthingArrival":1307653247000,"inheritedVoyage":"","adjustmentTime":31,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"isDeleted":false,"bufferTime":627,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":790,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307743247000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6482},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-2.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":3239,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":null,"updateTS":1332852561000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":1585,"insertTS":1332852561000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"pilottimeId":6482,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"isDeleted":false,"insertTS":1352209533000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"sequence":11,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307739647000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427162,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428273}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":427150,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1304625600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304596800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1352209533000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1352209533000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1352209533000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427152,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":428274}],"dieselConsumption":null},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1315981461000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374510451000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":748306}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":748306},"berthingId":232109,"vesselServiceAssignmentId":5333,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1377036000000,"berthingArrivalDate":1377064800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376956320000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":707749,"liveDepartureDate":1377172800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY334A","departureVoyage":"NY334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1513,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC ASTRID","vesselId":3978,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1513,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1331164740000,"dateInService":1193270400000,"code":"05888","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC ASTRID","vesselId":8196,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1513,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MAST","dateOutService":null,"dateInService":1331164800000,"code":"08158","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":231.0,"imoNumber":"9263344","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374510453000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377172800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1374510453000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY337R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1374510451000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374510451000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":745234,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1319473468000,"isBunkerCall":false,"updateTS":1375802262000,"berthingArrival":1319502268000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":30176,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1375802262000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":0,"insertTS":1375802262000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427150,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374510451000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":748320}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":748320},"berthingId":232117,"vesselServiceAssignmentId":5333,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1380664800000,"berthingArrivalDate":1380693600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380693600000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":707744,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY337R","departureVoyage":"NY337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1513,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374510453000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"operatorContainerMoves20":0,"updateTS":1374570436000,"noonPositionTelex":null,"pilotDepartureDate":1379736000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NZ337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"deleteUser":null,"updateTS":1374570435000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374570435000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":745735,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305165602000,"isBunkerCall":false,"updateTS":1374570435000,"berthingArrival":1305198002000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305345602000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13480},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.75,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701517,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305313202000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374570435000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":748801}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"proformavesselscheduleterminalcallId":748801},"berthingId":232333,"vesselServiceAssignmentId":5874,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1379556000000,"berthingArrivalDate":1379588400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NZ337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379588400000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":708226,"liveDepartureDate":1379703600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NZ337A","departureVoyage":"NZ337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3721,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC AGRIGENTO","vesselId":9159,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3721,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MAGI","dateOutService":null,"dateInService":1373846400000,"code":"08912","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9618276","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374570436000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379703600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8412},"operatorContainerMoves20":0,"updateTS":1374638199000,"noonPositionTelex":null,"pilotDepartureDate":1379270700000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FS337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374605108223,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":746505,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304649950000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304678750000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304880350000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12635,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559561,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304851550000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374605108223,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":749584}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":749584},"berthingId":233180,"vesselServiceAssignmentId":5767,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"draftArrivalAFT":0.0,"pilotArrivalDate":1379040300000,"berthingArrivalDate":1379069100000,"operatorContainerMoves40":0,"customArrivalVoyage":"FS337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379082120000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":708976,"liveDepartureDate":1379254920000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FS337A","departureVoyage":"FS337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8412},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1955,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC FILLIPPA","vesselId":5212,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1955,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MFPP","dateOutService":null,"dateInService":1308528000000,"code":"07655","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":366.0,"imoNumber":"9447902","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374638199000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379241900000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1374655109000,"noonPositionTelex":null,"pilotDepartureDate":1380780000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374619522083,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":746541,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308628094000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304460000000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304575200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374699,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304546400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374619522083,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":749620}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":749620},"berthingId":233234,"vesselServiceAssignmentId":4547,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":0.0,"pilotArrivalDate":1380636000000,"berthingArrivalDate":1380664800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NA336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380664800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":709012,"liveDepartureDate":1380751200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA336R","departureVoyage":"NA340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1840,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374655109000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380751200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374656036000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC338R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374530405237,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":745467,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304344800000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305583245000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439877,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374530405237,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":748541}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":748541},"berthingId":233238,"vesselServiceAssignmentId":5733,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1380549600000,"berthingArrivalDate":1380578400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380636000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":707959,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC338R","departureVoyage":"BC338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1379,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374656036000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374656036000,"noonPositionTelex":null,"pilotDepartureDate":1379484000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374530405237,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":745460,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305543885000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304373600000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304488800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439882,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304460000000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374530405237,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":748534}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":748534},"berthingId":233240,"vesselServiceAssignmentId":5733,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1379340000000,"berthingArrivalDate":1379368800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379448000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":707952,"liveDepartureDate":1379534400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC336R","departureVoyage":"BC338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1379,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374656036000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379455200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374659403000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374592802567,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":746157,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304402400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305640801000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403966,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374592802567,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":749236}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":749236},"berthingId":233270,"vesselServiceAssignmentId":3063,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":0.0,"pilotArrivalDate":1380607200000,"berthingArrivalDate":1380636000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380636000000,"customArrivalVoyage":"BB338R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB338R","dailyvesselschedulecellcompactId":708629,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB338R","departureVoyage":"BB338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374659403000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374659403000,"noonPositionTelex":null,"pilotDepartureDate":1379541600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374592802567,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":746153,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305551521000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304431200000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304546400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403968,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304517600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374592802567,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":749232}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":749232},"berthingId":233272,"vesselServiceAssignmentId":3063,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":0.0,"pilotArrivalDate":1379397600000,"berthingArrivalDate":1379426400000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379426400000,"customArrivalVoyage":"BB336R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB338A","dailyvesselschedulecellcompactId":708625,"liveDepartureDate":1379512800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB336R","departureVoyage":"BB336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374659403000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379512800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374661167000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH338R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374648608083,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":746618,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305698441000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382107,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374648608083,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":749697}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":749697},"berthingId":233276,"vesselServiceAssignmentId":2933,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1380664800000,"berthingArrivalDate":1380693600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380636000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":709089,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH338R","departureVoyage":"BH338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374661167000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374661167000,"noonPositionTelex":null,"pilotDepartureDate":1379599200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374648608083,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":746610,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305650141000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304604000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382113,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304575200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374648608083,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":749689}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":749689},"berthingId":233279,"vesselServiceAssignmentId":2933,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1379455200000,"berthingArrivalDate":1379484000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379426400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":709081,"liveDepartureDate":1379512800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH336R","departureVoyage":"BH338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374661167000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379570400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374661308000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI338R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374493512333,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744861,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304906401000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304935201000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640211,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374493512333,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747935}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747935},"berthingId":233282,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1379901600000,"berthingArrivalDate":1379930400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379930400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":707356,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI338R","departureVoyage":"BI338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374661308000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1374661308000,"noonPositionTelex":null,"pilotDepartureDate":1379412000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374493512333,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":744857,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304902561000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304330400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304416800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640213,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304388000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374493512333,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":747931}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":747931},"berthingId":233284,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1379296800000,"berthingArrivalDate":1379325600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379325600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":707352,"liveDepartureDate":1379383200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI337R","departureVoyage":"BI338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374661308000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379383200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1374678061000,"noonPositionTelex":null,"pilotDepartureDate":1378349940000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"insertTS":1374659451363,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":746710,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Renan BRASIL","userId":18516},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309423083000,"isBunkerCall":false,"updateTS":1375385362000,"berthingArrival":1309441083000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1020,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1309520283000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":11345,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":17.97,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":708178,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305072004000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1305090004000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1020,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":1455,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"updateTS":1370525256000,"isMaster":true,"isDeleted":false,"insertTS":1370525256000,"isInService":true,"versionInfo":"NWC TO SAEC  string 4 08/01","version":2,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":708177,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308773459000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1304546400000,"inheritedVoyage":"","adjustmentTime":38,"timeInPort":1740,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304658000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14183},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13573,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":134,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":343},"pilottimeId":14183,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":16.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304650800000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":343},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708177,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710700}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708175,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304686830000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1304694030000,"inheritedVoyage":"","adjustmentTime":2,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304787630000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14188},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13578,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"distanceInMiles":328,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"pilottimeId":14188,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":37.92,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.3,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304780430000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708175,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710697}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708180,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304859604000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1304881204000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2040,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305025204000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14182},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13581,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":234,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":360.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1012},"pilottimeId":14182,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":26.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305003604000,"pilotStation":{"?p":"true","pilotstationId":5,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1012},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708180,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710699}],"dieselConsumption":null},{"?p":"true","proformavesselscheduleportId":708178,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":708176,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305201603000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1305208803000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305273603000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14190},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-7.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13594,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"isDeleted":false,"distanceInMiles":5089,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171},"pilottimeId":14190,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":591.74,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.2,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305266403000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708176,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710693}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708179,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306314022000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1306324822000,"inheritedVoyage":"","adjustmentTime":31,"timeInPort":360,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306357222000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14181},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13590,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"distanceInMiles":181,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":180.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"pilottimeId":14181,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":6,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":19.05,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1306346422000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708179,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710691}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708181,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306400456000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1306404056000,"inheritedVoyage":"","adjustmentTime":122,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306515656000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14180},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13592,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"distanceInMiles":166,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":70},"pilottimeId":14180,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":29.91,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":11.1,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306512056000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":70},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708181,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710694}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708185,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306576814000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1306584014000,"inheritedVoyage":"","adjustmentTime":52,"timeInPort":1140,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306659614000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14187},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13595,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":27,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"isDeleted":false,"distanceInMiles":772,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"pilottimeId":14187,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":8,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":110.29,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306652414000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708185,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710692}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708184,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306861248000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1306864848000,"inheritedVoyage":"","adjustmentTime":420,"timeInPort":3300,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307066448000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14192},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13591,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":27,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"isDeleted":false,"distanceInMiles":20,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1168},"pilottimeId":14192,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":24},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":4.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":10.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307062848000,"pilotStation":{"?p":"true","pilotstationId":27,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1168},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708184,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710696}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708182,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307098848000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1307102448000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307170848000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14185},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13598,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"ARRGA9Z","isTBN":"false","name":"RIO GRANDE","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":657,"codePort":null}],"name":"RIO GRANDE (ARGENTINA )","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":27,"isRealPort":true,"displayName":"RIO GRANDE","isDeleted":false,"isInService":true,"isoCode":"ARRGA","timeZoneDifference":-4.0,"netpasName":null},"isDeleted":false,"distanceInMiles":314,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":570},"pilottimeId":14185,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":33.95,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307167248000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":570},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708182,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710702}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708186,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307228411000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1307232011000,"inheritedVoyage":"","adjustmentTime":107,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":27},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307307611000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14189},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13589,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":27},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"BRIOAAA","isTBN":"false","name":"ITAPO� TERMINAIS PORTU�RIOS S/A","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1192,"codePort":null}],"name":"ITAPOA","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":null,"pilotStations":[],"portId":864,"isRealPort":true,"displayName":"ITAPOA","isDeleted":false,"isInService":true,"isoCode":"BRIOA","timeZoneDifference":-3.0,"netpasName":null},"isDeleted":false,"distanceInMiles":455,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":657},"pilottimeId":14189,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":27},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":11,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":39.57,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":23.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307304011000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":657},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708186,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710698}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708187,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307376008000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1307383208000,"inheritedVoyage":"","adjustmentTime":7,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":864},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307455208000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14186},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13597,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":864},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"distanceInMiles":188,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1192},"pilottimeId":14186,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":864},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":19.79,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307448008000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1192},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708187,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710701}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708183,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307491250000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1307494850000,"inheritedVoyage":"","adjustmentTime":4,"timeInPort":1740,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307602850000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14180},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":3.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13588,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"portTo":{"isTBN":"false","terminals":[{"codeMSC":"MAPTMAA","isTBN":"false","name":"TANGER MED","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1247,"codePort":null}],"name":"TANGER MED","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":null,"pilotStations":[],"portId":880,"isRealPort":true,"displayName":"TANGER MED","isDeleted":false,"isInService":true,"isoCode":"MAPTM","timeZoneDifference":0.0,"netpasName":null},"isDeleted":false,"distanceInMiles":4347,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14180},"sequence":13,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":445.85,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307599250000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":70},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708183,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710703}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":708188,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308416413000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1308423613000,"inheritedVoyage":"","adjustmentTime":169,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":880},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1455,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1308517213000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14184},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":13603,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":null,"updateTS":1357663033000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":880},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"distanceInMiles":1310,"insertTS":1357663033000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1247},"pilottimeId":14184,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":880},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":134.36,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1308510013000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1247},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708188,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710705}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":708174,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308772799000,"isBunkerCall":false,"updateTS":1370525220000,"berthingArrival":1308779999000,"inheritedVoyage":"","adjustmentTime":38,"timeInPort":1740,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14183},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":13573,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14183},"sequence":15,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":16.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":343},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708174,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710704}],"dieselConsumption":null},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1305169204000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":11345,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1355479722000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"isDeleted":false,"distanceInMiles":159,"insertTS":1355479722000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"pilotOnOffBoard":300.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"pilottimeId":14191,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1370525256000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":17.97,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305151204000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1370525256000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1370525256000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"insertTS":1370525256000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708178,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":710695}],"dieselConsumption":null},"speed":17.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309502283000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374659451363,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":749791}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":749791},"berthingId":233396,"vesselServiceAssignmentId":5635,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1378252740000,"berthingArrivalDate":1378270740000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"dailyVesselScheduleCell":{"liveArrivalDate":1378263540000,"customArrivalVoyage":"336","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"336","dailyvesselschedulecellcompactId":709177,"liveDepartureDate":1378324740000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"336","departureVoyage":"336","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1012},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3122,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"SANTA ROSA","vesselId":8299,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3122,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCTO","dateOutService":null,"dateInService":1334793600000,"code":"08245","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9430363","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"SAEIV","isStandardMSCVoyageCoding":false,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":false,"isInService":true,"repeatWeeks":6,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"808080","laneCode":"SAEIV","useWeeklyVoyageNumbers":false,"name":"NWC TO SAEC - STRING IV","exceedingDateOffset":8640,"isScheduleDelayDisplayed":true,"serviceId":266,"incrementVoyageNumberOnRoutingSwitch":true,"tradeCode":"ME","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374678061000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378331940000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1374678061000,"noonPositionTelex":null,"pilotDepartureDate":1377745140000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"insertTS":1374659451817,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":746725,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Caue FELIPE","userId":13720},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309423083000,"isBunkerCall":false,"updateTS":1374873991000,"berthingArrival":1309441083000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1020,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1309520283000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":11345,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":17.97,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708178,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309502283000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374659451817,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":749806}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":749806},"berthingId":233411,"vesselServiceAssignmentId":5636,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1377647940000,"berthingArrivalDate":1377665940000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"dailyVesselScheduleCell":{"liveArrivalDate":1377655140000,"customArrivalVoyage":"335","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"335","dailyvesselschedulecellcompactId":709192,"liveDepartureDate":1377716340000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"335","departureVoyage":"335","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1012},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3120,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"SANTA CLARA","vesselId":8296,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3120,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCSR","dateOutService":null,"dateInService":1334188800000,"code":"08242","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9444716","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374678061000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377727140000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1374678061000,"noonPositionTelex":null,"pilotDepartureDate":1377140340000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"insertTS":1374100847467,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":742491,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13720},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309423083000,"isBunkerCall":false,"updateTS":1374873890000,"berthingArrival":1309441083000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1020,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1309520283000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":11345,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":17.97,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708178,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309502283000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374100847467,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":745548}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":745548},"berthingId":233426,"vesselServiceAssignmentId":5637,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1377043140000,"berthingArrivalDate":1377061140000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"dailyVesselScheduleCell":{"liveArrivalDate":1377247200000,"customArrivalVoyage":"334","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"334","dailyvesselschedulecellcompactId":704992,"liveDepartureDate":1377308400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"334","departureVoyage":"334","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1012},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":2935,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"SANTA CRUZ","vesselId":8014,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2935,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1329436740000,"dateInService":1326153600000,"code":"08012","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"SANTA CRUZ","vesselId":8297,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2935,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCCZ","dateOutService":null,"dateInService":1337817600000,"code":"08243","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9444742","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374678061000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377122340000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1374744298000,"noonPositionTelex":null,"pilotDepartureDate":1379829600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NM338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374736806797,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":747461,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304690440000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304719240000,"inheritedVoyage":"","adjustmentTime":92,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304834440000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2734,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55406,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805640000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374736806797,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":750548}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":750548},"berthingId":233954,"vesselServiceAssignmentId":693,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1379685600000,"berthingArrivalDate":1379714400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NM338A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379714400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":709904,"liveDepartureDate":1379800800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NM338A","departureVoyage":"NM338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1781,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374744298000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379800800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375451928000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA331R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375451926000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375451926000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753062,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308305317000,"isBunkerCall":false,"updateTS":1375451926000,"berthingArrival":1308334117000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374691,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375451926000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756195}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":756195},"berthingId":234085,"vesselServiceAssignmentId":5895,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":0.0,"pilotArrivalDate":1377612000000,"berthingArrivalDate":1377640800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NA331R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":61},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377640800000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":715462,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA331R","departureVoyage":"NA331R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3789,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC SHENZHEN","vesselId":9257,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3789,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSHZ","dateOutService":null,"dateInService":1372118400000,"code":"08998","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9285653","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374757747000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":66},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1374757747000,"noonPositionTelex":null,"pilotDepartureDate":1377756000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1374757745000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374757745000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":747788,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304431200000,"isBunkerCall":false,"updateTS":1374757745000,"berthingArrival":1304460000000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304575200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374699,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304546400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374757745000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":750867}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":750867},"berthingId":234100,"vesselServiceAssignmentId":5895,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":0.0,"pilotArrivalDate":1377612000000,"berthingArrivalDate":1377640800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NA335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377640800000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":710223,"liveDepartureDate":1377727200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA335A","departureVoyage":"NA335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3789,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374757747000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377727200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1374828877000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1374828873000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374828873000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":748482,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308088807000,"isBunkerCall":false,"updateTS":1374828873000,"berthingArrival":1308117607000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427150,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374828873000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":751551}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":751551},"berthingId":234314,"vesselServiceAssignmentId":4383,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1379455200000,"berthingArrivalDate":1379484000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379484000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":710896,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY335R","departureVoyage":null,"isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1038,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC ROSSELLA","vesselId":1704,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1038,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSRL","dateOutService":null,"dateInService":881712000000,"code":"00475","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":242.8,"imoNumber":"9065443","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374828877000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1375118542000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1375118539000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375118539000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750659,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307963602000,"isBunkerCall":false,"updateTS":1375118539000,"berthingArrival":1307992402000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427150,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375118539000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753771}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":753771},"berthingId":234342,"vesselServiceAssignmentId":3083,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1378850400000,"berthingArrivalDate":1378879200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379011920000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":713053,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY334R","departureVoyage":null,"isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1245,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC CHRISTINA","vesselId":3960,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1245,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"CHRI","dateOutService":1315526340000,"dateInService":1191196800000,"code":"05856","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC PAOLA","vesselId":5429,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1245,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1330646340000,"dateInService":1315526400000,"code":"07797","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC PAOLA","vesselId":8192,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1245,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MPAO","dateOutService":null,"dateInService":1330646400000,"code":"08154","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":243.0,"imoNumber":"9161297","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374828877000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1374832592000,"noonPositionTelex":null,"pilotDepartureDate":1379656800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374704406217,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":747238,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306933252000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304546400000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304661600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4046,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304632800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374704406217,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":750323}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":750323},"berthingId":234413,"vesselServiceAssignmentId":525,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":0.0,"pilotArrivalDate":1379512800000,"berthingArrivalDate":1379541600000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379541600000,"customArrivalVoyage":"23E36","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"24W38","dailyvesselschedulecellcompactId":709681,"liveDepartureDate":1379628000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"23E36","departureVoyage":"23E36","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1287,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374832592000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379628000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13720},"operatorContainerMoves20":0,"updateTS":1374873764000,"noonPositionTelex":null,"pilotDepartureDate":1378954680000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"insertTS":1374704753060,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":747284,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305072004000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305090004000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1020,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305169204000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":11345,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":17.97,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708178,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305151204000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374704753060,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":750371}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":750371},"berthingId":234639,"vesselServiceAssignmentId":5634,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1378857480000,"berthingArrivalDate":1378875480000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"dailyVesselScheduleCell":{"liveArrivalDate":1378879140000,"customArrivalVoyage":"337","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"337","dailyvesselschedulecellcompactId":709727,"liveDepartureDate":1378940340000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"337","departureVoyage":"337","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1012},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13720},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3119,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"SANTA CATARINA","vesselId":8295,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3119,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCHN","dateOutService":null,"dateInService":1335398400000,"code":"08241","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9444730","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1374873764000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378936680000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":4001},"operatorContainerMoves20":0,"updateTS":1375067894000,"noonPositionTelex":null,"pilotDepartureDate":1378328400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FL335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374852008070,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":748709,"averageVesselFuelConsumptionPerHour":4.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304946059000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304974859000,"inheritedVoyage":"","adjustmentTime":5,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305147659000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13406},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":10623,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13406},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":5.65,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698940,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305118859000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374852008070,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":751800}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":751800},"berthingId":234692,"vesselServiceAssignmentId":3603,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1378126800000,"berthingArrivalDate":1378155600000,"operatorContainerMoves40":0,"customArrivalVoyage":"FL335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378290600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":711132,"liveDepartureDate":1378434600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FL335A","departureVoyage":"FL335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":4001},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1996,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC ARIANE","vesselId":5653,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1996,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MARI","dateOutService":null,"dateInService":1326844800000,"code":"07970","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":365.5,"imoNumber":"9484443","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375067894000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378299600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"operatorContainerMoves20":0,"updateTS":1375085626000,"noonPositionTelex":null,"pilotDepartureDate":1380340800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NZ338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374867028397,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749066,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305165602000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305198002000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305345602000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13480},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701517,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305313202000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374867028397,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":752157}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":752157},"berthingId":234736,"vesselServiceAssignmentId":5481,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1380160800000,"berthingArrivalDate":1380193200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NZ338A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380206760000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":711489,"liveDepartureDate":1380321960000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NZ338A","departureVoyage":"NZ338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3654,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC ATHOS","vesselId":9075,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3654,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MATO","dateOutService":null,"dateInService":1365552000000,"code":"08840","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":299.0,"imoNumber":"9618317","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375085626000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380308400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375086176000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374934501633,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749651,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305957600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305986400000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732081,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1374934501633,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":752744}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":752744},"berthingId":234764,"vesselServiceAssignmentId":2920,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1380952800000,"berthingArrivalDate":1380981600000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380981600000,"customArrivalVoyage":"BA338R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA338R","dailyvesselschedulecellcompactId":712074,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA338R","departureVoyage":"BA338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":770,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375086176000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375086176000,"noonPositionTelex":null,"pilotDepartureDate":1379916000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374934501633,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749649,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305861840000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304776800000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":1680,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304920800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732082,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304892000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374934501633,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":752741}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":752741},"berthingId":234765,"vesselServiceAssignmentId":2920,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1379743200000,"berthingArrivalDate":1379772000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379772000000,"customArrivalVoyage":"BA336R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA338A","dailyvesselschedulecellcompactId":712072,"liveDepartureDate":1379887200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA336R","departureVoyage":"BA336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":770,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375086176000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379887200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"operatorContainerMoves20":0,"updateTS":1375086217000,"noonPositionTelex":null,"pilotDepartureDate":1380045600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375038937337,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749936,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309056347000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304877600000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305050400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617450,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305021600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375038937337,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753035}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753035},"berthingId":234781,"vesselServiceAssignmentId":4728,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":0.0,"pilotArrivalDate":1379844000000,"berthingArrivalDate":1379872800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NG335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379815200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":712357,"liveDepartureDate":1379959200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG335R","departureVoyage":"NG339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1399,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375086217000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380016800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"operatorContainerMoves20":0,"updateTS":1375087683000,"noonPositionTelex":null,"pilotDepartureDate":1380393000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NU339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375072531337,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750047,"averageVesselFuelConsumptionPerHour":2.8,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304627431000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304656231000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304793031000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1059,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246168,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304764231000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375072531337,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753146}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753146},"berthingId":234790,"vesselServiceAssignmentId":4874,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1380227400000,"berthingArrivalDate":1380256200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NU339A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380256200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":712468,"liveDepartureDate":1380364200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NU339A","departureVoyage":"NU339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1922,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375087683000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380364200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20364},"operatorContainerMoves20":0,"updateTS":1375088306000,"noonPositionTelex":null,"pilotDepartureDate":1379887200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1374907814553,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749228,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306513410000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304748000000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":750,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304892000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304863200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1374907814553,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":752319}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":752319},"berthingId":234804,"vesselServiceAssignmentId":4913,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1379714400000,"berthingArrivalDate":1379743200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NP337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379743200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":711651,"liveDepartureDate":1379858400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP337R","departureVoyage":"NP338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20364},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1042,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375088306000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379858400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17734},"operatorContainerMoves20":0,"updateTS":1375088767000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375076111023,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750064,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304884854000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304913654000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375076111023,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753163}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753163},"berthingId":234811,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1380484800000,"berthingArrivalDate":1380513600000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380513600000,"customArrivalVoyage":"RB338R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB338R","dailyvesselschedulecellcompactId":712485,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB338R","departureVoyage":"RB338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17734},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375088767000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17734},"operatorContainerMoves20":0,"updateTS":1375088767000,"noonPositionTelex":null,"pilotDepartureDate":1380024000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375076111023,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750061,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304877654000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304308800000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304424000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651687,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304395200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375076111023,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753160}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753160},"berthingId":234812,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1379880000000,"berthingArrivalDate":1379908800000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379908800000,"customArrivalVoyage":"RB337R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB338A","dailyvesselschedulecellcompactId":712482,"liveDepartureDate":1379995200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB337R","departureVoyage":"RB337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17734},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375088767000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379995200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375090556000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF339R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375026306147,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749935,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304834400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305468017000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382102,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375026306147,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753034}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753034},"berthingId":234821,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1380434400000,"berthingArrivalDate":1380463200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380456000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":712356,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF339R","departureVoyage":"BF339R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375090556000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375090556000,"noonPositionTelex":null,"pilotDepartureDate":1379959200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375026306147,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749931,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305432017000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304964000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382104,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304935200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375026306147,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753030}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753030},"berthingId":234823,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1379829600000,"berthingArrivalDate":1379858400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379851200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":712352,"liveDepartureDate":1379923200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF338R","departureVoyage":"BF339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375090556000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379930400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375091243000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375051512053,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749982,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304863200000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1306101655000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382124,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375051512053,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753081}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753081},"berthingId":234830,"vesselServiceAssignmentId":4494,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":0.0,"pilotArrivalDate":1381068000000,"berthingArrivalDate":1381096800000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381060800000,"customArrivalVoyage":"BJ339R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ339R","dailyvesselschedulecellcompactId":712403,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ339R","departureVoyage":"BJ339R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3133,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091243000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375091243000,"noonPositionTelex":null,"pilotDepartureDate":1380002400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375051512053,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749978,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306068115000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304892000000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382126,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375051512053,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753077}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753077},"berthingId":234832,"vesselServiceAssignmentId":4494,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":0.0,"pilotArrivalDate":1379858400000,"berthingArrivalDate":1379887200000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379851200000,"customArrivalVoyage":"BJ337R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ339A","dailyvesselschedulecellcompactId":712399,"liveDepartureDate":1379937600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ337R","departureVoyage":"BJ337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3133,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091243000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379973600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP338R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750253,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304812800000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304841605000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":315676,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304812800000,"isBunkerCall":false,"updateTS":1346879754000,"berthingArrival":1305446405000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"deleteUser":null,"pilotStationFrom":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateTS":1323872985920,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"isDeleted":false,"distanceInMiles":499,"insertTS":1323872985920,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1346879754000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"pilottimeId":4697,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1346879754000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1346879754000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1346879754000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1346879754000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315676,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":316242}],"dieselConsumption":null},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753343}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753343},"berthingId":234833,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1379808000000,"berthingArrivalDate":1379836800000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379836800000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712675,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP338R","departureVoyage":"RP338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"HANSE COURAGE","vesselId":4348,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MHCO","dateOutService":null,"dateInService":1240358400000,"code":"06590","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"X-PRESS ELBRUS","vesselId":7078,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1218499140000,"dateInService":1207526400000,"code":"06060","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":140.4,"imoNumber":"9318773","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"PRU","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":1320652800000,"includesAllPortCalls":true,"isInService":true,"repeatWeeks":8,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"6b8e23","laneCode":"PRUDK","useWeeklyVoyageNumbers":true,"name":"ANTWERP TO/FROM PORTBURY DUNKERQUE - FEEDER SERVICE","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":76,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"RP","dailyVesselScheduleAllowedDelay":60,"inheritsDelay":true},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"isTBN":"false","terminals":[{"codeMSC":"GBPRUBP","isTBN":"false","name":"BRISTOL PORT COMPANY","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532,"codePort":null}],"name":"PORTBURY","?t":"com.msc.medlog.mwp.entities.Port","timeToBerth":0,"pilotStations":[],"portId":226,"isRealPort":true,"displayName":"PORTBURY","isDeleted":false,"isInService":true,"isoCode":"GBPRU","timeZoneDifference":0.0,"netpasName":"Portbury"},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":1379995200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750254,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304208000000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304236800000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304395200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":315677,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305387185000,"isBunkerCall":false,"updateTS":1346879754000,"berthingArrival":1304841600000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":589,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"deleteUser":null,"updateTS":1355477690000,"isMaster":true,"isDeleted":false,"insertTS":1346879754000,"isInService":true,"versionInfo":"Antwerp to Portbury / Dunkerque Feeder (Start Sun)","version":1,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"?p":"true","proformavesselscheduleportId":315677,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":315678,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305115232000,"isBunkerCall":false,"updateTS":1346879754000,"berthingArrival":1305122432000,"inheritedVoyage":"","adjustmentTime":144,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":589,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305259232000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4696},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":17,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"deleteUser":null,"pilotStationFrom":null,"updateTS":1323872985920,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"isDeleted":false,"distanceInMiles":485,"insertTS":1323872985920,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1346879754000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"pilottimeId":4696,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"isDeleted":false,"insertTS":1346879754000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":2,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1305252032000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1346879754000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1346879754000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"insertTS":1346879754000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315678,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":316243}],"dieselConsumption":null},{"mergedSequence":null,"proformavesselscheduleportId":315679,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305356410000,"isBunkerCall":false,"updateTS":1346879754000,"berthingArrival":1305360010000,"inheritedVoyage":"","adjustmentTime":128,"timeInPort":360,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"isDeleted":false,"bufferTime":319,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":589,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305385210000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4698},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":15,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"deleteUser":null,"pilotStationFrom":null,"updateTS":1323872985920,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"distanceInMiles":24,"insertTS":1323872985920,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1346879754000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"pilottimeId":4698,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"isDeleted":false,"insertTS":1346879754000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732}},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305381610000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1346879754000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1346879754000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"insertTS":1346879754000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315679,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":316244}],"dieselConsumption":null}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"?p":"true","proformavesselscheduleportId":315676,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1305000000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304971200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1346879754000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"deleteUser":null,"updateTS":1346879754000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1346879754000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315677,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17732},"proformavesselscheduleterminalcallId":316245}],"dieselConsumption":null},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304366400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753362}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753362},"berthingId":234835,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1379808000000,"berthingArrivalDate":1379836800000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP339A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379836800000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712679,"liveDepartureDate":1379966400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP339A","departureVoyage":"RP339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379966400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP339R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750266,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304812800000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304841605000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315676,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753360}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753360},"berthingId":234841,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1380412800000,"berthingArrivalDate":1380441600000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380441600000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712685,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP339R","departureVoyage":"RP339R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP333R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750262,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304812800000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304841605000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315676,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753346}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753346},"berthingId":234843,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1376784000000,"berthingArrivalDate":1376812800000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP333R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376812800000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712666,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP333R","departureVoyage":"RP333R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":1379390400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750268,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304208000000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304236800000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304395200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315677,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304366400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753347}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753347},"berthingId":234844,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1379203200000,"berthingArrivalDate":1379232000000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP338A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379232000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712663,"liveDepartureDate":1379361600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP338A","departureVoyage":"RP338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379361600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP336R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750259,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304812800000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304841605000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315676,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753369}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753369},"berthingId":234850,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1378598400000,"berthingArrivalDate":1378627200000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378627200000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712668,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP336R","departureVoyage":"RP336R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP337R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750247,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304812800000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304841605000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315676,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753363}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753363},"berthingId":234851,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1379203200000,"berthingArrivalDate":1379232000000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379232000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712687,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP337R","departureVoyage":"RP337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP334R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750265,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304812800000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304841605000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315676,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753348}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753348},"berthingId":234852,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1377388800000,"berthingArrivalDate":1377417600000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP334R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377417600000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712688,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP334R","departureVoyage":"RP334R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":1378785600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750240,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304208000000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304236800000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304395200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315677,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304366400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753359}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753359},"berthingId":234853,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1378598400000,"berthingArrivalDate":1378627200000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378627200000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712674,"liveDepartureDate":1378756800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP337A","departureVoyage":"RP337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378756800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP335R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750270,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304812800000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304841605000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315676,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753366}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753366},"berthingId":234855,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1377993600000,"berthingArrivalDate":1378022400000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP335R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378022400000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712683,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP335R","departureVoyage":"RP335R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":1376971200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750261,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304208000000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304236800000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304395200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315677,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304366400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753353}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753353},"berthingId":234858,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1376784000000,"berthingArrivalDate":1376812800000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1376812800000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712678,"liveDepartureDate":1376942400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP334A","departureVoyage":"RP334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376942400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":1378180800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750249,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304208000000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304236800000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304395200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315677,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304366400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753355}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753355},"berthingId":234862,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1377993600000,"berthingArrivalDate":1378022400000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378022400000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712681,"liveDepartureDate":1378152000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP336A","departureVoyage":"RP336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378152000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375091351000,"noonPositionTelex":null,"pilotDepartureDate":1377576000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"deleteUser":null,"updateTS":1375091350000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375091350000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750250,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304208000000,"isBunkerCall":false,"updateTS":1375091350000,"berthingArrival":1304236800000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304395200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315677,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304366400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375091350000,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753371}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"proformavesselscheduleterminalcallId":753371},"berthingId":234864,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1377388800000,"berthingArrivalDate":1377417600000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377417600000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712662,"liveDepartureDate":1377547200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP335A","departureVoyage":"RP335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375091351000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377547200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1375093693000,"noonPositionTelex":null,"pilotDepartureDate":1377583200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NC334A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"deleteUser":null,"updateTS":1375093692000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375093692000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750285,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304843432000,"isBunkerCall":false,"updateTS":1375093692000,"berthingArrival":1304872232000,"inheritedVoyage":"","adjustmentTime":97,"timeInPort":1770,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007232000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2673,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52229,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978432000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375093692000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753382}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"proformavesselscheduleterminalcallId":753382},"berthingId":234865,"vesselServiceAssignmentId":5906,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1377419400000,"berthingArrivalDate":1377448200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NC334A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377448200000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712721,"liveDepartureDate":1377554400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NC334A","departureVoyage":"NC334A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1083,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC COLOMBIA","vesselId":3784,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1083,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MCOL","dateOutService":1339459140000,"dateInService":1169251200000,"code":"05540","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC BRIANNA","vesselId":9299,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1083,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MBRN","dateOutService":null,"dateInService":1372809600000,"code":"09035","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":293.5,"imoNumber":"9103685","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375093693000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377554400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1375093693000,"noonPositionTelex":null,"pilotDepartureDate":1380002400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NC338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"deleteUser":null,"updateTS":1375093692000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375093692000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750287,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304843432000,"isBunkerCall":false,"updateTS":1375093692000,"berthingArrival":1304872232000,"inheritedVoyage":"","adjustmentTime":97,"timeInPort":1770,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007232000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2673,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52229,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978432000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375093692000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753395}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"proformavesselscheduleterminalcallId":753395},"berthingId":234873,"vesselServiceAssignmentId":5906,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1379838600000,"berthingArrivalDate":1379867400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NC338A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379867400000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":712704,"liveDepartureDate":1379973600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NC338A","departureVoyage":"NC338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1083,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375093693000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379973600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375103822000,"noonPositionTelex":null,"pilotDepartureDate":1380780000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"insertTS":1375080025647,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750085,"averageVesselFuelConsumptionPerHour":4.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":-2208218371000,"isBunkerCall":false,"updateTS":null,"berthingArrival":-2208189571000,"inheritedVoyage":"","adjustmentTime":151,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":-2208103171000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3610,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5786},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":211.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":378193,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":19.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":-2208131971000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375080025647,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753184}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753184},"berthingId":234895,"vesselServiceAssignmentId":3025,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1380664800000,"berthingArrivalDate":1380693600000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":404},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1160},"dailyVesselScheduleCell":{"liveArrivalDate":1380693600000,"customArrivalVoyage":"00505S","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"00505S","dailyvesselschedulecellcompactId":712506,"liveDepartureDate":1380751200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"00505S","departureVoyage":"00505S","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3130,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"LONGAVI","vesselId":8312,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3130,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCCL","dateOutService":null,"dateInService":1337731200000,"code":"08256","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9294836","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":68},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375103822000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380751200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":506},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19805},"operatorContainerMoves20":0,"updateTS":1375108684000,"noonPositionTelex":null,"pilotDepartureDate":1380088800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RM339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375026008837,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":749925,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304978400000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":3918,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305093600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12890},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":13152,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12890},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.9,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":676870,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305064800000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375026008837,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753024}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753024},"berthingId":234936,"vesselServiceAssignmentId":4472,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1379944800000,"berthingArrivalDate":1379973600000,"operatorContainerMoves40":0,"customArrivalVoyage":"RM339A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379973600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":712346,"liveDepartureDate":1380060000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RM339A","departureVoyage":"RM339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19805},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3593,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375108684000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380060000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8412},"operatorContainerMoves20":0,"updateTS":1375251208000,"noonPositionTelex":null,"pilotDepartureDate":1379875500000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FS338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375213208427,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":751363,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304649950000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304678750000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304880350000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12635,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559561,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304851550000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375213208427,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":754477}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":754477},"berthingId":235319,"vesselServiceAssignmentId":4080,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"draftArrivalAFT":0.0,"pilotArrivalDate":1379645100000,"berthingArrivalDate":1379673900000,"operatorContainerMoves40":0,"customArrivalVoyage":"FS338A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379673900000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":713773,"liveDepartureDate":1379846700000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FS338A","departureVoyage":"FS338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":8412},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":2972,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC VANDYA","vesselId":8067,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2972,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVAN","dateOutService":null,"dateInService":1331769600000,"code":"08051","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":366.0,"imoNumber":"9484467","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375251208000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379846700000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375259533000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375193703850,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":751276,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304402400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305640801000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403966,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375193703850,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":754390}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":754390},"berthingId":235324,"vesselServiceAssignmentId":3064,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":0.0,"pilotArrivalDate":1381212000000,"berthingArrivalDate":1381240800000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381240800000,"customArrivalVoyage":"BB339R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB339R","dailyvesselschedulecellcompactId":713686,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB339R","departureVoyage":"BB339R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":768,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375259533000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375259533000,"noonPositionTelex":null,"pilotDepartureDate":1380146400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375193703850,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":751272,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305551521000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304431200000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304546400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403968,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304517600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375193703850,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":754386}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":754386},"berthingId":235326,"vesselServiceAssignmentId":3064,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":0.0,"pilotArrivalDate":1380002400000,"berthingArrivalDate":1380031200000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380031200000,"customArrivalVoyage":"BB337R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB339A","dailyvesselschedulecellcompactId":713682,"liveDepartureDate":1380117600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB337R","departureVoyage":"BB337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":768,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375259533000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380117600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375259999000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC339R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375139413303,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750732,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304344800000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305583245000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439877,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375139413303,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753834}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753834},"berthingId":235330,"vesselServiceAssignmentId":5329,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1381154400000,"berthingArrivalDate":1381183200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381190400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":713142,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC339R","departureVoyage":"BC339R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1801,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375259999000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375259999000,"noonPositionTelex":null,"pilotDepartureDate":1380088800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375139413303,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750725,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305543885000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304373600000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304488800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439882,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304460000000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375139413303,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753827}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753827},"berthingId":235332,"vesselServiceAssignmentId":5329,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1379944800000,"berthingArrivalDate":1379973600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380002400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":713135,"liveDepartureDate":1380088800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC337R","departureVoyage":"BC339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1801,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375259999000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380060000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1375260838000,"noonPositionTelex":null,"pilotDepartureDate":1380283200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NW339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375168518670,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750823,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517635000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304546435000,"inheritedVoyage":"","adjustmentTime":2396,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304683235000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22167,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":21.23,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304654435000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375168518670,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753930}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753930},"berthingId":235360,"vesselServiceAssignmentId":1910,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1380117600000,"berthingArrivalDate":1380146400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NW339A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380159360000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":713233,"liveDepartureDate":1380267360000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NW339A","departureVoyage":"NW339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":2977,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"CSAV RIO DE JANEIRO","vesselId":8074,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2977,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1351727940000,"dateInService":1327536000000,"code":"08059","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"CSAV RIO DE JANEIRO","vesselId":8822,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":2977,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MCRC","dateOutService":null,"dateInService":1351728000000,"code":"08601","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":294.1,"imoNumber":"9407885","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375260838000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380254400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375262044000,"noonPositionTelex":null,"pilotDepartureDate":1381384800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NA341A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375227923397,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":751385,"averageVesselFuelConsumptionPerHour":2.1,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308628094000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304460000000,"inheritedVoyage":"","adjustmentTime":9,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304575200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3722,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5756},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":8.1,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":374699,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304546400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375227923397,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":754499}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":754499},"berthingId":235405,"vesselServiceAssignmentId":3494,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":61},"draftArrivalAFT":0.0,"pilotArrivalDate":1381240800000,"berthingArrivalDate":1381269600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NA337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381269600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":713795,"liveDepartureDate":1381356000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NA337R","departureVoyage":"NA341A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":57},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1478,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":67},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375262044000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1381356000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375262944000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH339R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375256109600,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":751526,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305698441000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382107,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375256109600,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":754640}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":754640},"berthingId":235416,"vesselServiceAssignmentId":5704,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1381269600000,"berthingArrivalDate":1381298400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381194000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":713936,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH339R","departureVoyage":"BH339R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3240,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375262944000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375262944000,"noonPositionTelex":null,"pilotDepartureDate":1380204000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375256109600,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":751518,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305650141000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304604000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382113,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304575200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375256109600,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":754632}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":754632},"berthingId":235419,"vesselServiceAssignmentId":5704,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1380060000000,"berthingArrivalDate":1380088800000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH337R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379984400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":713928,"liveDepartureDate":1380070800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH337R","departureVoyage":"BH339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3240,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375262944000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380175200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375263466000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI339R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375098010413,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750319,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304906401000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304935201000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640211,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375098010413,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753419}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753419},"berthingId":235422,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1380506400000,"berthingArrivalDate":1380535200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380535200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":712739,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI339R","departureVoyage":"BI339R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375263466000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375263466000,"noonPositionTelex":null,"pilotDepartureDate":1380016800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375098010413,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":750315,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304902561000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304330400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304416800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640213,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304388000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375098010413,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":753415}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":753415},"berthingId":235424,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1379901600000,"berthingArrivalDate":1379930400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379930400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":712735,"liveDepartureDate":1379988000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI338R","departureVoyage":"BI339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375263466000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379988000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18516},"operatorContainerMoves20":0,"updateTS":1375385144000,"noonPositionTelex":null,"pilotDepartureDate":1379559480000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"insertTS":1375312870020,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":752377,"averageVesselFuelConsumptionPerHour":2.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305072004000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305090004000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1020,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305169204000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":11345,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14191},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":17.97,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":708178,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.7,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305151204000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375312870020,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":755491}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":755491},"berthingId":235763,"vesselServiceAssignmentId":5633,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1379462280000,"berthingArrivalDate":1379480280000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":171},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":40},"dailyVesselScheduleCell":{"liveArrivalDate":1379514540000,"customArrivalVoyage":"338","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"338","dailyvesselschedulecellcompactId":714776,"liveDepartureDate":1379575740000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"338","departureVoyage":"338","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1012},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18516},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3121,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"SANTA RITA","vesselId":8298,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3121,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCHR","dateOutService":null,"dateInService":1336003200000,"code":"08244","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9425382","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":266},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375385144000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379541480000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"operatorContainerMoves20":0,"updateTS":1375431009000,"noonPositionTelex":null,"pilotDepartureDate":1380261600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375312508117,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":752348,"averageVesselFuelConsumptionPerHour":1.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306933252000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304546400000,"inheritedVoyage":"","adjustmentTime":105,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304661600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":30,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":14.76,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":4046,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304632800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375312508117,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":755462}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":755462},"berthingId":235803,"vesselServiceAssignmentId":5545,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"draftArrivalAFT":0.0,"pilotArrivalDate":1380117600000,"berthingArrivalDate":1380146400000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380146400000,"customArrivalVoyage":"693E37","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"694W39","dailyvesselschedulecellcompactId":714747,"liveDepartureDate":1380232800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"693E37","departureVoyage":"693E37","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18376},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1337,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":61},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375431009000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380232800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1375433883000,"noonPositionTelex":null,"pilotDepartureDate":1380434400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NM339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375345808007,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":752581,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304690440000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304719240000,"inheritedVoyage":"","adjustmentTime":92,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304834440000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2734,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55406,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805640000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375345808007,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":755695}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":755695},"berthingId":235808,"vesselServiceAssignmentId":1775,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1380290400000,"berthingArrivalDate":1380319200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NM339A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380319200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":714979,"liveDepartureDate":1380405600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NM339A","departureVoyage":"NM339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1712,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375433883000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380405600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"operatorContainerMoves20":0,"updateTS":1375521819000,"noonPositionTelex":null,"pilotDepartureDate":1378933200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FL336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375460109617,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753171,"averageVesselFuelConsumptionPerHour":4.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304946059000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304974859000,"inheritedVoyage":"","adjustmentTime":5,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305147659000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13406},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":10623,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13406},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":5.65,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":698940,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305118859000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375460109617,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756303}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756303},"berthingId":236037,"vesselServiceAssignmentId":4671,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1378731600000,"berthingArrivalDate":1378760400000,"operatorContainerMoves40":0,"customArrivalVoyage":"FL336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378760460000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":715569,"liveDepartureDate":1378904460000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FL336A","departureVoyage":"FL336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17746},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1880,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC IRENE","vesselId":4680,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1880,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MIRE","dateOutService":null,"dateInService":1273622400000,"code":"07059","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":366.0,"imoNumber":"9399040","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":46},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375521819000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378904400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"operatorContainerMoves20":0,"updateTS":1375689000000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RB339R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375682110600,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753913,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304884854000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304913654000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651686,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375682110600,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757051}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":757051},"berthingId":236083,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1381089600000,"berthingArrivalDate":1381118400000,"operatorContainerMoves40":0,"customArrivalVoyage":"RB339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381118400000,"customArrivalVoyage":"RB339R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB339R","dailyvesselschedulecellcompactId":716310,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB339R","departureVoyage":"RB339R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689000000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"operatorContainerMoves20":0,"updateTS":1375689000000,"noonPositionTelex":null,"pilotDepartureDate":1380628800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RB339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375682110600,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753910,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304877654000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304308800000,"inheritedVoyage":"","adjustmentTime":1,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304424000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":23874,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":12267},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":651687,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304395200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375682110600,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757048}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":757048},"berthingId":236084,"vesselServiceAssignmentId":5327,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1380484800000,"berthingArrivalDate":1380513600000,"operatorContainerMoves40":0,"customArrivalVoyage":"RB338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":531},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380513600000,"customArrivalVoyage":"RB338R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"RB339A","dailyvesselschedulecellcompactId":716307,"liveDepartureDate":1380600000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RB338R","departureVoyage":"RB338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2929,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":47},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689000000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380600000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":222},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1375689096000,"noonPositionTelex":null,"pilotDepartureDate":1380225600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1375689091000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375689091000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753967,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":1375689091000,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304625600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427152,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304596800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375689091000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757103}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":757103},"berthingId":236087,"vesselServiceAssignmentId":4383,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1380060000000,"berthingArrivalDate":1380088800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY339A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379484000000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":716377,"liveDepartureDate":1380196800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY339A","departureVoyage":"NY339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1038,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689096000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380196800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1375689096000,"noonPositionTelex":null,"pilotDepartureDate":1377806400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY335A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1375689091000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375689091000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753976,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":1375689091000,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304625600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427152,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304596800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375689091000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757141}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":757141},"berthingId":236108,"vesselServiceAssignmentId":5929,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1377640800000,"berthingArrivalDate":1377669600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY335A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377669600000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":716384,"liveDepartureDate":1377777600000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY335A","departureVoyage":"NY335A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1079,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC MEDITERRANEAN","vesselId":3061,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1079,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1325116740000,"dateInService":1106092800000,"code":"04703","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC MEDITERRANEAN","vesselId":6909,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1079,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MVMT","dateOutService":null,"dateInService":1325116800000,"code":"08002","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":202.8,"imoNumber":"9102710","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689096000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377777600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1375689096000,"noonPositionTelex":null,"pilotDepartureDate":1379620800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY338A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1375689091000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375689091000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753994,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":1375689091000,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304625600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427152,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304596800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375689091000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757126}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":757126},"berthingId":236112,"vesselServiceAssignmentId":3083,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1379455200000,"berthingArrivalDate":1379484000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY338A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1379011920000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":716358,"liveDepartureDate":1379592000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY338A","departureVoyage":"NY338A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1245,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689096000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379592000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1375689096000,"noonPositionTelex":null,"pilotDepartureDate":1378411200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1375689091000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375689091000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753984,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":1375689091000,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304625600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427152,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304596800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375689091000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757129}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":757129},"berthingId":236133,"vesselServiceAssignmentId":3080,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1378245600000,"berthingArrivalDate":1378274400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1377958800000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":716387,"liveDepartureDate":1378382400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY336A","departureVoyage":"NY336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1102,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689096000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378382400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1375689096000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY338R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1375689091000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375689091000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753959,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308088807000,"isBunkerCall":false,"updateTS":1375689091000,"berthingArrival":1308117607000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":12,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427150,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375689091000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757128}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":757128},"berthingId":236136,"vesselServiceAssignmentId":5929,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1381269600000,"berthingArrivalDate":1381298400000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381298400000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":716375,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY338R","departureVoyage":"NY338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1079,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689096000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"operatorContainerMoves20":0,"updateTS":1375689096000,"noonPositionTelex":null,"pilotDepartureDate":1379016000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NY337A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"deleteUser":null,"updateTS":1375689091000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375689091000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":754018,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460000000,"isBunkerCall":false,"updateTS":1375689091000,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":68,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304625600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":3235,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6479},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":427152,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304596800000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375689091000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757134}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"proformavesselscheduleterminalcallId":757134},"berthingId":236137,"vesselServiceAssignmentId":3103,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":385},"draftArrivalAFT":0.0,"pilotArrivalDate":1378850400000,"berthingArrivalDate":1378879200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NY337A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378540980000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":716401,"liveDepartureDate":1378987200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NY337A","departureVoyage":"NY337A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":331},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":15436},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1187,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":63},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689096000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378987200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"operatorContainerMoves20":0,"updateTS":1375689512000,"noonPositionTelex":null,"pilotDepartureDate":1380945600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NZ339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375467928413,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753351,"averageVesselFuelConsumptionPerHour":4.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305165602000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305198002000,"inheritedVoyage":"","adjustmentTime":10,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":120,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305345602000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13479},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":26819,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13480},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":39.75,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":701517,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305313202000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375467928413,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756483}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756483},"berthingId":236155,"vesselServiceAssignmentId":5873,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":749},"draftArrivalAFT":0.0,"pilotArrivalDate":1380765600000,"berthingArrivalDate":1380798000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NZ339A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380798000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":715749,"liveDepartureDate":1380913200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NZ339A","departureVoyage":"NZ339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":187},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17751},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3859,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC ANTALYA","vesselId":9357,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3859,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MNTY","dateOutService":null,"dateInService":1375142400000,"code":"09089","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9605152","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":69},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689512000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380913200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"operatorContainerMoves20":0,"updateTS":1375689768000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP340R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375606211740,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753780,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304812800000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305446405000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315676,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375606211740,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756918}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756918},"berthingId":236165,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1381017600000,"berthingArrivalDate":1381046400000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP340R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381046400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":716177,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP340R","departureVoyage":"RP340R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689768000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"operatorContainerMoves20":0,"updateTS":1375689768000,"noonPositionTelex":null,"pilotDepartureDate":1380600000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RP340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375606211740,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753777,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305387185000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304841600000,"inheritedVoyage":"","adjustmentTime":106,"timeInPort":2160,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305000000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":16,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":4697},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":315677,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304971200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375606211740,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756915}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756915},"berthingId":236166,"vesselServiceAssignmentId":5905,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":754},"draftArrivalAFT":0.0,"pilotArrivalDate":1380412800000,"berthingArrivalDate":1380441600000,"operatorContainerMoves40":0,"customArrivalVoyage":"RP339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":532},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380441600000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":716174,"liveDepartureDate":1380571200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RP339R","departureVoyage":"RP340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":168},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21897},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1702,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":76},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375689768000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380571200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":226},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"operatorContainerMoves20":0,"updateTS":1375690374000,"noonPositionTelex":null,"pilotDepartureDate":1380997800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NU340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375678533710,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753890,"averageVesselFuelConsumptionPerHour":2.8,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304627431000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304656231000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304793031000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1059,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.35,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246168,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304764231000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375678533710,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757028}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":757028},"berthingId":236183,"vesselServiceAssignmentId":4640,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1380832200000,"berthingArrivalDate":1380861000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NU340A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380861000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":716287,"liveDepartureDate":1380969000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NU340A","departureVoyage":"NU340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1132,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375690374000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380969000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20364},"operatorContainerMoves20":0,"updateTS":1375690396000,"noonPositionTelex":null,"pilotDepartureDate":1380492000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NP339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375510815427,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753478,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306513410000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304748000000,"inheritedVoyage":"","adjustmentTime":307,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":750,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304892000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1036,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":13073},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.58,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":681495,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":13.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304863200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375510815427,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756612}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756612},"berthingId":236197,"vesselServiceAssignmentId":5074,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"draftArrivalAFT":0.0,"pilotArrivalDate":1380319200000,"berthingArrivalDate":1380348000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NP338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380348000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":715875,"liveDepartureDate":1380463200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NP338R","departureVoyage":"NP339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20364},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3617,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":65},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375690396000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380463200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"operatorContainerMoves20":0,"updateTS":1375691691000,"noonPositionTelex":null,"pilotDepartureDate":1380650400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NG340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375644339803,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753810,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1309284047000,"isBunkerCall":false,"updateTS":1375981499000,"berthingArrival":1309312847000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2400,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1309485647000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":19368,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":9871},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":617450,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1309456847000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375644339803,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756948}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756948},"berthingId":236214,"vesselServiceAssignmentId":5615,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":603},"draftArrivalAFT":0.0,"pilotArrivalDate":1380448800000,"berthingArrivalDate":1380477600000,"operatorContainerMoves40":0,"customArrivalVoyage":"NG336R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380420000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":716207,"liveDepartureDate":1380564000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NG336R","departureVoyage":"NG340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":540},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17735},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1382,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":71},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375691691000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380621600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375694603000,"noonPositionTelex":null,"pilotDepartureDate":1380520800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375539002037,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753647,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305861840000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304776800000,"inheritedVoyage":"","adjustmentTime":36,"timeInPort":1920,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":1680,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304920800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":2.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4990,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14832},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":113.62,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":732082,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304892000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375539002037,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756784}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756784},"berthingId":236218,"vesselServiceAssignmentId":5311,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"draftArrivalAFT":0.0,"pilotArrivalDate":1380348000000,"berthingArrivalDate":1380376800000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":640},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380376800000,"customArrivalVoyage":"BA337R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BA339A","dailyvesselschedulecellcompactId":716044,"liveDepartureDate":1380492000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BA337R","departureVoyage":"BA337R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":417},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":997,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":7},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375694603000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380492000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":525},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375694863000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF340R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375631707130,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753809,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304834400000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1305468017000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382102,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375631707130,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756947}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756947},"berthingId":236225,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1381039200000,"berthingArrivalDate":1381068000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF340R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381060800000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":716206,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF340R","departureVoyage":"BF340R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375694863000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375694863000,"noonPositionTelex":null,"pilotDepartureDate":1380564000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BF340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375631707130,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753805,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305432017000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304863200000,"inheritedVoyage":"","adjustmentTime":34,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304964000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2844,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5842},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382104,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304935200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375631707130,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756943}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756943},"berthingId":236227,"vesselServiceAssignmentId":3065,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":447},"draftArrivalAFT":0.0,"pilotArrivalDate":1380434400000,"berthingArrivalDate":1380463200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BF339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":377},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380456000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":716202,"liveDepartureDate":1380528000000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BF339R","departureVoyage":"BF340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":373},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3305,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":12},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375694863000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380535200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":451},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375698226000,"noonPositionTelex":null,"pilotDepartureDate":1380607200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375656611193,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753868,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306068115000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304892000000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007200000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2886,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5858},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382126,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978400000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375656611193,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757006}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":757006},"berthingId":236247,"vesselServiceAssignmentId":4493,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":159},"draftArrivalAFT":0.0,"pilotArrivalDate":1380463200000,"berthingArrivalDate":1380492000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380492000000,"customArrivalVoyage":"BJ338R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BJ340A","dailyvesselschedulecellcompactId":716265,"liveDepartureDate":1380578400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BJ338R","departureVoyage":"BJ338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":153},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":771,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":16},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375698226000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380578400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375705005000,"noonPositionTelex":null,"pilotDepartureDate":null,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI340R","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375696809673,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":754072,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304906401000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304935201000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":5,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640211,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375696809673,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757209}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":757209},"berthingId":236277,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1381111200000,"berthingArrivalDate":1381140000000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI340R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381140000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":716469,"liveDepartureDate":null,"isPortOfReturn":true,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI340R","departureVoyage":"BI340R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375705005000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":null,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"operatorContainerMoves20":0,"updateTS":1375705005000,"noonPositionTelex":null,"pilotDepartureDate":1380621600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BI340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375696809673,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":754068,"averageVesselFuelConsumptionPerHour":1.3,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304902561000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304330400000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304416800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22957,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11857},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":57.21,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":640213,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.315,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304388000000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375696809673,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757205}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":757205},"berthingId":236279,"vesselServiceAssignmentId":5805,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":145},"draftArrivalAFT":0.0,"pilotArrivalDate":1380506400000,"berthingArrivalDate":1380535200000,"operatorContainerMoves40":0,"customArrivalVoyage":"BI339R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":136},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380535200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":716465,"liveDepartureDate":1380592800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BI339R","departureVoyage":"BI340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":137},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12142},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2143,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":15},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375705005000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380592800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":142},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19805},"operatorContainerMoves20":0,"updateTS":1375718034000,"noonPositionTelex":null,"pilotDepartureDate":1380693600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"RM340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375631409257,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":753799,"averageVesselFuelConsumptionPerHour":1.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949600000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304978400000,"inheritedVoyage":"","adjustmentTime":6,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":3918,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305093600000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14491},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":13152,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":14491},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":18.9,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":718756,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305064800000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375631409257,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":756937}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":756937},"berthingId":236546,"vesselServiceAssignmentId":3077,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1380549600000,"berthingArrivalDate":1380578400000,"operatorContainerMoves40":0,"customArrivalVoyage":"RM340A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1218},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380578400000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":716196,"liveDepartureDate":1380664800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"RM340A","departureVoyage":"RM340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":19805},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1393,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":5},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375718034000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380664800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"operatorContainerMoves20":0,"updateTS":1375799089000,"noonPositionTelex":null,"pilotDepartureDate":1378578600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NU336A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"deleteUser":null,"updateTS":1375799088000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375799088000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":755241,"averageVesselFuelConsumptionPerHour":2.8,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304627431000,"isBunkerCall":false,"updateTS":1375799088000,"berthingArrival":1304656231000,"inheritedVoyage":"","adjustmentTime":8,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304793031000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":1059,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":3578},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":28.35,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":246168,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.9,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304764231000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375799088000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":758389}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"proformavesselscheduleterminalcallId":758389},"berthingId":236703,"vesselServiceAssignmentId":5939,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1378413000000,"berthingArrivalDate":1378441800000,"operatorContainerMoves40":0,"customArrivalVoyage":"NU336A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":173},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1378441800000,"customArrivalVoyage":null,"?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":null,"dailyvesselschedulecellcompactId":717607,"liveDepartureDate":1378549800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NU336A","departureVoyage":"NU336A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":17733},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1477,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC LUDOVICA","vesselId":2136,"isInService":false,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1477,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"","dateOutService":1327190340000,"dateInService":998438400000,"code":"02240","nextProgressiveVoyageNumber":"0"},{"isDeleted":false,"name":"MSC LUDOVICA","vesselId":8042,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1477,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MSLU","dateOutService":null,"dateInService":1327190400000,"code":"08035","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":299.9,"imoNumber":"9251690","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":70},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375799089000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378549800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":756},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1375832236000,"noonPositionTelex":null,"pilotDepartureDate":1381212000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NC340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375777502220,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":754966,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304843432000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304872232000,"inheritedVoyage":"","adjustmentTime":97,"timeInPort":1770,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":720,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1305007232000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2673,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":4,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":52229,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304978432000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375777502220,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":758119}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":758119},"berthingId":236948,"vesselServiceAssignmentId":5162,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1381048200000,"berthingArrivalDate":1381077000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NC340A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1056},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1381077000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":717330,"liveDepartureDate":1381183200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NC340A","departureVoyage":"NC340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1784,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":1},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375832236000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1381183200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":250},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"operatorContainerMoves20":0,"updateTS":1375863050000,"noonPositionTelex":null,"pilotDepartureDate":1380751200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375803006280,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":755442,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305551521000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304431200000,"inheritedVoyage":"","adjustmentTime":19,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":60,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304546400000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6741,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6095},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":403968,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304517600000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375803006280,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":758598}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":758598},"berthingId":237000,"vesselServiceAssignmentId":3063,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":197},"draftArrivalAFT":0.0,"pilotArrivalDate":1380607200000,"berthingArrivalDate":1380636000000,"operatorContainerMoves40":0,"customArrivalVoyage":"","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380636000000,"customArrivalVoyage":"BB338R","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"BB340A","dailyvesselschedulecellcompactId":717806,"liveDepartureDate":1380722400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BB338R","departureVoyage":"BB338R","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":156},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":769,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":8},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375863050000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380722400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"operatorContainerMoves20":0,"updateTS":1375863521000,"noonPositionTelex":null,"pilotDepartureDate":1380693600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BC340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375741204297,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":754703,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305543885000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304373600000,"inheritedVoyage":"","adjustmentTime":11,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304488800000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":6846,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":6664},"sequence":1,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":439882,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":16.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304460000000,"pilotStation":{"?p":"true","pilotstationId":2,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375741204297,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757852}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":757852},"berthingId":237006,"vesselServiceAssignmentId":5733,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1380549600000,"berthingArrivalDate":1380578400000,"operatorContainerMoves40":0,"customArrivalVoyage":"BC338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":534},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380636000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":717067,"liveDepartureDate":1380722400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BC338R","departureVoyage":"BC340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1379,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":9},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375863521000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380664800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":230},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"operatorContainerMoves20":0,"updateTS":1375864461000,"noonPositionTelex":null,"pilotDepartureDate":1380808800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"BH340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375859709140,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":755909,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305650141000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304488800000,"inheritedVoyage":"","adjustmentTime":16,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304604000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2860,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":5846},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":382113,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304575200000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375859709140,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":759065}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":759065},"berthingId":237020,"vesselServiceAssignmentId":2933,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":750},"draftArrivalAFT":0.0,"pilotArrivalDate":1380664800000,"berthingArrivalDate":1380693600000,"operatorContainerMoves40":0,"customArrivalVoyage":"BH338R","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":184},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380636000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":718254,"liveDepartureDate":1380722400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"BH338R","departureVoyage":"BH340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":191},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18989},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":2545,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":14},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375864461000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380780000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"operatorContainerMoves20":0,"updateTS":1375867611000,"noonPositionTelex":null,"pilotDepartureDate":1380888000000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NW340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375770320593,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":754849,"averageVesselFuelConsumptionPerHour":3.5,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304517635000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304546435000,"inheritedVoyage":"","adjustmentTime":2396,"timeInPort":1800,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304683235000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":22167,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":11453},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":21.23,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":636499,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":15.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304654435000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375770320593,"useTimeZoneDifference":false,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":757999}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":757999},"berthingId":237036,"vesselServiceAssignmentId":5806,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"draftArrivalAFT":0.0,"pilotArrivalDate":1380722400000,"berthingArrivalDate":1380751200000,"operatorContainerMoves40":0,"customArrivalVoyage":"NW340A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380751200000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":717213,"liveDepartureDate":1380859200000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NW340A","departureVoyage":"NW340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":614},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":13229},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1785,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC KIM","vesselId":4057,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1785,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MKIM","dateOutService":null,"dateInService":1208908800000,"code":"06047","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":265.0,"imoNumber":"9351581","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":66},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375867611000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380859200000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18511},"operatorContainerMoves20":0,"updateTS":1375886738000,"noonPositionTelex":null,"pilotDepartureDate":1380480300000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"FS339A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375815009437,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":755777,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304649950000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304678750000,"inheritedVoyage":"","adjustmentTime":0,"timeInPort":2880,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304880350000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12635,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8320},"sequence":3,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":559561,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":14.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304851550000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375815009437,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":758933}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":758933},"berthingId":237140,"vesselServiceAssignmentId":4523,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":744},"draftArrivalAFT":0.0,"pilotArrivalDate":1380249900000,"berthingArrivalDate":1380278700000,"operatorContainerMoves40":0,"customArrivalVoyage":"FS339A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":613},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380278700000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":718122,"liveDepartureDate":1380451500000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"FS339A","departureVoyage":"FS339A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":49},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":18511},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":1904,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MSC MELATILDE","vesselId":4749,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":1904,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"MMED","dateOutService":null,"dateInService":1277251200000,"code":"07146","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":366.0,"imoNumber":"9404675","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":89},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375886738000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380451500000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375893273000,"noonPositionTelex":null,"pilotDepartureDate":1381183200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":null,"proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892932000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1375892932000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":756856,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1311621260000,"isBunkerCall":false,"updateTS":1375893271000,"berthingArrival":1311650060000,"inheritedVoyage":"","adjustmentTime":17,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1311736460000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15317},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15317},"sequence":12,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":756765,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307282401000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1307311201000,"inheritedVoyage":"","adjustmentTime":17,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"proformavesselscheduleId":1529,"vesselClass":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule","service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"updateTS":1375892440000,"isMaster":true,"isDeleted":false,"insertTS":1375892440000,"isInService":true,"versionInfo":"NWC 3 - SAMBA  07/08","version":10,"dateInUse":null,"deleteTS":null,"proformaVesselSchedulePorts":[{"mergedSequence":null,"proformavesselscheduleportId":756759,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308560659000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1304319600000,"inheritedVoyage":"","adjustmentTime":554,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304388000000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15319},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":4472,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"deleteUser":null,"pilotStationFrom":null,"updateTS":1340212479000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"distanceInMiles":166,"insertTS":1340212479000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1346},"pilottimeId":15319,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":1,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.4,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304384400000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1346},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756759,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759924}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756757,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304460045000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1304467245000,"inheritedVoyage":"","adjustmentTime":1350,"timeInPort":780,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1304521245000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15324},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"isOverride":false,"serviceportdistanceId":7805,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance","pilotStationTo":null,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":7053},"service":{"voyageIncrement":1,"isSelectedVesselCurrentlyOnService":"false","?t":"com.msc.medlog.mwp.entities.Service","isProformaDayMatched":true,"isApproved":true,"berthingCode":"IPAN","isStandardMSCVoyageCoding":true,"useVoyageLinking":true,"isDeleted":false,"startDate":null,"includesAllPortCalls":false,"isInService":true,"repeatWeeks":11,"callFrequency":7,"requiresMatchingDaysToMergePortCalls":true,"color":"d3d3d3","laneCode":"IPAN","useWeeklyVoyageNumbers":true,"name":"IPANEMA","exceedingDateOffset":10080,"isScheduleDelayDisplayed":true,"serviceId":220,"incrementVoyageNumberOnRoutingSwitch":false,"tradeCode":"FI","dailyVesselScheduleAllowedDelay":720,"inheritsDelay":true},"deleteUser":null,"pilotStationFrom":null,"updateTS":1352481736000,"portFrom":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"portTo":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"distanceInMiles":772,"insertTS":1352481736000,"isInService":true,"deleteTS":null,"insertUser":{"isDeleted":false,"isInService":true,"?t":"com.msc.medlog.mwp.entities.User","userName":"Emanuele DI DIO","userId":7053}},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"pilottimeId":15324,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":67},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":8.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304514045000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":62},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756757,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759929}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756760,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304949645000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1304953245000,"inheritedVoyage":"","adjustmentTime":29,"timeInPort":1410,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305041445000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15326},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12775,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":570},"pilottimeId":15326,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":634},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":3,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305037845000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":570},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756760,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759919}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756758,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305100807000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1305104407000,"inheritedVoyage":"","adjustmentTime":17,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":70},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305165607000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15323},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12776,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":65},"pilottimeId":15323,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":70},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":4,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305162007000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":65},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756758,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759922}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756756,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305226858000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1305234058000,"inheritedVoyage":"","adjustmentTime":42,"timeInPort":600,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":897},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305277258000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15321},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12778,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1289},"pilottimeId":15321,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":897},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":5,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305270058000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1289},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756756,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759923}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756761,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305331227000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1305334827000,"inheritedVoyage":"","adjustmentTime":31,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305396027000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15325},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12765,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":68},"pilottimeId":15325,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":6,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305392427000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":68},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756761,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759930}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756764,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1305759601000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1305763201000,"inheritedVoyage":"","adjustmentTime":168,"timeInPort":840,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":784},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1305817201000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15318},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":4.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12772,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":63},"pilottimeId":15318,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":784},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":7,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1305813601000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":63},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756764,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759921}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756767,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306414839000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1306418439000,"inheritedVoyage":"","adjustmentTime":14,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306486839000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15327},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12769,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"pilottimeId":15327,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":8,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":17.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306483239000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756767,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759920}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756762,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306756846000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1306764046000,"inheritedVoyage":"","adjustmentTime":110,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306857646000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15316},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12770,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":120.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"pilottimeId":15316,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":232},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":9,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":12.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306850446000,"pilotStation":null,"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":536},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756762,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759926}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756766,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1306908046000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1306911646000,"inheritedVoyage":"","adjustmentTime":1320,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1306972846000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15322},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12777,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":60.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":340},"pilottimeId":15322,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":762},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":10,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":10.0,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1306969246000,"pilotStation":{"?p":"true","pilotstationId":15,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":340},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756766,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759925}],"dieselConsumption":0.0},{"mergedSequence":null,"proformavesselscheduleportId":756768,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307124046000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1307138446000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":1200,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307224846000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15320},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12774,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":240.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"pilottimeId":15320,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":11,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":16.0,"isVoyageCodeUpdateRequired":true,"isLocked":"false","berthingDeparture":1307210446000,"pilotStation":{"?p":"true","pilotstationId":6,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756768,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759928}],"dieselConsumption":0.0},{"?p":"true","proformavesselscheduleportId":756765,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},{"mergedSequence":null,"proformavesselscheduleportId":756763,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307646052000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1307649652000,"inheritedVoyage":"","adjustmentTime":4,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":{"?p":"true","proformavesselscheduleId":1529,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedule"},"isInService":true,"pilotDeparture":1307739652000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15327},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":-4.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12767,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15327},"sequence":13,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":19.1,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307736052000,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756763,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759932}],"dieselConsumption":0.0}],"voyageCalculationMethod":{"?p":"true","?t":"com.msc.medlog.mwp.entities.VoyageCalculationMethod","voyagecalculationmethodId":1},"vesselClassDraft":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformaVesselScheduleReeferDetails":[],"dateOutUse":null,"portOfReturn":{"mergedSequence":null,"proformavesselscheduleportId":756755,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1308549619000,"isBunkerCall":false,"updateTS":1375892410000,"berthingArrival":1308553219000,"inheritedVoyage":"","adjustmentTime":554,"timeInPort":1080,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":74},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":null,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15319},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":4472,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15319},"sequence":14,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":15.4,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":null,"pilotStation":null,"routing":"R","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1346},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756755,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759927}],"dieselConsumption":0.0},"isInUse":"false","originalProformaVesselSchedule":null},"isInService":true,"pilotDeparture":1307397601000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15317},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"isOverride":false,"?t":"com.msc.medlog.mwp.entities.PilotTime","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"pilotOnOffBoard":480.0,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"pilottimeId":15317,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"insertTS":1375892440000,"isInService":true,"deleteTS":null,"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330}},"sequence":12,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":null,"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307368801000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375892440000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892440000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1375892440000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756765,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759931}],"dieselConsumption":0.0},"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1311707660000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375892932000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":760042}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":760042},"berthingId":237206,"vesselServiceAssignmentId":4155,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1381068000000,"berthingArrivalDate":1381096800000,"operatorContainerMoves40":0,"customArrivalVoyage":null,"nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"dailyVesselScheduleCell":{"liveArrivalDate":1381218120000,"customArrivalVoyage":"1313","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"1313","dailyvesselschedulecellcompactId":719131,"liveDepartureDate":1381275720000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"1313","departureVoyage":"1313","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3323,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MAERSK LINS","vesselId":8588,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3323,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCLI","dateOutService":null,"dateInService":1347580800000,"code":"08500","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9527025","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375893273000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1381154400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375893273000,"noonPositionTelex":null,"pilotDepartureDate":1380578400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":null,"proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892932000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1375892932000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":756823,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1311621260000,"isBunkerCall":false,"updateTS":1375893271000,"berthingArrival":1311650060000,"inheritedVoyage":"","adjustmentTime":17,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1311736460000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15317},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15317},"sequence":12,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756765,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1311707660000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375892932000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":759996}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759996},"berthingId":237220,"vesselServiceAssignmentId":4157,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1380463200000,"berthingArrivalDate":1380492000000,"operatorContainerMoves40":0,"customArrivalVoyage":null,"nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"dailyVesselScheduleCell":{"liveArrivalDate":1380690780000,"customArrivalVoyage":"1313","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"1313","dailyvesselschedulecellcompactId":719145,"liveDepartureDate":1380748380000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"1313","departureVoyage":"1313","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3147,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MAERSK LETICIA","vesselId":8343,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3147,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCKC","dateOutService":null,"dateInService":1335139200000,"code":"08285","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9526916","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375893273000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1380549600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375893273000,"noonPositionTelex":null,"pilotDepartureDate":1379973600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":null,"proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375892746000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1375892746000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":756805,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1311621260000,"isBunkerCall":false,"updateTS":1375893271000,"berthingArrival":1311650060000,"inheritedVoyage":"","adjustmentTime":17,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1311736460000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15317},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15317},"sequence":12,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756765,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1311707660000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375892746000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":759943}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":759943},"berthingId":237234,"vesselServiceAssignmentId":4154,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1379858400000,"berthingArrivalDate":1379887200000,"operatorContainerMoves40":0,"customArrivalVoyage":null,"nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"dailyVesselScheduleCell":{"liveArrivalDate":1379887200000,"customArrivalVoyage":"1313","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"1313","dailyvesselschedulecellcompactId":719125,"liveDepartureDate":1379944800000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"1313","departureVoyage":"1313","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3258,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MAERSK LABERINTO","vesselId":8507,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3258,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCET","dateOutService":null,"dateInService":1341964800000,"code":"08435","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9526978","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375893273000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379944800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21832},"operatorContainerMoves20":0,"updateTS":1375905397000,"noonPositionTelex":null,"pilotDepartureDate":1379368800000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":null,"proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21832},"deleteUser":null,"updateTS":1375905390000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1375905390000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":757030,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21832},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307267110000,"isBunkerCall":false,"updateTS":1375905390000,"berthingArrival":1307295910000,"inheritedVoyage":"","adjustmentTime":17,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1307382310000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15317},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21832},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":15317},"sequence":11,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":756765,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307353510000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375905390000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":760201}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":21832},"proformavesselscheduleterminalcallId":760201},"berthingId":237248,"vesselServiceAssignmentId":4153,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1379253600000,"berthingArrivalDate":1379282400000,"operatorContainerMoves40":0,"customArrivalVoyage":null,"nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"dailyVesselScheduleCell":{"liveArrivalDate":1379224800000,"customArrivalVoyage":"1313","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"1313","dailyvesselschedulecellcompactId":719352,"liveDepartureDate":1379282400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"1313","departureVoyage":"1313","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3111,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MAERSK LEBU","vesselId":8279,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3111,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCKB","dateOutService":null,"dateInService":1333929600000,"code":"08225","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9526930","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375893273000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1379340000000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375893273000,"noonPositionTelex":null,"pilotDepartureDate":1378159200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"1311","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375893271000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1375893271000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":756950,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307030499000,"isBunkerCall":false,"updateTS":1375893271000,"berthingArrival":1307059299000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1307145699000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8365},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8365},"sequence":11,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561507,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307116899000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375893271000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":760075}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":760075},"berthingId":237276,"vesselServiceAssignmentId":4158,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1378044000000,"berthingArrivalDate":1378072800000,"operatorContainerMoves40":0,"customArrivalVoyage":"1311","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"dailyVesselScheduleCell":{"liveArrivalDate":1378025700000,"customArrivalVoyage":"1311","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"1311","dailyvesselschedulecellcompactId":719216,"liveDepartureDate":1378083300000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"1311","departureVoyage":"1311","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3108,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MAERSK LAGUNA","vesselId":8276,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3108,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCGU","dateOutService":null,"dateInService":1332806400000,"code":"08222","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9526942","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375893273000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1378130400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375893273000,"noonPositionTelex":null,"pilotDepartureDate":1377554400000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"1311","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375893271000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1375893271000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":756925,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307003349000,"isBunkerCall":false,"updateTS":1375893271000,"berthingArrival":1307032149000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1307118549000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8365},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8365},"sequence":10,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561507,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307089749000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375893271000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":760116}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":760116},"berthingId":237289,"vesselServiceAssignmentId":4159,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1377439200000,"berthingArrivalDate":1377468000000,"operatorContainerMoves40":0,"customArrivalVoyage":"1311","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"dailyVesselScheduleCell":{"liveArrivalDate":1377542760000,"customArrivalVoyage":"1311","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"1311","dailyvesselschedulecellcompactId":719238,"liveDepartureDate":1377600360000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"1311","departureVoyage":"1311","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"isDeleted":false,"isInService":true,"vesselphysicalinfoId":3124,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo","vessels":[{"isDeleted":false,"name":"MAERSK LIRQUEN","vesselId":8301,"isInService":true,"?t":"com.msc.medlog.mwp.entities.Vessel","physicalInfo":{"?p":"true","vesselphysicalinfoId":3124,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"caspCode":"SCKQ","dateOutService":null,"dateInService":1336435200000,"code":"08247","nextProgressiveVoyageNumber":"0"}],"vesselClassCompact":null,"isTBNVessel":false,"length":null,"imoNumber":"9526887","vesselServiceChange":null},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375893273000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1377525600000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"operatorContainerMoves20":0,"updateTS":1375893273000,"noonPositionTelex":null,"pilotDepartureDate":1376949600000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"1311","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"deleteUser":null,"updateTS":1375893271000,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"insertTS":1375893271000,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":756963,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1307003349000,"isBunkerCall":false,"updateTS":1375893271000,"berthingArrival":1307032149000,"inheritedVoyage":"","adjustmentTime":18,"timeInPort":960,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1307118549000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8365},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"timezoneCorrectionGMT":0.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":12771,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":8365},"sequence":10,"adjustmentTimeIsPositiveValue":false,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":0.0,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":561507,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.5,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1307089749000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"R","consumptionModifier":0,"insertTS":1375893271000,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":760062}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"proformavesselscheduleterminalcallId":760062},"berthingId":237301,"vesselServiceAssignmentId":4155,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":747},"draftArrivalAFT":0.0,"pilotArrivalDate":1376834400000,"berthingArrivalDate":1376863200000,"operatorContainerMoves40":0,"customArrivalVoyage":"1311","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":728},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":1263},"dailyVesselScheduleCell":{"liveArrivalDate":1376984520000,"customArrivalVoyage":"1311","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"1311","dailyvesselschedulecellcompactId":719267,"liveDepartureDate":1377042120000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"1311","departureVoyage":"1311","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":185},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":12330},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":3323,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":207},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375893273000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1376920800000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":171},"operatorFullMoves":0},{"?t":"com.msc.medlog.mwp.entities.Berthing","updateUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"operatorContainerMoves20":0,"updateTS":1375999823000,"noonPositionTelex":null,"pilotDepartureDate":1381039200000,"isDeleted":false,"isInService":true,"departureTelex":null,"vesselNumber":null,"customDepartureVoyage":"NM340A","proformaVesselScheduleTerminalCall":{"sequence":1,"?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","updateUser":null,"deleteUser":null,"updateTS":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"insertTS":1375948506577,"isDeleted":false,"isInService":true,"deleteTS":null,"proformaVesselSchedulePort":{"mergedSequence":null,"proformavesselscheduleportId":757201,"averageVesselFuelConsumptionPerHour":0.0,"updateUser":null,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort","pilotArrival":1304690440000,"isBunkerCall":false,"updateTS":null,"berthingArrival":1304719240000,"inheritedVoyage":"","adjustmentTime":92,"timeInPort":1440,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"isDeleted":false,"bufferTime":0,"proformaVesselSchedule":null,"isInService":true,"pilotDeparture":1304834440000,"departurePilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"timezoneCorrectionGMT":1.0,"servicePortDistance":{"?p":"true","serviceportdistanceId":2734,"?t":"com.msc.medlog.mwp.entities.ServicePortDistance"},"arrivalPilotTime":{"?p":"true","?t":"com.msc.medlog.mwp.entities.PilotTime","pilottimeId":253},"sequence":2,"adjustmentTimeIsPositiveValue":true,"averageVesselFuelConsumptionSteaming":0.0,"isTransitionPort":false,"manoeuvringConsumption":null,"averageLiveTransitionTime":"0","deleteUser":null,"leg":1,"matchingProformaVesselSchedulePort":{"?p":"true","proformavesselscheduleportId":55406,"?t":"com.msc.medlog.mwp.entities.ProformaVesselSchedulePort"},"speed":18.8,"isVoyageCodeUpdateRequired":false,"isLocked":"false","berthingDeparture":1304805640000,"pilotStation":{"?p":"true","pilotstationId":1,"?t":"com.msc.medlog.mwp.entities.PilotStation"},"routing":"A","consumptionModifier":0,"insertTS":1375948506577,"useTimeZoneDifference":true,"deleteTS":null,"terminalCalls":[{"?p":"true","?t":"com.msc.medlog.mwp.entities.ProformaVesselScheduleTerminalCall","proformavesselscheduleterminalcallId":760368}],"dieselConsumption":0.0},"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":-1006},"proformavesselscheduleterminalcallId":760368},"berthingId":237890,"vesselServiceAssignmentId":3975,"draftDeparture":0.0,"isLocked":false,"draftArrivalFW":0.0,"previousPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":671},"draftArrivalAFT":0.0,"pilotArrivalDate":1380895200000,"berthingArrivalDate":1380924000000,"operatorContainerMoves40":0,"customArrivalVoyage":"NM340A","nextTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":502},"portComment":null,"terminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":47},"dailyVesselScheduleCell":{"liveArrivalDate":1380924000000,"customArrivalVoyage":"","?t":"com.msc.medlog.mwp.entities.DailyVesselScheduleCellCompact","customDepartureVoyage":"","dailyvesselschedulecellcompactId":719517,"liveDepartureDate":1381010400000,"isPortOfReturn":false,"isDeleted":false,"isInService":true,"arrivalVoyage":"NM340A","departureVoyage":"NM340A","isCanceled":false,"isModificationComplete":false},"operatorEmptyMoves":0,"port":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":743},"previousTerminal":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Terminal","terminalId":526},"hiddenBerthings":[],"insertUser":{"?p":"true","?t":"com.msc.medlog.mwp.entities.User","userId":20110},"vesselPhysicalInfo":{"?p":"true","vesselphysicalinfoId":1711,"?t":"com.msc.medlog.mwp.entities.VesselPhysicalInfo"},"operatorReeferMoves":0,"amountOfRestows":0,"departureDisplayMode":1,"arrivalDisplayMode":1,"service":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Service","serviceId":57},"timeReceived":null,"deleteUser":null,"isUnlinked":false,"timeClosed":null,"draftArrival":0.0,"insertTS":1375999823000,"arrivalTelex":null,"deleteTS":null,"isModificationComplete":false,"berthingDepartureDate":1381010400000,"nextPort":{"?p":"true","?t":"com.msc.medlog.mwp.entities.Port","portId":576},"operatorFullMoves":0}]';
}